'use strict';

var tslib = require('tslib');
var React = require('react');
var classnames = require('classnames');
var reactAria = require('react-aria');
var reactAriaComponents = require('react-aria-components');
var Badge = require('../../Badge/Badge.cjs');
require('../../Loading/LoadingGraphic/LoadingGraphic.cjs');
require('../../Loading/LoadingHeading/LoadingHeading.cjs');
require('../../Loading/LoadingInput/LoadingInput.cjs');
require('../../Loading/LoadingParagraph/LoadingParagraph.cjs');
var LoadingSpinner = require('../../Loading/LoadingSpinner/LoadingSpinner.cjs');
var GenericButton_module = require('./GenericButton.module.scss.cjs');
function _interopDefault(e) {
  return e && e.__esModule ? e : {
    default: e
  };
}
var React__default = /*#__PURE__*/_interopDefault(React);
var classnames__default = /*#__PURE__*/_interopDefault(classnames);

// We're treating custom props as anything that is kebab cased.
// This is so we can support properties like aria-* or data-*
var getCustomProps = function (props) {
  var keys = Object.keys(props).filter(function (k) {
    return k.includes('-');
  });
  return keys.reduce(function (acc, val) {
    acc[val] = props[val];
    return acc;
  }, {});
};
var GenericButton = React.forwardRef(function (_a, ref) {
  var _b = _a.iconPosition,
    iconPosition = _b === void 0 ? 'start' : _b,
    _c = _a.iconButton,
    iconButton = _c === void 0 ? false : _c,
    _d = _a.primary,
    primary = _d === void 0 ? false : _d,
    _e = _a.secondary,
    secondary = _e === void 0 ? false : _e,
    _f = _a.newTabAndIUnderstandTheAccessibilityImplications,
    newTabAndIUnderstandTheAccessibilityImplications = _f === void 0 ? false : _f,
    _g = _a.disableTabFocusAndIUnderstandTheAccessibilityImplications,
    disableTabFocusAndIUnderstandTheAccessibilityImplications = _g === void 0 ? false : _g,
    _h = _a.type,
    type = _h === void 0 ? 'button' : _h,
    otherProps = tslib.__rest(_a, ["iconPosition", "iconButton", "primary", "secondary", "newTabAndIUnderstandTheAccessibilityImplications", "disableTabFocusAndIUnderstandTheAccessibilityImplications", "type"]);
  var buttonRef = React.useRef();
  var wrapperRef = React.useRef(null);
  React.useImperativeHandle(ref, function () {
    return {
      focus: function () {
        var _a;
        (_a = buttonRef.current) === null || _a === void 0 ? void 0 : _a.focus();
      }
    };
  });
  var props = tslib.__assign({
    iconPosition: iconPosition,
    iconButton: iconButton,
    primary: primary,
    secondary: secondary,
    newTabAndIUnderstandTheAccessibilityImplications: newTabAndIUnderstandTheAccessibilityImplications,
    disableTabFocusAndIUnderstandTheAccessibilityImplications: disableTabFocusAndIUnderstandTheAccessibilityImplications,
    type: type
  }, otherProps);
  if (props.component) {
    return renderCustomComponent(props.component, props, wrapperRef);
  }
  return React__default.default.createElement("span", {
    ref: wrapperRef,
    className: classnames__default.default(GenericButton_module.container, props.fullWidth && GenericButton_module.fullWidth),
    "aria-live": 'workingLabel' in props ? 'polite' : undefined
  }, props.href && !props.disabled && !props.working ? renderLink(props, buttonRef) : renderButton(props, buttonRef));
});
GenericButton.displayName = 'GenericButton';
var renderCustomComponent = function (CustomComponent, props, ref) {
  var passedInProps = tslib.__assign({
    'id': props.id,
    'className': buttonClass(props),
    'disabled': props.disabled,
    'href': props.href,
    'onClick': props.onClick,
    'onFocus': props.onFocus,
    'onBlur': props.onBlur,
    'aria-label': generateAriaLabel(props)
  }, getCustomProps(props));
  var _a = reactAriaComponents.useContextProps(passedInProps, ref,
    // @ts-expect-error we're using span ref on link context, but that's ok because we need only sizing
    reactAriaComponents.LinkContext),
    contextProps = _a[0],
    contextRef = _a[1];
  // @ts-expect-error Not fixing as a new Button component exists
  // @todo: Make a wrapper and take it out of Button
  var linkProps = reactAria.useLink(contextProps, contextRef).linkProps;
  // Unset this because the one defined in buttonProps shows
  // focus-visible styles on click, in future we'll style using [data-focus-visible] which is consistent across browsers
  delete linkProps.onPointerDown;
  return React__default.default.createElement("span", {
    ref: contextRef,
    className: classnames__default.default(GenericButton_module.container, props.fullWidth && GenericButton_module.fullWidth),
    "aria-live": 'workingLabel' in props ? 'polite' : undefined
  }, React__default.default.createElement(CustomComponent, tslib.__assign({}, contextProps, linkProps, {
    "aria-describedby": props['aria-describedby'] === null ? undefined : linkProps['aria-describedby']
  }), renderContent(props)));
};
var renderButton = function (props, ref) {
  var _a;
  var disableActions = Boolean(props.disabled || props.working);
  var passedInProps = tslib.__assign({
    'id': props.id,
    'disabled': props.disabled,
    'onClick': !disableActions ? props.onClick : undefined,
    'onMouseDown': !disableActions ? props.onMouseDown : undefined,
    'type': props.type,
    'onFocus': props.onFocus,
    'onBlur': props.onBlur,
    'form': props.form,
    'formAction': props.formAction,
    'formMethod': props.formMethod,
    'formEncType': props.formEncType,
    'formTarget': props.formTarget,
    'formNoValidate': props.formNoValidate,
    'className': buttonClass(props),
    'aria-label': generateAriaLabel(props),
    'aria-disabled': props.disabled || props.working ? true : undefined,
    'tabIndex': props.disableTabFocusAndIUnderstandTheAccessibilityImplications ? -1 : undefined
  }, getCustomProps(props));
  // @ts-expect-error we're using useFocusable instead of useButton because at this stage we want to hook only to focusable.
  // Not standardize button behavior as we're currently relying on some weird native behaviours (like onClick firing on enter key press) see https://react-spectrum.adobe.com/blog/building-a-button-part-1.html
  var focusableProps = reactAria.useFocusable(passedInProps, ref).focusableProps;
  return (
    // eslint-disable-next-line react/button-has-type
    React__default.default.createElement("button", tslib.__assign({}, passedInProps, focusableProps, {
      "aria-describedby": props['aria-describedby'] === null ? undefined : (_a = props['aria-describedby']) !== null && _a !== void 0 ? _a : focusableProps['aria-describedby'],
      // Unset this because the one defined in buttonProps shows
      // focus-visible styles on click
      onPointerDown: undefined,
      ref: ref
    }), renderContent(props))
  );
};
var renderLink = function (props, ref) {
  var _a;
  var target = props.newTabAndIUnderstandTheAccessibilityImplications ? '_blank' : '_self';
  var passedInProps = tslib.__assign({
    'id': props.id,
    'href': props.href,
    target: target,
    'rel': target === '_blank' ? 'noopener noreferrer' : undefined,
    'className': buttonClass(props),
    'onClick': props.onClick,
    'onFocus': props.onFocus,
    'onBlur': props.onBlur,
    'aria-label': generateAriaLabel(props)
  }, getCustomProps(props));
  // @ts-expect-error we're using useFocusable instead of useLink because at this stage we want to hook only to focusable.
  // Not standardize button behavior as we're currently relying on some weird native behaviours (like onClick firing on enter key press) see https://react-spectrum.adobe.com/blog/building-a-button-part-1.html
  var focusableProps = reactAria.useFocusable(passedInProps, ref).focusableProps;
  return React__default.default.createElement("a", tslib.__assign({}, passedInProps, focusableProps, {
    "aria-describedby": props['aria-describedby'] === null ? undefined : (_a = props['aria-describedby']) !== null && _a !== void 0 ? _a : focusableProps['aria-describedby'],
    // Unset this because the one defined in linkProps shows
    // focus-visible styles on click
    onPointerDown: undefined,
    ref: ref
  }), renderContent(props));
};
var buttonClass = function (props) {
  var isDefault = !props.primary && !props.destructive && !props.secondary;
  return classnames__default.default(GenericButton_module.button, isDefault && GenericButton_module.default,
  // @ts-expect-error aria-disabled exists in props
  Boolean(props.disabled || props['aria-disabled']) && GenericButton_module.disabled, props.primary && GenericButton_module.primary, props.destructive && GenericButton_module.destructive, props.secondary && GenericButton_module.secondary, props.size && GenericButton_module[props.size], props.reversed && GenericButton_module.reversed, props.iconButton && GenericButton_module.iconButton, props.working && GenericButton_module.working, Boolean(props.directionalLink || props.paginationLink) && GenericButton_module.circleButton, props.directionalLink && GenericButton_module.directionalLink, props.paginationLink && GenericButton_module.paginationLink, props.isActive && GenericButton_module.isPaginationLinkActive, props.classNameOverride);
};
var renderLoadingSpinner = function () {
  return React__default.default.createElement("div", {
    className: GenericButton_module.loadingSpinner
  }, React__default.default.createElement(LoadingSpinner.LoadingSpinner, {
    accessibilityLabel: "",
    size: "sm"
  }));
};
var renderWorkingContent = function (props) {
  if (props.workingLabelHidden) {
    return React__default.default.createElement(React__default.default.Fragment, null, React__default.default.createElement("span", {
      className: GenericButton_module.hidden,
      "aria-hidden": "true"
    }, renderDefaultContent(props)), React__default.default.createElement("span", {
      className: GenericButton_module.centeredLoadingSpinner
    }, renderLoadingSpinner()));
  }
  return React__default.default.createElement(React__default.default.Fragment, null, props.iconPosition !== 'end' && renderLoadingSpinner(), React__default.default.createElement("span", {
    className: GenericButton_module.label
  }, props.workingLabel), props.additionalContent && React__default.default.createElement("span", {
    className: GenericButton_module.additionalContentWrapper
  }, props.additionalContent), props.iconPosition === 'end' && renderLoadingSpinner());
};
var renderDefaultContent = function (props) {
  return React__default.default.createElement(React__default.default.Fragment, null, props.icon && props.iconPosition !== 'end' && renderIcon(props.icon), (!props.icon || !props.iconButton) && React__default.default.createElement("span", {
    className: GenericButton_module.label
  }, props.label), props.additionalContent && React__default.default.createElement("span", {
    className: GenericButton_module.additionalContentWrapper
  }, props.additionalContent), renderBadge(props), props.icon && props.iconPosition === 'end' && renderIcon(props.icon));
};
var renderBadge = function (props) {
  if (!props.badge) return null;
  var _a = props.badge,
    text = _a.text,
    animateChange = _a.animateChange,
    reversed = _a.reversed,
    variant = _a.variant;
  if (animateChange) {
    return React__default.default.createElement(Badge.BadgeAnimated, {
      variant: variant,
      reversed: reversed
    }, text);
  }
  return React__default.default.createElement(Badge.Badge, {
    variant: variant,
    reversed: reversed
  }, text);
};
var renderContent = function (props) {
  return React__default.default.createElement("span", {
    className: GenericButton_module.content
  }, props.working ? renderWorkingContent(props) : renderDefaultContent(props));
};
var renderIcon = function (icon) {
  return React__default.default.createElement("span", {
    className: GenericButton_module.iconWrapper
  }, icon);
};
// We only want an aria-label in the case that the button has just an icon and no text
// This can happen when the button is working and workingLabelHidden is true,
// or when this is an IconButton
var generateAriaLabel = function (props) {
  if (props.working && props.workingLabelHidden) {
    return props.workingLabel;
  }
  if (props.iconButton) {
    return props.label;
  }
  return undefined;
};
exports.GenericButton = GenericButton;
