'use strict';

var tslib = require('tslib');
var React = require('react');
var i18nReactIntl = require('@cultureamp/i18n-react-intl');
var reactFocusOn = require('react-focus-on');
var CalendarSingle = require('../Calendar/CalendarSingle/CalendarSingle.cjs');
require('../Calendar/CalendarRange/CalendarRange.cjs');
var calculateDisabledDays = require('../Calendar/utils/calculateDisabledDays.cjs');
var formatDateAsNumeral = require('../Calendar/utils/formatDateAsNumeral.cjs');
var formatDateAsText = require('../Calendar/utils/formatDateAsText.cjs');
var isDisabledDate = require('../Calendar/utils/isDisabledDate.cjs');
var isInvalidDate = require('../Calendar/utils/isInvalidDate.cjs');
var isSelectingDayInCalendar = require('../Calendar/utils/isSelectingDayInCalendar.cjs');
var parseDateAsTextOrNumeral = require('../Calendar/utils/parseDateAsTextOrNumeral.cjs');
require('date-fns');
var setFocusInCalendar = require('../Calendar/utils/setFocusInCalendar.cjs');
var CalendarPopover = require('../Calendar/CalendarPopover/CalendarPopover.cjs');
var VisuallyHidden = require('../VisuallyHidden/VisuallyHidden.cjs');
var DateInputField = require('./subcomponents/DateInputField/DateInputField.cjs');
var getLocale = require('./utils/getLocale.cjs');
var validateDate = require('./utils/validateDate.cjs');
function _interopDefault(e) {
  return e && e.__esModule ? e : {
    default: e
  };
}
var React__default = /*#__PURE__*/_interopDefault(React);

/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3082061174/Date+Picker Guidance} |
 * {@link https://cultureamp.design/?path=/docs/components-date-controls-datepicker--docs Storybook}
 */
var DatePicker = function (_a) {
  var propsId = _a.id,
    propsButtonRef = _a.buttonRef,
    _b = _a.locale,
    propsLocale = _b === void 0 ? 'en-AU' : _b,
    disabledDates = _a.disabledDates,
    disabledDaysOfWeek = _a.disabledDaysOfWeek,
    disabledRange = _a.disabledRange,
    disabledBeforeAfter = _a.disabledBeforeAfter,
    disabledBefore = _a.disabledBefore,
    disabledAfter = _a.disabledAfter,
    weekStartsOn = _a.weekStartsOn,
    defaultMonth = _a.defaultMonth,
    selectedDay = _a.selectedDay,
    status = _a.status,
    validationMessage = _a.validationMessage,
    onInputClick = _a.onInputClick,
    onInputFocus = _a.onInputFocus,
    onInputChange = _a.onInputChange,
    onInputBlur = _a.onInputBlur,
    onButtonClick = _a.onButtonClick,
    onDayChange = _a.onDayChange,
    onValidate = _a.onValidate,
    restDateInputFieldProps = tslib.__rest(_a, ["id", "buttonRef", "locale", "disabledDates", "disabledDaysOfWeek", "disabledRange", "disabledBeforeAfter", "disabledBefore", "disabledAfter", "weekStartsOn", "defaultMonth", "selectedDay", "status", "validationMessage", "onInputClick", "onInputFocus", "onInputChange", "onInputBlur", "onButtonClick", "onDayChange", "onValidate"]);
  var formatMessage = i18nReactIntl.useIntl().formatMessage;
  var calendarLabelDesc = formatMessage({
    id: 'datePicker.calendarLabelDescription',
    defaultMessage: 'Select date from calendar for:',
    description: 'Label for the search input'
  });
  var reactId = React.useId();
  var id = propsId !== null && propsId !== void 0 ? propsId : reactId;
  var containerRef = React.useRef(null);
  var inputRef = React.useRef(null);
  var fallbackButtonRef = React.useRef(null);
  var buttonRef = propsButtonRef !== null && propsButtonRef !== void 0 ? propsButtonRef : fallbackButtonRef;
  var dateInputRefs = React.useRef({
    inputRef: inputRef,
    buttonRef: buttonRef
  });
  var _c = React.useState(''),
    inputValue = _c[0],
    setInputValue = _c[1];
  var _d = React.useState(false),
    isOpen = _d[0],
    setIsOpen = _d[1];
  var _e = React.useState(),
    lastTrigger = _e[0],
    setLastTrigger = _e[1];
  var _f = React.useState(),
    inbuiltStatus = _f[0],
    setInbuiltStatus = _f[1];
  var _g = React.useState(),
    inbuiltValidationMessage = _g[0],
    setInbuiltValidationMessage = _g[1];
  var shouldUseInbuiltValidation = onValidate === undefined;
  var locale = getLocale.getLocale(propsLocale);
  var disabledDays = calculateDisabledDays.calculateDisabledDays({
    disabledDates: disabledDates,
    disabledDaysOfWeek: disabledDaysOfWeek,
    disabledRange: disabledRange,
    disabledBeforeAfter: disabledBeforeAfter,
    disabledBefore: disabledBefore,
    disabledAfter: disabledAfter
  });
  var handleValidation = function (validationResponse) {
    if (shouldUseInbuiltValidation) {
      setInbuiltStatus(validationResponse.status);
      setInbuiltValidationMessage(validationResponse.validationMessage);
    } else {
      onValidate(validationResponse);
    }
  };
  var handleDayChange = function (date, newInputValue) {
    var _a = validateDate.validateDate({
        date: date,
        inputValue: newInputValue,
        disabledDays: disabledDays
      }),
      validationResponse = _a.validationResponse,
      newDate = _a.newDate;
    handleValidation(validationResponse);
    onDayChange(newDate);
  };
  var handleCalendarDayChange = function (date) {
    if (!isDisabledDate.isDisabledDate(date, disabledDays)) {
      var newInputValue = lastTrigger === 'calendarButton' ? formatDateAsText.formatDateAsText(date, disabledDays, locale) : formatDateAsNumeral.formatDateAsNumeral(date, locale);
      setInputValue(newInputValue);
      handleDayChange(date);
      setIsOpen(false);
    }
  };
  var handleInputClick = function (e) {
    setIsOpen(true);
    onInputClick === null || onInputClick === void 0 ? void 0 : onInputClick(e);
  };
  var handleInputFocus = function (e) {
    setLastTrigger('inputFocus');
    if (selectedDay) {
      var newInputValue = formatDateAsNumeral.formatDateAsNumeral(selectedDay, locale);
      setInputValue(newInputValue);
    }
    onInputFocus === null || onInputFocus === void 0 ? void 0 : onInputFocus(e);
  };
  var handleInputChange = function (e) {
    setInputValue(e.target.value);
    onInputChange === null || onInputChange === void 0 ? void 0 : onInputChange(e);
  };
  var handleInputBlur = function (e) {
    if (isSelectingDayInCalendar.isSelectingDayInCalendar(e.relatedTarget)) return;
    if (inputValue !== '') {
      var parsedDate = parseDateAsTextOrNumeral.parseDateAsTextOrNumeral(inputValue, locale);
      if (!isInvalidDate.isInvalidDate(parsedDate)) {
        setInputValue(formatDateAsText.formatDateAsText(parsedDate, disabledDays, locale));
      }
      handleDayChange(parsedDate, inputValue);
      onInputBlur === null || onInputBlur === void 0 ? void 0 : onInputBlur(e);
      return;
    }
    handleDayChange(undefined, inputValue);
    onInputBlur === null || onInputBlur === void 0 ? void 0 : onInputBlur(e);
  };
  var handleKeyDown = function (e) {
    if (e.key === 'Enter') {
      setIsOpen(false);
      var parsedDate = parseDateAsTextOrNumeral.parseDateAsTextOrNumeral(inputValue, locale);
      handleDayChange(parsedDate, e.currentTarget.value);
    }
    if (e.key === 'ArrowDown' || e.key === 'ArrowDown' && e.altKey === true) {
      e.preventDefault();
      setIsOpen(true);
      setLastTrigger('inputKeydown');
    }
  };
  var handleButtonClick = function (e) {
    setIsOpen(!isOpen);
    setLastTrigger('calendarButton');
    onButtonClick === null || onButtonClick === void 0 ? void 0 : onButtonClick(e);
  };
  var handleCalendarMount = function (calendarElement) {
    if (lastTrigger === 'inputFocus') return;
    setFocusInCalendar.setFocusInCalendar(calendarElement, selectedDay);
  };
  var handleReturnFocus = function () {
    var _a, _b;
    if (lastTrigger === 'inputKeydown' || lastTrigger === 'inputFocus') {
      return (_a = inputRef.current) === null || _a === void 0 ? void 0 : _a.focus();
    }
    (_b = buttonRef.current) === null || _b === void 0 ? void 0 : _b.focus();
  };
  React.useEffect(function () {
    if (selectedDay) {
      setInputValue(formatDateAsText.formatDateAsText(selectedDay, disabledDays, locale));
      var formattedDate = formatDateAsNumeral.formatDateAsNumeral(selectedDay, locale);
      var validationResponse = validateDate.validateDate({
        date: selectedDay,
        inputValue: formattedDate,
        disabledDays: disabledDays
      }).validationResponse;
      if (!validationResponse.isValidDate && !validationResponse.isEmpty) {
        handleValidation(validationResponse);
      }
    }
    // @todo: Fix if possible - avoiding breaking in eslint upgrade
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [selectedDay]);
  var calendarId = "".concat(id, "-calendar-dialog");
  return React__default.default.createElement(reactFocusOn.FocusOn, {
    scrollLock: false,
    returnFocus: false,
    onDeactivation: handleReturnFocus,
    onClickOutside: function () {
      return setIsOpen(false);
    },
    onEscapeKey: function () {
      return setIsOpen(false);
    },
    enabled: isOpen
  }, React__default.default.createElement("div", {
    ref: containerRef
  }, React__default.default.createElement(DateInputField.DateInputField, tslib.__assign({
    ref: dateInputRefs,
    id: id,
    role: "combobox",
    "aria-haspopup": "dialog",
    "aria-expanded": isOpen,
    "aria-controls": calendarId,
    value: inputValue,
    locale: locale,
    onButtonClick: handleButtonClick,
    onClick: handleInputClick,
    onFocus: handleInputFocus,
    onChange: handleInputChange,
    onBlur: handleInputBlur,
    onKeyDown: handleKeyDown,
    status: status !== undefined || !shouldUseInbuiltValidation ? status : inbuiltStatus,
    validationMessage: validationMessage !== undefined || !shouldUseInbuiltValidation ? validationMessage : inbuiltValidationMessage
  }, restDateInputFieldProps))), isOpen && React__default.default.createElement(CalendarPopover.CalendarPopover, {
    referenceElement: containerRef.current,
    "aria-labelledby": "".concat(id, "-calendar-label ").concat(id, "-input-label")
  }, React__default.default.createElement(React__default.default.Fragment, null, React__default.default.createElement(VisuallyHidden.VisuallyHidden, {
    id: "".concat(id, "-calendar-label")
  }, calendarLabelDesc), React__default.default.createElement(CalendarSingle.CalendarSingle, {
    id: calendarId,
    selected: selectedDay,
    defaultMonth: defaultMonth,
    weekStartsOn: weekStartsOn,
    disabled: disabledDays,
    locale: locale,
    onDayClick: handleCalendarDayChange,
    onMount: handleCalendarMount
  }))));
};
DatePicker.displayName = 'DatePicker';
exports.DatePicker = DatePicker;
