'use strict';

var tslib = require('tslib');
var React = require('react');
var classnames = require('classnames');
var locale = require('date-fns/locale');
var reactDayPicker = require('react-day-picker');
var reactFocusOn = require('react-focus-on');
require('../Calendar/CalendarSingle/CalendarSingle.cjs');
require('../Calendar/CalendarRange/CalendarRange.cjs');
var calculateDisabledDays = require('../Calendar/utils/calculateDisabledDays.cjs');
require('date-fns');
var isDisabledDate = require('../Calendar/utils/isDisabledDate.cjs');
var CalendarPopover = require('../Calendar/CalendarPopover/CalendarPopover.cjs');
var LegacyCalendarRange = require('../Calendar/LegacyCalendarRange/LegacyCalendarRange.cjs');
var Label = require('../Label/Label.cjs');
var VisuallyHidden = require('../VisuallyHidden/VisuallyHidden.cjs');
var Icon = require('../__next__/Icon/Icon.cjs');
var DateRangePicker_module = require('./DateRangePicker.module.scss.cjs');
function _interopDefault(e) {
  return e && e.__esModule ? e : {
    default: e
  };
}
var React__default = /*#__PURE__*/_interopDefault(React);
var classnames__default = /*#__PURE__*/_interopDefault(classnames);

/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3082094237/Date+Range+Picker Guidance} |
 * {@link https://cultureamp.design/storybook/?path=/docs/components-date-controls-daterangepicker--docs Storybook}
 */
var DateRangePicker = function (_a) {
  var _b;
  var propsId = _a.id,
    buttonRef = _a.buttonRef;
  _a.description; // not used
  var labelText = _a.labelText,
    _c = _a.isDisabled,
    isDisabled = _c === void 0 ? false : _c,
    classNameOverride = _a.classNameOverride,
    disabledDates = _a.disabledDates,
    disabledDaysOfWeek = _a.disabledDaysOfWeek,
    disabledRange = _a.disabledRange,
    disabledBeforeAfter = _a.disabledBeforeAfter,
    disabledBefore = _a.disabledBefore,
    disabledAfter = _a.disabledAfter,
    weekStartsOn = _a.weekStartsOn,
    defaultMonth = _a.defaultMonth,
    selectedDateRange = _a.selectedDateRange,
    value = _a.value,
    onChange = _a.onChange,
    inputProps = tslib.__rest(_a, ["id", "buttonRef", "description", "labelText", "isDisabled", "classNameOverride", "disabledDates", "disabledDaysOfWeek", "disabledRange", "disabledBeforeAfter", "disabledBefore", "disabledAfter", "weekStartsOn", "defaultMonth", "selectedDateRange", "value", "onChange"]);
  var fallbackRef = React.useRef(null);
  var ref = buttonRef !== null && buttonRef !== void 0 ? buttonRef : fallbackRef;
  var reactId = React.useId();
  var id = propsId !== null && propsId !== void 0 ? propsId : reactId;
  var containerRef = React.useRef(null);
  var _d = React.useState(false),
    isOpen = _d[0],
    setIsOpen = _d[1];
  var disabledDays = calculateDisabledDays.calculateDisabledDays({
    disabledDates: disabledDates,
    disabledDaysOfWeek: disabledDaysOfWeek,
    disabledRange: disabledRange,
    disabledBeforeAfter: disabledBeforeAfter,
    disabledBefore: disabledBefore,
    disabledAfter: disabledAfter
  });
  var handleOpenClose = function () {
    setIsOpen(!isOpen);
  };
  var handleReturnFocus = function () {
    if (ref.current) {
      ref.current.focus();
    }
  };
  var handleDayClick = function (day) {
    /** react-day-picker will fire events for disabled days by default.
     *  We're checking here if it includes the CSS Modules class for disabled
     *  on the modifier to then return early.
     * */
    if (isDisabledDate.isDisabledDate(day, disabledDays)) {
      return;
    }
    if (!selectedDateRange) return;
    /** If user has already selected range and then selects again, treat first
     * click as the start of the new range.
     *  */
    if (isSelectingFirstDay(selectedDateRange, day)) {
      onChange({
        from: day,
        to: undefined
      });
    } else {
      // Otherwise, treat click as the final selection.
      onChange({
        from: selectedDateRange.from,
        to: day
      });
      handleOpenClose();
    }
  };
  var isSelectingFirstDay = function (range, day) {
    var isBeforeFirstDay = !!range.from && reactDayPicker.isMatch(day, [{
      before: range.from
    }]);
    var isRangeSelected = !!range.from && !!range.to;
    return !range.from || isBeforeFirstDay || isRangeSelected;
  };
  return React__default.default.createElement("div", null, React__default.default.createElement("div", {
    ref: containerRef,
    className: classNameOverride
  }, React__default.default.createElement(Label.Label, {
    id: "".concat(id, "-input-label"),
    disabled: isDisabled,
    htmlFor: id,
    labelText: labelText
  }), React__default.default.createElement("button", tslib.__assign({
    type: "button",
    id: id,
    className: classnames__default.default(DateRangePicker_module.button, DateRangePicker_module.withStartIconAdornment, (_b = {}, _b[DateRangePicker_module.disabled] = isDisabled, _b)),
    disabled: isDisabled,
    ref: ref,
    onClick: handleOpenClose,
    "aria-label": (selectedDateRange === null || selectedDateRange === void 0 ? void 0 : selectedDateRange.from) ? "Change date: ".concat(value) : 'Choose date'
  }, inputProps), React__default.default.createElement("div", {
    className: DateRangePicker_module.startIconAdornment
  }, React__default.default.createElement(Icon.Icon, {
    name: "today",
    isPresentational: true,
    isFilled: true
  })), React__default.default.createElement("span", {
    className: DateRangePicker_module.value
  }, (selectedDateRange === null || selectedDateRange === void 0 ? void 0 : selectedDateRange.from) ? value : undefined))), isOpen && React__default.default.createElement(reactFocusOn.FocusOn, {
    scrollLock: false,
    onDeactivation: handleReturnFocus,
    onClickOutside: handleOpenClose,
    onEscapeKey: handleOpenClose,
    enabled: isOpen
  }, React__default.default.createElement(CalendarPopover.CalendarPopover, {
    referenceElement: containerRef.current,
    "aria-labelledby": "".concat(id, "-calendar-label ").concat(id, "-input-label")
  }, React__default.default.createElement(VisuallyHidden.VisuallyHidden, {
    id: "".concat(id, "-calendar-label")
  }, "Select dates from calendar for:"), React__default.default.createElement(LegacyCalendarRange.LegacyCalendarRange, {
    selectedRange: selectedDateRange,
    defaultMonth: defaultMonth,
    weekStartsOn: weekStartsOn,
    disabledDays: disabledDays,
    onDayChange: handleDayClick,
    locale: locale.enUS
  }))));
};
DateRangePicker.displayName = 'DateRangePicker';
exports.DateRangePicker = DateRangePicker;
