'use strict';

var tslib = require('tslib');
var React = require('react');
var FilterMultiSelect = require('../../../FilterMultiSelect/FilterMultiSelect.cjs');
require('../../../FilterMultiSelect/context/MenuTriggerProvider/MenuTriggerProvider.cjs');
require('../../../FilterMultiSelect/context/SelectionProvider/SelectionProvider.cjs');
var getSelectedOptionLabels = require('../../../FilterMultiSelect/utils/getSelectedOptionLabels.cjs');
var FilterBarContext = require('../../context/FilterBarContext.cjs');
var checkArraysMatch = require('../../utils/checkArraysMatch.cjs');
var FilterBarMultiSelect_module = require('./FilterBarMultiSelect.module.css.cjs');
function _interopDefault(e) {
  return e && e.__esModule ? e : {
    default: e
  };
}
var React__default = /*#__PURE__*/_interopDefault(React);
var convertSelectionToAConsumableFormat = function (value) {
  if (value === 'all') return 'all';
  var arrayOfValues = Array.from(value);
  return arrayOfValues.length > 0 ? Array.from(value) : undefined;
};
var convertConsumableFormatIntoSelection = function (value) {
  return new Set(value);
};
var FilterBarMultiSelect = function (_a) {
  var _b;
  var id = _a.id,
    propsItems = _a.items,
    children = _a.children,
    onSelectionChange = _a.onSelectionChange,
    props = tslib.__rest(_a, ["id", "items", "children", "onSelectionChange"]);
  var _c = FilterBarContext.useFilterBarContext(),
    getFilterState = _c.getFilterState,
    setFilterOpenState = _c.setFilterOpenState,
    updateValue = _c.updateValue,
    hideFilter = _c.hideFilter,
    focusId = _c.focusId,
    setFocus = _c.setFocus;
  var _d = React.useState(propsItems),
    items = _d[0],
    setItems = _d[1];
  var buttonRef = React.useRef(null);
  if (!id) throw Error('Missing `id` prop in FilterBarMultiSelect');
  var filterState = getFilterState(id);
  React.useEffect(function () {
    if (!checkArraysMatch.checkArraysMatch(items, propsItems)) {
      setItems(propsItems);
    }
    // We only want to run this effect when propsItems changes
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [propsItems]);
  React.useEffect(function () {
    if (Array.isArray(filterState.value)) {
      var itemValues_1 = items.map(function (_a) {
        var value = _a.value;
        return value;
      });
      var filteredValues = filterState.value.filter(function (value) {
        return itemValues_1.includes(value);
      });
      if (!checkArraysMatch.checkArraysMatch(filterState.value, filteredValues)) {
        updateValue(id, filteredValues);
      }
    }
    // We only want to run this effect when items changes
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [items]);
  React.useEffect(function () {
    var _a;
    if (focusId === id) {
      (_a = buttonRef.current) === null || _a === void 0 ? void 0 : _a.focus();
      setFocus(undefined);
    }
  }, [focusId, id, setFocus]);
  return React__default.default.createElement(FilterMultiSelect.FilterMultiSelect, tslib.__assign({
    label: filterState.name,
    // Convert the incoming FilterBar state to a Set (internal FilterMultiSelect state)
    selectedKeys: new Set((_b = filterState.value) !== null && _b !== void 0 ? _b : null),
    onSelectionChange: function (keys) {
      // Convert the internal FilterMultiSelect state (Set) to an Array for FilterBar state
      updateValue(id, convertSelectionToAConsumableFormat(keys));
      onSelectionChange === null || onSelectionChange === void 0 ? void 0 : onSelectionChange(keys);
    },
    items: items,
    isOpen: filterState.isOpen,
    onOpenChange: function (open) {
      return setFilterOpenState(id, open);
    },
    className: FilterBarMultiSelect_module.filterMultiSelect,
    trigger: function () {
      var triggerProps = {
        selectedOptionLabels: filterState.value ? getSelectedOptionLabels.getSelectedOptionLabels(convertConsumableFormatIntoSelection(filterState.value), items) : [],
        label: filterState.name
      };
      return filterState.isRemovable ? React__default.default.createElement(FilterMultiSelect.FilterMultiSelect.RemovableTrigger, tslib.__assign({}, triggerProps, {
        onRemove: function () {
          return hideFilter(id);
        },
        classNameOverride: FilterBarMultiSelect_module.triggerButton
      })) : React__default.default.createElement(FilterMultiSelect.FilterMultiSelect.TriggerButton, tslib.__assign({
        classNameOverride: FilterBarMultiSelect_module.triggerButton
      }, triggerProps));
    },
    triggerRef: buttonRef
  }, props), children);
};
FilterBarMultiSelect.displayName = 'FilterBar.MultiSelect';
exports.FilterBarMultiSelect = FilterBarMultiSelect;
