'use strict';

require('../../../Calendar/CalendarSingle/CalendarSingle.cjs');
require('../../../Calendar/CalendarRange/CalendarRange.cjs');
require('tslib');
var formatDateAsNumeral = require('../../../Calendar/utils/formatDateAsNumeral.cjs');
var formatDateAsText = require('../../../Calendar/utils/formatDateAsText.cjs');
var isDisabledDate = require('../../../Calendar/utils/isDisabledDate.cjs');
var isInvalidDate = require('../../../Calendar/utils/isInvalidDate.cjs');
var isSelectingDayInCalendar = require('../../../Calendar/utils/isSelectingDayInCalendar.cjs');
var parseDateFromNumeralFormatValue = require('../../../Calendar/utils/parseDateFromNumeralFormatValue.cjs');
var parseDateFromTextFormatValue = require('../../../Calendar/utils/parseDateFromTextFormatValue.cjs');
var useDateInputHandlers = function (_a) {
  var locale = _a.locale,
    disabledDays = _a.disabledDays,
    setInputValue = _a.setInputValue,
    onDateChange = _a.onDateChange,
    onDateSubmit = _a.onDateSubmit,
    onChange = _a.onChange,
    onFocus = _a.onFocus,
    onBlur = _a.onBlur,
    onKeyDown = _a.onKeyDown;
  var isValidDate = function (date) {
    return !isInvalidDate.isInvalidDate(date) && !isDisabledDate.isDisabledDate(date, disabledDays);
  };
  var handleChange = function (e) {
    setInputValue(e.currentTarget.value);
    onChange === null || onChange === void 0 ? void 0 : onChange(e);
  };
  var handleFocus = function (e) {
    var date = parseDateFromTextFormatValue.parseDateFromTextFormatValue(e.currentTarget.value, locale);
    if (!isInvalidDate.isInvalidDate(date)) {
      var newInputValue = formatDateAsNumeral.formatDateAsNumeral(date, locale);
      setInputValue(newInputValue);
    }
    onFocus === null || onFocus === void 0 ? void 0 : onFocus(e);
  };
  var handleBlur = function (e) {
    if (isSelectingDayInCalendar.isSelectingDayInCalendar(e.relatedTarget)) return;
    if (e.currentTarget.value === '') {
      onDateChange(undefined);
      onBlur === null || onBlur === void 0 ? void 0 : onBlur(e);
      return;
    }
    var date = parseDateFromNumeralFormatValue.parseDateFromNumeralFormatValue(e.currentTarget.value, locale);
    if (isValidDate(date)) {
      var newInputValue = formatDateAsText.formatDateAsText(date, disabledDays, locale);
      setInputValue(newInputValue);
    }
    onDateChange(date);
    onBlur === null || onBlur === void 0 ? void 0 : onBlur(e);
  };
  var handleKeyDown = function (e) {
    if (e.key === 'Enter') {
      e.preventDefault();
      var date = parseDateFromNumeralFormatValue.parseDateFromNumeralFormatValue(e.currentTarget.value, locale);
      onDateChange(date);
      onDateSubmit === null || onDateSubmit === void 0 ? void 0 : onDateSubmit(date);
    }
    onKeyDown === null || onKeyDown === void 0 ? void 0 : onKeyDown(e);
  };
  return {
    onChange: handleChange,
    onFocus: handleFocus,
    onBlur: handleBlur,
    onKeyDown: handleKeyDown
  };
};
exports.useDateInputHandlers = useDateInputHandlers;
