'use strict';

var tslib = require('tslib');
var React = require('react');
var classnames = require('classnames');
var Button = require('../Button/Button/Button.cjs');
require('../Button/IconButton/IconButton.cjs');
var Heading = require('../Heading/Heading.cjs');
var Text = require('../Text/Text.cjs');
var Tooltip = require('../Tooltip/Tooltip.cjs');
var useMediaQueries = require('../utils/useMediaQueries.cjs');
var GuidanceBlock_module = require('./GuidanceBlock.module.css.cjs');
var Icon = require('../__next__/Icon/Icon.cjs');
function _interopDefault(e) {
  return e && e.__esModule ? e : {
    default: e
  };
}
var React__default = /*#__PURE__*/_interopDefault(React);
var classnames__default = /*#__PURE__*/_interopDefault(classnames);
var WithTooltip = function (_a) {
  var tooltipProps = _a.tooltipProps,
    children = _a.children;
  return tooltipProps ? React__default.default.createElement(Tooltip.Tooltip, tslib.__assign({}, tooltipProps), children) : React__default.default.createElement(React__default.default.Fragment, null, children);
};
/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3082093807/Guidance+Block Guidance} |
 * {@link https://cultureamp.design/?path=/docs/components-guidanceblock--docs Storybook}
 */
var GuidanceBlock = function (_a) {
  var _b, _c, _d, _e, _f;
  var _g = _a.layout,
    layout = _g === void 0 ? 'default' : _g,
    _h = _a.variant,
    variant = _h === void 0 ? 'default' : _h,
    _j = _a.withActionButtonArrow,
    withActionButtonArrow = _j === void 0 ? true : _j,
    _k = _a.noMaxWidth,
    noMaxWidth = _k === void 0 ? false : _k,
    _l = _a.illustrationType,
    illustrationType = _l === void 0 ? 'spot' : _l,
    _m = _a.smallScreenTextAlignment,
    smallScreenTextAlignment = _m === void 0 ? 'center' : _m,
    actions = _a.actions,
    illustration = _a.illustration,
    secondaryDismiss = _a.secondaryDismiss,
    actionsSlot = _a.actionsSlot,
    restProps = tslib.__rest(_a, ["layout", "variant", "withActionButtonArrow", "noMaxWidth", "illustrationType", "smallScreenTextAlignment", "actions", "illustration", "secondaryDismiss", "actionsSlot"]);
  var _o = React.useState(false),
    hidden = _o[0],
    setHidden = _o[1];
  var _p = React.useState(false),
    removed = _p[0],
    setRemoved = _p[1];
  var queries = useMediaQueries.useMediaQueries().queries;
  var containerRef = React__default.default.createRef();
  var handleDismissBanner = function () {
    var _a;
    setHidden(true);
    (_a = actions === null || actions === void 0 ? void 0 : actions.dismiss) === null || _a === void 0 ? void 0 : _a.onClick();
  };
  var onTransitionEnd = function (e) {
    // Be careful: this assumes the final CSS property to be animated is "margin-top".
    if (hidden && e.propertyName === 'margin-top') {
      setRemoved(true);
    }
  };
  var marginTop = function () {
    if (hidden && containerRef.current) {
      return -containerRef.current.clientHeight + 'px';
    }
    return '0';
  };
  if (removed) {
    return React__default.default.createElement(React__default.default.Fragment, null);
  }
  return React__default.default.createElement("div", {
    className: classnames__default.default(GuidanceBlock_module.banner, variant && GuidanceBlock_module[variant], layout && GuidanceBlock_module[layout], hidden && GuidanceBlock_module.hidden, queries.isSmall && GuidanceBlock_module.centerContent, noMaxWidth && GuidanceBlock_module.noMaxWidth, illustrationType === 'scene' && GuidanceBlock_module.hasSceneIllustration, smallScreenTextAlignment === 'left' && GuidanceBlock_module.smallScreenTextAlignment),
    style: {
      marginTop: marginTop()
    },
    ref: containerRef,
    onTransitionEnd: onTransitionEnd
  }, React__default.default.createElement("div", {
    className: GuidanceBlock_module.illustrationWrapper
  }, React__default.default.createElement("div", {
    className: GuidanceBlock_module.illustration
  }, illustrationType === 'scene' ? React__default.default.cloneElement(illustration, {
    enableAspectRatio: true
  }) : illustration)), React__default.default.createElement("div", {
    className: GuidanceBlock_module.descriptionAndActions
  }, React__default.default.createElement("div", {
    className: GuidanceBlock_module.descriptionContainer
  }, 'content' in restProps && restProps.content, 'text' in restProps && React__default.default.createElement(React__default.default.Fragment, null, React__default.default.createElement("div", {
    className: GuidanceBlock_module.headingWrapper
  }, React__default.default.createElement(Heading.Heading, {
    tag: (_c = (_b = restProps === null || restProps === void 0 ? void 0 : restProps.text) === null || _b === void 0 ? void 0 : _b.titleTag) !== null && _c !== void 0 ? _c : 'h3',
    variant: "heading-3"
  }, (_d = restProps === null || restProps === void 0 ? void 0 : restProps.text) === null || _d === void 0 ? void 0 : _d.title)), React__default.default.createElement(Text.Text, {
    tag: "p",
    variant: "body"
  }, (_e = restProps === null || restProps === void 0 ? void 0 : restProps.text) === null || _e === void 0 ? void 0 : _e.description))), (actions === null || actions === void 0 ? void 0 : actions.primary) || actionsSlot ? React__default.default.createElement("div", {
    className: GuidanceBlock_module.buttonContainer
  }, (actions === null || actions === void 0 ? void 0 : actions.primary) && React__default.default.createElement(React__default.default.Fragment, null, React__default.default.createElement(WithTooltip, {
    tooltipProps: actions.primary.tooltip
  }, React__default.default.createElement(Button.Button, tslib.__assign({
    icon: withActionButtonArrow ? React__default.default.createElement(Icon.Icon, {
      name: "arrow_forward",
      isPresentational: true,
      shouldMirrorInRTL: true
    }) : undefined,
    iconPosition: "end"
  }, actions.primary, {
    fullWidth: queries.isSmall
  }))), (actions === null || actions === void 0 ? void 0 : actions.secondary) && React__default.default.createElement(WithTooltip, {
    tooltipProps: actions.secondary.tooltip
  }, React__default.default.createElement("div", {
    className: GuidanceBlock_module.secondaryAction
  }, React__default.default.createElement(Button.Button, tslib.__assign({
    secondary: true
  }, actions.secondary, {
    onClick: secondaryDismiss ? function () {
      return handleDismissBanner();
    } : (_f = actions === null || actions === void 0 ? void 0 : actions.secondary) === null || _f === void 0 ? void 0 : _f.onClick,
    fullWidth: queries.isSmall
  }))))), !actions && actionsSlot && actionsSlot) : null));
};
GuidanceBlock.displayName = 'GuidanceBlock';
exports.GuidanceBlock = GuidanceBlock;
