'use strict';

var React = require('react');
var classnames = require('classnames');
require('../../../Button/Button/Button.cjs');
var IconButton = require('../../../Button/IconButton/IconButton.cjs');
var hostedAssets = require('../../../utils/hostedAssets.cjs');
var canPlayWebm = require('../../utils/canPlayWebm.cjs');
var usePausePlay = require('../../utils/usePausePlay.cjs');
var Base_module = require('../Base/Base.module.scss.cjs');
function _interopDefault(e) {
  return e && e.__esModule ? e : {
    default: e
  };
}
var React__default = /*#__PURE__*/_interopDefault(React);
var classnames__default = /*#__PURE__*/_interopDefault(classnames);
var VideoPlayer = function (_a) {
  var _b = _a.autoplay,
    autoplay = _b === void 0 ? true : _b,
    _c = _a.loop,
    loop = _c === void 0 ? false : _c,
    fallback = _a.fallback,
    source = _a.source,
    aspectRatio = _a.aspectRatio,
    onEnded = _a.onEnded;
  var videoRef = React.useRef(null);
  var _d = React__default.default.useState(true),
    prefersReducedMotion = _d[0],
    setPrefersReducedMotion = _d[1];
  var _e = React__default.default.useState(false),
    isWebmCompatible = _e[0],
    setIsWebmCompatible = _e[1];
  var _f = React__default.default.useState(false),
    windowIsAvailable = _f[0],
    setWindowIsAvailable = _f[1];
  React.useEffect(function () {
    /**
     * Setting `muted` on the player is required in Safari/Webkit and older
     * versions of Chome for the video to autoplay (regardless of whether
     * the format contains an audio stream or not).
     *
     * React does not guarentee the `muted` attribute is set on the
     * `video` element. So on load we force set this attribute. See issue:
     * https://github.com/facebook/react/issues/10389
     */
    var videoElement = videoRef.current;
    if (videoElement !== null) {
      videoElement.setAttribute('muted', '');
    }
  }, []);
  React.useEffect(function () {
    // when the source of the animation is updated, we need to reload the asset
    // to ensure the video player is in sync with the new source.
    var videoElement = videoRef.current;
    if (videoElement !== null) {
      videoElement.load();
    }
  }, [source]);
  React.useEffect(function () {
    if (!window) return;
    var reducedMotionQuery = window.matchMedia('(prefers-reduced-motion: reduce)');
    setPrefersReducedMotion(reducedMotionQuery.matches);
    var updateMotionPreferences = function () {
      var _a = window.matchMedia('(prefers-reduced-motion: reduce)').matches,
        matches = _a === void 0 ? false : _a;
      setPrefersReducedMotion(matches);
    };
    var isLegacyEdge = /Edge/.exec(navigator.userAgent);
    var isUnsupportedSafari = window.matchMedia('').addEventListener === undefined;
    if (isLegacyEdge || isUnsupportedSafari) return;
    reducedMotionQuery.addEventListener('change', updateMotionPreferences, true);
    return function cleanup() {
      reducedMotionQuery.removeEventListener('change', updateMotionPreferences);
    };
  }, []);
  React.useEffect(function () {
    var _a;
    var videoElement = videoRef.current;
    if (!videoElement) return;
    if (prefersReducedMotion) {
      videoElement.pause();
    } else if (autoplay && !prefersReducedMotion) {
      try {
        // Older browsers may not return a promise, so .play could return undefined
        (_a = videoElement.play()) === null || _a === void 0 ? void 0 : _a.catch(function () {
          /*
           * An DOMException _may_ be raised by some browsers if we
           * programatically interact with the video before the
           * user has interacted with the page. This is okay - so
           * we're going to catch this error without handling it. See:
           * https://developer.mozilla.org/en-US/docs/Web/Media/Autoplay_guide#autoplay_availability
           */
        });
      } catch (_b) {
        /**
         * Older browsers will raise a synchronous error because their first implementation
         * of `.play` was not a promise.
         */
      }
    }
    /**
     * Chrome seems to have an issue with changes to autoplay after the video
     * has been mounted. If there is a change in autoplay we need to force the
     * play() method to be called.
     */
  }, [prefersReducedMotion, autoplay]);
  React.useEffect(function () {
    // Add event listeners for the video element
    var videoElement = videoRef.current;
    if (!videoElement || !onEnded) return;
    videoElement.addEventListener('ended', onEnded);
    return function cleanup() {
      videoElement.removeEventListener('ended', onEnded);
    };
  }, [onEnded, videoRef]);
  React.useEffect(function () {
    // SSR does not have a window, which is required for canPlayWebm.
    if (window !== undefined) setWindowIsAvailable(true);
  }, []);
  React.useEffect(function () {
    if (windowIsAvailable) setIsWebmCompatible(canPlayWebm.canPlayWebm());
  }, [windowIsAvailable]);
  var pausePlay = usePausePlay.usePausePlay(videoRef);
  return React__default.default.createElement("figure", {
    className: classnames__default.default(Base_module.figure, aspectRatio && Base_module[aspectRatio], aspectRatio && Base_module.aspectRatioWrapper)
  }, React__default.default.createElement("video", {
    muted: true,
    "aria-hidden": true,
    preload: "metadata",
    ref: videoRef,
    width: "100%",
    "data-testid": "kz-video-player",
    className: Base_module.wrapper,
    loop: loop,
    poster: hostedAssets.assetUrl("".concat(fallback, ".png")),
    autoPlay: prefersReducedMotion ? false : autoplay,
    playsInline: true,
    tabIndex: -1
  }, isWebmCompatible && React__default.default.createElement("source", {
    src: hostedAssets.assetUrl("".concat(source, ".webm")),
    type: "video/webm"
  }), React__default.default.createElement("source", {
    src: hostedAssets.assetUrl("".concat(source, ".mp4")),
    type: "video/mp4"
  })), React__default.default.createElement(IconButton.IconButton, {
    onClick: function () {
      return pausePlay.toggle();
    },
    icon: pausePlay.icon,
    label: pausePlay.label,
    classNameOverride: Base_module.pausePlayButton
  }));
};
exports.VideoPlayer = VideoPlayer;
