'use strict';

var React = require('react');
var classnames = require('classnames');
var FieldMessage = require('../FieldMessage/FieldMessage.cjs');
var Text = require('../Text/Text.cjs');
var Icon = require('../__next__/Icon/Icon.cjs');
var determineSelectionFromKeyPress = require('./utils/determineSelectionFromKeyPress.cjs');
var LikertScaleLegacy_module = require('./LikertScaleLegacy.module.scss.cjs');
function _interopDefault(e) {
  return e && e.__esModule ? e : {
    default: e
  };
}
var React__default = /*#__PURE__*/_interopDefault(React);
var classnames__default = /*#__PURE__*/_interopDefault(classnames);
var SelectedItemIcon = function () {
  return React__default.default.createElement(Icon.Icon, {
    name: "check",
    isPresentational: true,
    className: LikertScaleLegacy_module.check
  });
};
/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3082060201/Likert+Scale Guidance} |
 * {@link https://cultureamp.design/?path=/docs/components-likertscalelegacy--docs Storybook}
 */
var LikertScaleLegacy = function (_a) {
  var _b, _c;
  var scale = _a.scale,
    selectedItem = _a.selectedItem,
    reversed = _a.reversed,
    _d = _a.colorSchema,
    colorSchema = _d === void 0 ? 'classical' : _d,
    dataTestId = _a["data-testid"],
    onSelect = _a.onSelect,
    validationMessage = _a.validationMessage,
    status = _a.status,
    labelId = _a.labelId;
  var _e = React.useState(null),
    hoveredItem = _e[0],
    setHoveredItem = _e[1];
  var itemRefs = scale.map(function (s) {
    return {
      value: s.value,
      ref: React.createRef()
    };
  });
  var handleRadioClick = function (item) {
    var _a;
    // Is this a click on the item that is currently selected?
    var isClickOnSelectedItem = (selectedItem === null || selectedItem === void 0 ? void 0 : selectedItem.value) === item.value;
    // Grab "Not rated" state item from the scale, its value is -1
    var notYetRated = (_a = scale.find(function (s) {
      return s.value === -1;
    })) !== null && _a !== void 0 ? _a : null;
    // Clear or set new selection
    var newItem = isClickOnSelectedItem ? notYetRated : item;
    onSelect(newItem);
    setHoveredItem(null);
  };
  /**
   * Because the radios have been built with divs, we need to add the keyboard functionality manually
   */
  var handleKeyDown = function (event, focusedItem) {
    var _a, _b, _c;
    var newPosition = determineSelectionFromKeyPress(event.keyCode, selectedItem, focusedItem);
    if (newPosition) {
      event.preventDefault();
      onSelect((_a = scale.find(function (s) {
        return s.value === newPosition;
      })) !== null && _a !== void 0 ? _a : null);
      // Update focus
      var itemRef = itemRefs.find(function (item) {
        return item.value === newPosition;
      });
      (_c = (_b = itemRef === null || itemRef === void 0 ? void 0 : itemRef.ref) === null || _b === void 0 ? void 0 : _b.current) === null || _c === void 0 ? void 0 : _c.focus();
    }
  };
  var legend = (_c = (_b = hoveredItem === null || hoveredItem === void 0 ? void 0 : hoveredItem.label) !== null && _b !== void 0 ? _b : selectedItem === null || selectedItem === void 0 ? void 0 : selectedItem.label) !== null && _c !== void 0 ? _c : 'Not rated';
  var shouldDisplayValidationMessage = status !== 'default' && validationMessage !== undefined;
  var validationMessageId = shouldDisplayValidationMessage ? "".concat(labelId, "-field-validation-message") : undefined;
  var isRated = selectedItem && selectedItem.value > 0;
  return React__default.default.createElement("div", {
    className: classnames__default.default(LikertScaleLegacy_module.container, isRated && LikertScaleLegacy_module.rated, reversed && [LikertScaleLegacy_module.reversed], hoveredItem !== null && LikertScaleLegacy_module.hovered),
    "aria-labelledby": labelId,
    role: "radiogroup",
    tabIndex: -1,
    "aria-describedby": validationMessageId,
    "data-testid": dataTestId
  }, React__default.default.createElement("div", {
    className: LikertScaleLegacy_module.legend,
    "data-testid": dataTestId && "".concat(dataTestId, "-legend")
  }, React__default.default.createElement(Text.Text, {
    variant: "small",
    color: reversed ? 'white' : 'dark'
  }, legend)), React__default.default.createElement("div", {
    className: classnames__default.default(LikertScaleLegacy_module.itemContainer, isRated && LikertScaleLegacy_module.rated, reversed && LikertScaleLegacy_module.reversed)
  }, scale.map(function (item) {
    if (item.value <= 0) {
      return;
    }
    var isSelectedItem = (selectedItem === null || selectedItem === void 0 ? void 0 : selectedItem.value) === item.value;
    var itemRef = itemRefs.find(function (i) {
      return item.value === i.value;
    });
    // Make control tabbable
    var tabIndex = 0;
    // Unless.. there's an item selected and it's not this one
    if (selectedItem && selectedItem.value > 0 && selectedItem.value !== item.value) {
      tabIndex = -1;
    }
    var isSelected = selectedItem && item.value <= (selectedItem === null || selectedItem === void 0 ? void 0 : selectedItem.value) && !hoveredItem;
    var isSuggested = hoveredItem && hoveredItem.value >= item.value;
    var isUnselected = selectedItem && selectedItem.value < item.value;
    return React__default.default.createElement("div", {
      className: classnames__default.default(LikertScaleLegacy_module.likertItem, colorSchema == 'blue' ? LikertScaleLegacy_module.blueColorSchema : LikertScaleLegacy_module.classicalColorSchema, LikertScaleLegacy_module["likertItem".concat(item.value)], isSelected && LikertScaleLegacy_module.selected, isSuggested && LikertScaleLegacy_module.suggested, isUnselected && LikertScaleLegacy_module.unselected),
      key: item.value,
      "data-testid": dataTestId && "".concat(dataTestId, "-item-").concat(item.value),
      onClick: function () {
        return handleRadioClick(item);
      },
      onMouseEnter: function () {
        return setHoveredItem(item);
      },
      onMouseLeave: function () {
        return setHoveredItem(null);
      },
      onKeyDown: function (event) {
        return handleKeyDown(event, item);
      },
      onFocus: function () {
        return setHoveredItem(item);
      },
      onBlur: function () {
        return setHoveredItem(null);
      },
      role: "radio",
      "aria-label": item.label,
      "aria-checked": isSelectedItem,
      "aria-posinset": item.value,
      "aria-setsize": 5,
      tabIndex: tabIndex,
      ref: itemRef === null || itemRef === void 0 ? void 0 : itemRef.ref
    }, React__default.default.createElement("div", {
      className: classnames__default.default(LikertScaleLegacy_module.likertItemFill, LikertScaleLegacy_module["field".concat(item.value)], isSelectedItem && LikertScaleLegacy_module.pop)
    }), isSelectedItem ? React__default.default.createElement(SelectedItemIcon, null) : null);
  })), shouldDisplayValidationMessage && React__default.default.createElement(FieldMessage.FieldMessage, {
    id: validationMessageId,
    message: validationMessage,
    status: status,
    reversed: reversed
  }));
};
exports.LikertScaleLegacy = LikertScaleLegacy;
