'use strict';

var tslib = require('tslib');
var React = require('react');
var classnames = require('classnames');
var Heading = require('../../Heading/Heading.cjs');
var GenericModal = require('../GenericModal/GenericModal.cjs');
require('../GenericModal/context/ModalContext.cjs');
require('../GenericModal/subcomponents/ModalAccessibleDescription/ModalAccessibleDescription.cjs');
var ModalFooter = require('../GenericModal/subcomponents/ModalFooter/ModalFooter.cjs');
var ModalHeader = require('../GenericModal/subcomponents/ModalHeader/ModalHeader.cjs');
var ModalAccessibleLabel = require('../GenericModal/subcomponents/ModalAccessibleLabel/ModalAccessibleLabel.cjs');
var ModalBody = require('../GenericModal/subcomponents/ModalBody/ModalBody.cjs');
var InputEditModal_module = require('./InputEditModal.module.scss.cjs');
function _interopDefault(e) {
  return e && e.__esModule ? e : {
    default: e
  };
}
var React__default = /*#__PURE__*/_interopDefault(React);
var classnames__default = /*#__PURE__*/_interopDefault(classnames);

/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3082093114/Modal#Input-Edit-Modal Guidance} |
 * {@link https://cultureamp.design/?path=/docs/components-modals-inputeditmodal--docs Storybook}
 */
var InputEditModal = function (_a) {
  var isOpen = _a.isOpen,
    mood = _a.mood,
    title = _a.title,
    onSubmit = _a.onSubmit,
    onSecondaryAction = _a.onSecondaryAction,
    onAfterLeave = _a.onAfterLeave,
    _b = _a.submitLabel,
    submitLabel = _b === void 0 ? 'Submit' : _b,
    _c = _a.dismissLabel,
    dismissLabel = _c === void 0 ? 'Cancel' : _c,
    secondaryLabel = _a.secondaryLabel,
    submitWorking = _a.submitWorking,
    children = _a.children,
    _d = _a.unpadded,
    unpadded = _d === void 0 ? false : _d,
    propsOnDismiss = _a.onDismiss,
    onAfterEnter = _a.onAfterEnter,
    className = _a.className,
    props = tslib.__rest(_a, ["isOpen", "mood", "title", "onSubmit", "onSecondaryAction", "onAfterLeave", "submitLabel", "dismissLabel", "secondaryLabel", "submitWorking", "children", "unpadded", "onDismiss", "onAfterEnter", "className"]);
  var onDismiss = submitWorking ? undefined : propsOnDismiss;
  var submitAction = {
    label: submitLabel,
    onClick: onSubmit
  };
  var workingProps = submitWorking ? {
    working: true,
    workingLabel: submitWorking.label,
    workingLabelHidden: submitWorking.labelHidden
  } : {};
  var showSecondary = onSecondaryAction && secondaryLabel;
  var footerActions = [tslib.__assign(tslib.__assign({}, submitAction), workingProps), {
    label: showSecondary ? secondaryLabel : dismissLabel,
    onClick: showSecondary ? onSecondaryAction : onDismiss,
    disabled: !!submitWorking
  }];
  return React__default.default.createElement(GenericModal.GenericModal, {
    isOpen: isOpen,
    onEscapeKeyup: onDismiss,
    onAfterLeave: onAfterLeave,
    onAfterEnter: onAfterEnter,
    className: className
  }, React__default.default.createElement("div", tslib.__assign({
    className: InputEditModal_module.modal,
    "data-modal": true
  }, props), React__default.default.createElement(ModalHeader.ModalHeader, {
    onDismiss: onDismiss
  }, React__default.default.createElement("div", {
    className: classnames__default.default(InputEditModal_module.header, !unpadded && InputEditModal_module.padded)
  }, React__default.default.createElement(ModalAccessibleLabel.ModalAccessibleLabel, null, React__default.default.createElement(Heading.Heading, {
    tag: "h2",
    variant: "heading-2"
  }, title)))), React__default.default.createElement(ModalBody.ModalBody, null, React__default.default.createElement("div", {
    className: classnames__default.default(InputEditModal_module.body, !unpadded && InputEditModal_module.padded)
  }, children)), React__default.default.createElement(ModalFooter.ModalFooter, {
    actions: footerActions,
    appearance: mood === 'destructive' ? 'destructive' : 'primary',
    variant: "inputEdit",
    unpadded: unpadded
  })));
};
InputEditModal.displayName = 'InputEditModal';
exports.InputEditModal = InputEditModal;
