'use strict';

var tslib = require('tslib');
var React = require('react');
var classnames = require('classnames');
var reactPopper = require('react-popper');
var Heading = require('../Heading/Heading.cjs');
var Text = require('../Text/Text.cjs');
var Icon = require('../__next__/Icon/Icon.cjs');
var classMappers = require('./utils/classMappers.cjs');
var Popover_module = require('./Popover.module.scss.cjs');
function _interopDefault(e) {
  return e && e.__esModule ? e : {
    default: e
  };
}
var React__default = /*#__PURE__*/_interopDefault(React);
var classnames__default = /*#__PURE__*/_interopDefault(classnames);

// Sync with styles.scss
var arrowWidth = 14;
var arrowHeight = 7;
/**
 * {@link https://cultureamp.design/components/popover/ Guidance} |
 * {@link https://cultureamp.design/storybook/?path=/docs/components-popover--default-kaizen-site-demo Storybook}
 */
var Popover = function (_a) {
  var children = _a.children,
    _b = _a.variant,
    variant = _b === void 0 ? 'default' : _b,
    _c = _a.placement,
    placement = _c === void 0 ? 'top' : _c,
    _d = _a.size,
    size = _d === void 0 ? 'small' : _d,
    heading = _a.heading,
    _e = _a.dismissible,
    dismissible = _e === void 0 ? false : _e,
    onClose = _a.onClose,
    _f = _a.singleLine,
    singleLine = _f === void 0 ? false : _f,
    customIcon = _a.customIcon,
    referenceElement = _a.referenceElement,
    classNameOverride = _a.classNameOverride,
    restProps = tslib.__rest(_a, ["children", "variant", "placement", "size", "heading", "dismissible", "onClose", "singleLine", "customIcon", "referenceElement", "classNameOverride"]);
  var _g = React.useState(null),
    popperElement = _g[0],
    setPopperElement = _g[1];
  var _h = React.useState(null),
    arrowElement = _h[0],
    setArrowElement = _h[1];
  var _j = reactPopper.usePopper(referenceElement, popperElement, {
      modifiers: [{
        name: 'arrow',
        options: {
          element: arrowElement,
          // Ensures that the arrow doesn't go too far to the left or right
          // of the tooltip.
          padding: arrowWidth / 2 + 10
        }
      }, {
        name: 'offset',
        options: {
          offset: [0, arrowHeight + 6]
        }
      }, {
        name: 'preventOverflow',
        options: {
          // Makes sure that the popover isn't flush up against the end of the
          // viewport
          padding: 8,
          altAxis: true,
          altBoundary: true,
          tetherOffset: 50
        }
      }, {
        name: 'flip',
        options: {
          padding: 8,
          altBoundary: true,
          fallbackPlacements: ['left', 'top', 'bottom', 'right']
        }
      }],
      placement: placement
    }),
    popperStyles = _j.styles,
    attributes = _j.attributes;
  return React__default.default.createElement("div", tslib.__assign({
    ref: setPopperElement,
    style: popperStyles.popper
  }, attributes.popper, {
    className: classnames__default.default(Popover_module.root, classMappers.mapSizeToClass(size), classNameOverride)
  }, restProps), React__default.default.createElement("div", {
    className: classMappers.mapVariantToBoxClass(variant)
  }, heading && React__default.default.createElement("div", {
    className: Popover_module.header
  }, variant !== 'default' && React__default.default.createElement("span", {
    className: classnames__default.default(Popover_module.icon, classMappers.mapVariantToIconClass(variant))
  }, customIcon !== null && customIcon !== void 0 ? customIcon : classMappers.mapVariantToIcon(variant)), React__default.default.createElement(Heading.Heading, {
    variant: "heading-6",
    classNameOverride: Popover_module.singleLine
  }, heading), dismissible && React__default.default.createElement("button", {
    className: Popover_module.close,
    onClick: onClose,
    type: "button",
    "aria-label": "close"
  }, React__default.default.createElement(Icon.Icon, {
    name: "close",
    isPresentational: true,
    isFilled: true
  }))), React__default.default.createElement(Text.Text, {
    tag: "div",
    variant: "small",
    classNameOverride: classnames__default.default(Popover_module.container, classMappers.mapLineVariant(singleLine))
  }, children)), React__default.default.createElement("div", {
    ref: setArrowElement,
    style: popperStyles.arrow,
    className: Popover_module.arrowWrapper
  }, React__default.default.createElement("div", {
    className: classnames__default.default(Popover_module.arrow, classMappers.mapArrowVariantToClass(variant))
  })));
};
Popover.displayName = 'Popover';
/**
 * How to use:
 *
 * const [referenceElementRef, Popover] = usePopover()
 *
 * return (<>
 *   <button ref={referenceElementRef}>
 *     Hello world
 *   </button>
 *   <Popover>Hello world</Popover>
 * </>)
 *
 * The purpose of this hook is to abstract away some of the awkwardness with the
 * requirement of passing in refs with popper. We need to use `useState` instead
 * of `useRef`, which may not be immediately intuitive.
 *
 * The popper documentation to help provide more context:
 *   https://popper.js.org/react-popper/v2/hook/
 */
var usePopover = function () {
  var _a = React.useState(null),
    referenceElement = _a[0],
    setReferenceElement = _a[1];
  // I guess the problem with this pattern, is that every time referenceElement
  // changes, a brand new component is generated, which would be bad for memoization.
  // In this situation however, the value is rarely going to change, and
  // popovers aren't going to include content with expensive render times.
  var PopoverWithRef = React.useMemo(
  // eslint-disable-next-line react/display-name
  function () {
    return function (props) {
      return referenceElement ? React__default.default.createElement(Popover, tslib.__assign({}, props, {
        referenceElement: referenceElement
      })) : null;
    };
  }, [referenceElement]);
  return [setReferenceElement, PopoverWithRef];
};
exports.Popover = Popover;
exports.usePopover = usePopover;
