'use strict';

var tslib = require('tslib');
var React = require('react');
var classnames = require('classnames');
var FieldMessage = require('../../FieldMessage/FieldMessage.cjs');
var Label = require('../../Label/Label.cjs');
var InlineNotification = require('../../Notification/InlineNotification/InlineNotification.cjs');
require('../../Notification/GlobalNotification/GlobalNotification.cjs');
require('../../Notification/ToastNotification/ToastNotification/ToastNotification.cjs');
require('../../Notification/ToastNotification/ToastNotificationsList/ToastNotificationsList.cjs');
require('../../Notification/ToastNotification/context/ToastNotificationContext.cjs');
var ProseMirrorState = require('prosemirror-state');
require('prosemirror-view');
var useRichTextEditor = require('../utils/core/hooks/useRichTextEditor.cjs');
var ProseMirrorModel = require('prosemirror-model');
require('prosemirror-inputrules');
var LinkManager = require('../utils/plugins/LinkManager/LinkManager.cjs');
require('../utils/plugins/LinkManager/components/LinkEditor/LinkEditor.cjs');
require('../utils/plugins/LinkManager/components/LinkModal/LinkModal.cjs');
require('../utils/plugins/LinkManager/components/LinkPopover/LinkPopover.cjs');
var ProseMirrorCommands = require('prosemirror-commands');
var ProseMirrorKeymap = require('prosemirror-keymap');
var ProseMirrorHistory = require('prosemirror-history');
require('prosemirror-schema-list');
var schema = require('./schema.cjs');
var ToggleIconButton = require('./subcomponents/ToggleIconButton/ToggleIconButton.cjs');
var Toolbar = require('./subcomponents/Toolbar/Toolbar.cjs');
var ToolbarSection = require('./subcomponents/ToolbarSection/ToolbarSection.cjs');
var controlmap = require('./utils/controlmap.cjs');
var inputrules = require('./utils/inputrules.cjs');
var keymap = require('./utils/keymap.cjs');
var RichTextEditor_module = require('./RichTextEditor.module.scss.cjs');
function _interopDefault(e) {
  return e && e.__esModule ? e : {
    default: e
  };
}
function _interopNamespace(e) {
  if (e && e.__esModule) return e;
  var n = Object.create(null);
  if (e) {
    Object.keys(e).forEach(function (k) {
      if (k !== 'default') {
        var d = Object.getOwnPropertyDescriptor(e, k);
        Object.defineProperty(n, k, d.get ? d : {
          enumerable: true,
          get: function () {
            return e[k];
          }
        });
      }
    });
  }
  n.default = e;
  return Object.freeze(n);
}
var React__default = /*#__PURE__*/_interopDefault(React);
var classnames__default = /*#__PURE__*/_interopDefault(classnames);
var ProseMirrorState__namespace = /*#__PURE__*/_interopNamespace(ProseMirrorState);
var ProseMirrorModel__namespace = /*#__PURE__*/_interopNamespace(ProseMirrorModel);
var ProseMirrorCommands__namespace = /*#__PURE__*/_interopNamespace(ProseMirrorCommands);
var ProseMirrorKeymap__namespace = /*#__PURE__*/_interopNamespace(ProseMirrorKeymap);
var ProseMirrorHistory__namespace = /*#__PURE__*/_interopNamespace(ProseMirrorHistory);

/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3081896752/Rich+Text+Editor Guidance} |
 * {@link https://cultureamp.design/?path=/docs/components-richtexteditor--docs Storybook}
 */
var RichTextEditor = function (_a) {
  var id = _a.id,
    onChange = _a.onChange,
    defaultValue = _a.defaultValue,
    labelText = _a.labelText,
    labelledBy = _a["aria-labelledby"],
    describedBy = _a["aria-describedby"],
    classNameOverride = _a.classNameOverride,
    controls = _a.controls,
    _b = _a.rows,
    rows = _b === void 0 ? 3 : _b,
    dataError = _a.dataError,
    onDataError = _a.onDataError,
    validationMessage = _a.validationMessage,
    description = _a.description,
    _c = _a.status,
    status = _c === void 0 ? 'default' : _c,
    restProps = tslib.__rest(_a, ["id", "onChange", "defaultValue", "labelText", 'aria-labelledby', 'aria-describedby', "classNameOverride", "controls", "rows", "dataError", "onDataError", "validationMessage", "description", "status"]);
  var generatedId = React.useId();
  var schema$1 = React.useState(schema.createSchemaFromControls(controls))[0];
  var editorId = id !== null && id !== void 0 ? id : generatedId;
  var labelId = labelledBy !== null && labelledBy !== void 0 ? labelledBy : "".concat(editorId, "-rte-label");
  var validationMessageAria = validationMessage ? "".concat(editorId, "-rte-validation-message") : '';
  var descriptionAria = description ? "".concat(editorId, "-rte-description") : '';
  var ariaDescribedBy = classnames__default.default(validationMessageAria, descriptionAria, describedBy);
  var useRichTextEditorResult = function () {
    try {
      // @todo: Fix if possible - avoiding breaking in eslint upgrade
      // eslint-disable-next-line react-hooks/rules-of-hooks
      return useRichTextEditor.useRichTextEditor(ProseMirrorState__namespace.EditorState.create({
        doc: ProseMirrorModel__namespace.Node.fromJSON(schema$1, {
          type: 'doc',
          // we're converting empty arrays to the ProseMirror default "empty" state because when
          // given an empty array ProseMirror returns undefined, breaking the type
          content: (defaultValue === null || defaultValue === void 0 ? void 0 : defaultValue.length) > 0 ? defaultValue : [{
            type: 'paragraph'
          }]
        }),
        schema: schema$1,
        plugins: getPlugins(controls, schema$1)
      }), {
        'aria-labelledby': labelId,
        'role': 'textbox',
        'aria-describedby': ariaDescribedBy
      });
    } catch (_a) {
      return new Error('Bad data error');
    }
  }();
  if (useRichTextEditorResult instanceof Error) {
    onDataError === null || onDataError === void 0 ? void 0 : onDataError();
    return React__default.default.createElement(InlineNotification.InlineNotification, {
      headingProps: {
        children: 'Error',
        variant: 'heading-6'
      },
      type: "negative",
      persistent: true
    }, dataError !== null && dataError !== void 0 ? dataError : 'Something went wrong');
  }
  var editorRef = useRichTextEditorResult[0],
    editorState = useRichTextEditorResult[1],
    dispatchTransaction = useRichTextEditorResult[2];
  var controlMap = controlmap.buildControlMap(schema$1, editorState, controls);
  // @todo: Fix if possible - avoiding breaking in eslint upgrade
  // eslint-disable-next-line react-hooks/rules-of-hooks
  React.useEffect(function () {
    onChange(editorState);
    // Including `onContentChange` in the dependencies here will cause a 'Maximum update depth exceeded' issue
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [editorState]);
  return React__default.default.createElement(React__default.default.Fragment, null, !labelledBy && labelText && React__default.default.createElement(Label.Label, {
    classNameOverride: RichTextEditor_module.editorLabel,
    id: labelId,
    labelText: labelText
  }), React__default.default.createElement("div", {
    className: classnames__default.default(RichTextEditor_module.editorWrapper, RichTextEditor_module[status])
  }, controls && React__default.default.createElement(Toolbar.Toolbar, {
    "aria-controls": editorId,
    "aria-label": "Text formatting",
    classNameOverride: RichTextEditor_module.toolbar
  }, controlMap.map(function (section, index) {
    return React__default.default.createElement(ToolbarSection.ToolbarSection, {
      key: index
    }, section.map(function (controlConfig, controlKeyIndex) {
      return React__default.default.createElement(ToggleIconButton.ToggleIconButton, {
        key: controlKeyIndex,
        icon: controlConfig.icon,
        disabled: controlConfig.disabled,
        label: controlConfig.label,
        isActive: controlConfig.isActive,
        onClick: function () {
          return dispatchTransaction(controlConfig.action);
        }
      });
    }));
  })), React__default.default.createElement("div", tslib.__assign({
    id: editorId,
    ref: editorRef,
    className: classnames__default.default(RichTextEditor_module.editor, RichTextEditor_module["rows".concat(rows)], classNameOverride, controls != null && controls.length > 0 && RichTextEditor_module.hasToolbar)
  }, restProps))), validationMessage && React__default.default.createElement(FieldMessage.FieldMessage, {
    id: validationMessageAria,
    message: validationMessage,
    status: status
  }), description && React__default.default.createElement(FieldMessage.FieldMessage, {
    id: descriptionAria,
    message: description
  }));
};
RichTextEditor.displayName = 'RichTextEditor';
function getPlugins(controls, schema) {
  var allControlNames = controls ? controls.reduce(function (acc, c) {
    return tslib.__spreadArray(tslib.__spreadArray([], acc, true), [c.name], false);
  }, []) : [];
  var plugins = [ProseMirrorHistory__namespace.history(), ProseMirrorKeymap__namespace.keymap(keymap.buildKeymap(schema)), ProseMirrorKeymap__namespace.keymap(ProseMirrorCommands__namespace.baseKeymap), inputrules.buildInputRules(schema)];
  if (allControlNames.includes('link')) {
    plugins.push(LinkManager.createLinkManager({
      markType: schema.marks.link
    }));
  }
  return plugins;
}
exports.RichTextEditor = RichTextEditor;
