'use strict';

var tslib = require('tslib');
var React = require('react');
var Icon = require('../../../__next__/Icon/Icon.cjs');
var listIsActive = require('../../utils/commands/listIsActive.cjs');
var markIsActive = require('../../utils/commands/markIsActive.cjs');
require('prosemirror-transform');
var ProseMirrorCommands = require('prosemirror-commands');
require('prosemirror-keymap');
require('prosemirror-history');
require('prosemirror-state');
require('prosemirror-model');
require('prosemirror-inputrules');
var ProseMirrorSchemaList = require('prosemirror-schema-list');
function _interopDefault(e) {
  return e && e.__esModule ? e : {
    default: e
  };
}
function _interopNamespace(e) {
  if (e && e.__esModule) return e;
  var n = Object.create(null);
  if (e) {
    Object.keys(e).forEach(function (k) {
      if (k !== 'default') {
        var d = Object.getOwnPropertyDescriptor(e, k);
        Object.defineProperty(n, k, d.get ? d : {
          enumerable: true,
          get: function () {
            return e[k];
          }
        });
      }
    });
  }
  n.default = e;
  return Object.freeze(n);
}
var React__default = /*#__PURE__*/_interopDefault(React);
var ProseMirrorCommands__namespace = /*#__PURE__*/_interopNamespace(ProseMirrorCommands);
var ProseMirrorSchemaList__namespace = /*#__PURE__*/_interopNamespace(ProseMirrorSchemaList);

/** Chains multiple commands to dispatch each transitions in sequential order */
var chainTransactions = function () {
  var commands = [];
  for (var _i = 0; _i < arguments.length; _i++) {
    commands[_i] = arguments[_i];
  }
  return function (state, dispatch) {
    var _a;
    var updateStateAndDispatch = function (tr) {
      state = state.apply(tr);
      dispatch === null || dispatch === void 0 ? void 0 : dispatch(tr);
    };
    var lastCommand = commands.pop();
    for (var _i = 0, commands_1 = commands; _i < commands_1.length; _i++) {
      var command = commands_1[_i];
      command(state, updateStateAndDispatch);
    }
    return (_a = lastCommand === null || lastCommand === void 0 ? void 0 : lastCommand(state, dispatch)) !== null && _a !== void 0 ? _a : false;
  };
};
/** Dispatches a transaction to create initial p tag required for pm commands */
var createInitialParagraph = function (state, dispatch) {
  if (dispatch) {
    var tr = state.tr,
      schema = state.schema;
    dispatch(tr.replaceSelectionWith(schema.nodes.paragraph.create()));
    return true;
  }
  return false;
};
/** Create command for toggling Marks */
var createToggleMarkCommand = function (mark) {
  return function (state, dispatch) {
    var docIsEmpty = state.doc.content.size === 0;
    if (docIsEmpty) {
      return chainTransactions(createInitialParagraph, ProseMirrorCommands__namespace.toggleMark(mark))(state, dispatch);
    }
    return ProseMirrorCommands__namespace.toggleMark(mark)(state, dispatch);
  };
};
/** Create command for toggling Lists */
var createToggleListCommand = function (node) {
  return function (state, dispatch) {
    var docIsEmpty = state.doc.content.size === 0;
    if (docIsEmpty) {
      return chainTransactions(createInitialParagraph, ProseMirrorSchemaList__namespace.wrapInList(node))(state, dispatch);
    }
    return ProseMirrorSchemaList__namespace.wrapInList(node)(state, dispatch);
  };
};
/** Create command for reducing indents in a List */
var createLiftListCommand = function () {
  return function (state, dispatch) {
    var _a;
    var $from = state.selection.$from;
    // calculate the parent node from the current tag selected
    var listItemNode = (_a = $from.node($from.depth - 1)) === null || _a === void 0 ? void 0 : _a.type;
    return ProseMirrorSchemaList__namespace.liftListItem(listItemNode)(state, dispatch);
  };
};
/** Create command for indenting in a List */
var createIndentListCommand = function () {
  return function (state, dispatch) {
    var _a;
    var $from = state.selection.$from;
    var listItemNode = (_a = $from.node($from.depth - 1)) === null || _a === void 0 ? void 0 : _a.type;
    return ProseMirrorSchemaList__namespace.sinkListItem(listItemNode)(state, dispatch);
  };
};
/** handler lift list disabled state */
var liftListIsDisabled = function (state) {
  var _a;
  var $from = state.selection.$from;
  var listItemNode = (_a = $from.node($from.depth - 1)) === null || _a === void 0 ? void 0 : _a.type;
  var isValidListItem = (listItemNode === null || listItemNode === void 0 ? void 0 : listItemNode.name) === 'listItem' || false;
  return !isValidListItem;
};
/** handler indent list disabled state */
var indentListIsDisabled = function (state) {
  var _a;
  var _b = state.selection,
    $from = _b.$from,
    $to = _b.$to;
  var listItemNode = (_a = $from.node($from.depth - 1)) === null || _a === void 0 ? void 0 : _a.type;
  var isValidListItem = (listItemNode === null || listItemNode === void 0 ? void 0 : listItemNode.name) === 'listItem' || false;
  if (!isValidListItem) {
    return true;
  }
  var range = $from.blockRange($to, function (node) {
    return node.childCount > 0 && node.firstChild.type === listItemNode;
  });
  return !range || range.startIndex === 0 ? true : false;
};
/** Creates an object used as an index to map the controls to respective groups */
var createControlGroupIndex = function (controls) {
  return controls.reduce(function (groups, currentControl) {
    var _a;
    var _b;
    if (!(currentControl === null || currentControl === void 0 ? void 0 : currentControl.name)) return groups;
    return tslib.__assign(tslib.__assign({}, groups), (_a = {}, _a[currentControl.name] = (_b = currentControl.group) !== null && _b !== void 0 ? _b : 'ungrouped', _a));
  }, {});
};
/** Creates an initial object used to map button configuration into its respective groups */
var createInitialControls = function (controlGroupIndex) {
  var uniqueGroups = Array.from(new Set(Object.values(controlGroupIndex)));
  var initialControlObject = uniqueGroups.reduce(function (controlObject, controlKey) {
    var _a;
    if (controlKey === 'ungrouped') return controlObject;
    return tslib.__assign(tslib.__assign({}, controlObject), (_a = {}, _a[controlKey] = [], _a));
  }, {});
  // This ensure that ungrouped controls are always last
  initialControlObject.ungrouped = [];
  return initialControlObject;
};
/** Retrieves the name of the group a control belongs to */
var getGroupIndex = function (controlGroupIndex, controlType) {
  var _a;
  if (controlType) {
    return (_a = controlGroupIndex[controlType]) !== null && _a !== void 0 ? _a : 'ungrouped';
  }
  return 'ungrouped';
};
/** Filters out empty control groups and returns a multi dimensional array  */
var filterToolbarControls = function (groupedControls) {
  return Object.values(groupedControls).filter(function (controls) {
    return controls.length > 0;
  });
};
/** Builds an array of object used to map control configuration to rte toolbar buttons */
var buildControlMap = function (schema, editorState, controls) {
  var _a, _b;
  if (!controls) return [];
  var controlGroupIndex = createControlGroupIndex(controls);
  var toolbarControls = createInitialControls(controlGroupIndex);
  var listNodes = [schema.nodes.bulletList, schema.nodes.orderedList];
  if (schema.marks.strong) {
    var type = schema.marks.strong;
    var groupIndex = getGroupIndex(controlGroupIndex, 'bold');
    toolbarControls[groupIndex].push({
      isActive: markIsActive.markIsActive(editorState, type),
      action: createToggleMarkCommand(type),
      label: 'Bold',
      icon: React__default.default.createElement(Icon.Icon, {
        name: "format_bold",
        isPresentational: true
      })
    });
  }
  if (schema.marks.em) {
    var type = schema.marks.em;
    var groupIndex = getGroupIndex(controlGroupIndex, 'italic');
    toolbarControls[groupIndex].push({
      isActive: markIsActive.markIsActive(editorState, type),
      action: createToggleMarkCommand(type),
      label: 'Italic',
      icon: React__default.default.createElement(Icon.Icon, {
        name: "format_italic",
        isPresentational: true
      })
    });
  }
  if (schema.marks.underline) {
    var type = schema.marks.underline;
    var groupIndex = getGroupIndex(controlGroupIndex, 'underline');
    toolbarControls[groupIndex].push({
      isActive: markIsActive.markIsActive(editorState, type),
      action: createToggleMarkCommand(type),
      label: 'Underline',
      icon: React__default.default.createElement(Icon.Icon, {
        name: "format_underlined",
        isPresentational: true
      })
    });
  }
  if (schema.nodes.bulletList) {
    var type = schema.nodes.bulletList;
    var groupIndex = getGroupIndex(controlGroupIndex, 'bulletList');
    toolbarControls[groupIndex].push({
      action: createToggleListCommand(type),
      isActive: listIsActive.listIsActive(editorState, type, listNodes),
      label: 'Bullet List',
      icon: React__default.default.createElement(Icon.Icon, {
        name: "format_list_bulleted",
        isPresentational: true,
        shouldMirrorInRTL: true
      })
    });
  }
  if (schema.nodes.orderedList) {
    var type = schema.nodes.orderedList;
    var groupIndex = getGroupIndex(controlGroupIndex, 'orderedList');
    toolbarControls[groupIndex].push({
      action: createToggleListCommand(type),
      isActive: listIsActive.listIsActive(editorState, type, listNodes),
      label: 'Numbered List',
      icon: React__default.default.createElement(Icon.Icon, {
        name: "format_list_numbered",
        isPresentational: true,
        shouldMirrorInRTL: true
      })
    });
  }
  if (schema.nodes.orderedList || schema.nodes.bulletList) {
    var groupIndex = (_b = (_a = controlGroupIndex.orderedList) !== null && _a !== void 0 ? _a : controlGroupIndex.bulletList) !== null && _b !== void 0 ? _b : 'ungrouped';
    toolbarControls[groupIndex].push({
      action: createLiftListCommand(),
      disabled: liftListIsDisabled(editorState),
      isActive: false,
      label: 'Decrease indent',
      icon: React__default.default.createElement(Icon.Icon, {
        name: "format_indent_decrease",
        isPresentational: true,
        shouldMirrorInRTL: true
      })
    }, {
      action: createIndentListCommand(),
      disabled: indentListIsDisabled(editorState),
      isActive: false,
      label: 'Increase indent',
      icon: React__default.default.createElement(Icon.Icon, {
        name: "format_indent_increase",
        isPresentational: true,
        shouldMirrorInRTL: true
      })
    });
  }
  if (schema.marks.link) {
    var type = schema.marks.link;
    var groupIndex = getGroupIndex(controlGroupIndex, 'link');
    toolbarControls[groupIndex].push({
      action: createToggleMarkCommand(type),
      disabled: editorState.selection.empty,
      isActive: false,
      label: 'Link',
      icon: React__default.default.createElement(Icon.Icon, {
        name: "add_link",
        isPresentational: true
      })
    });
  }
  return filterToolbarControls(toolbarControls);
};
exports.buildControlMap = buildControlMap;
