'use strict';

var ProseMirrorCommands = require('prosemirror-commands');
require('prosemirror-keymap');
var ProseMirrorHistory = require('prosemirror-history');
require('prosemirror-state');
require('prosemirror-model');
var ProseMirrorInputrules = require('prosemirror-inputrules');
var ProseMirrorSchemaList = require('prosemirror-schema-list');
function _interopNamespace(e) {
  if (e && e.__esModule) return e;
  var n = Object.create(null);
  if (e) {
    Object.keys(e).forEach(function (k) {
      if (k !== 'default') {
        var d = Object.getOwnPropertyDescriptor(e, k);
        Object.defineProperty(n, k, d.get ? d : {
          enumerable: true,
          get: function () {
            return e[k];
          }
        });
      }
    });
  }
  n.default = e;
  return Object.freeze(n);
}
var ProseMirrorCommands__namespace = /*#__PURE__*/_interopNamespace(ProseMirrorCommands);
var ProseMirrorHistory__namespace = /*#__PURE__*/_interopNamespace(ProseMirrorHistory);
var ProseMirrorInputrules__namespace = /*#__PURE__*/_interopNamespace(ProseMirrorInputrules);
var ProseMirrorSchemaList__namespace = /*#__PURE__*/_interopNamespace(ProseMirrorSchemaList);
var buildKeymap = function (schema) {
  var redo = ProseMirrorHistory__namespace.redo,
    undo = ProseMirrorHistory__namespace.undo;
  var undoInputRule = ProseMirrorInputrules__namespace.undoInputRule;
  var wrapInList = ProseMirrorSchemaList__namespace.wrapInList,
    splitListItem = ProseMirrorSchemaList__namespace.splitListItem,
    liftListItem = ProseMirrorSchemaList__namespace.liftListItem,
    sinkListItem = ProseMirrorSchemaList__namespace.sinkListItem;
  var mac = typeof navigator != 'undefined' ? navigator.platform.includes('Mac') : false;
  var chainCommands = ProseMirrorCommands__namespace.chainCommands,
    exitCode = ProseMirrorCommands__namespace.exitCode,
    joinDown = ProseMirrorCommands__namespace.joinDown,
    joinUp = ProseMirrorCommands__namespace.joinUp,
    lift = ProseMirrorCommands__namespace.lift,
    selectParentNode = ProseMirrorCommands__namespace.selectParentNode,
    setBlockType = ProseMirrorCommands__namespace.setBlockType,
    toggleMark = ProseMirrorCommands__namespace.toggleMark;
  var keys = {
    'Mod-z': undo,
    'Shift-Mod-z': redo,
    'Backspace': undoInputRule,
    'Alt-ArrowUp': joinUp,
    'Alt-ArrowDown': joinDown,
    'Mod-BracketLeft': lift,
    'Escape': selectParentNode
  };
  if (!mac) {
    keys['Mod-y'] = redo;
  }
  if (schema.marks.strong) {
    var type = schema.marks.strong;
    keys['Mod-b'] = toggleMark(type);
    keys['Mod-B'] = toggleMark(type);
  }
  if (schema.marks.em) {
    var type = schema.marks.em;
    keys['Mod-i'] = toggleMark(type);
    keys['Mod-I'] = toggleMark(type);
  }
  if (schema.marks.underline) {
    var type = schema.marks.underline;
    keys['Mod-u'] = toggleMark(type);
    keys['Mod-U'] = toggleMark(type);
  }
  if (schema.nodes.hardBreak) {
    var br_1 = schema.nodes.hardBreak;
    var cmd = chainCommands(exitCode, function (state, dispatch) {
      dispatch === null || dispatch === void 0 ? void 0 : dispatch(state.tr.replaceSelectionWith(br_1.create()).scrollIntoView());
      return true;
    });
    keys['Mod-Enter'] = cmd;
    keys['Shift-Enter'] = cmd;
    if (mac) {
      keys['Ctrl-Enter'] = cmd;
    }
  }
  if (schema.nodes.paragraph) {
    keys['Shift-Ctrl-0'] = setBlockType(schema.nodes.paragraph);
  }
  if (schema.nodes.bulletList) {
    keys['Shift-Ctrl-8'] = wrapInList(schema.nodes.bulletList);
  }
  if (schema.nodes.orderedList) {
    keys['Shift-Ctrl-9'] = wrapInList(schema.nodes.orderedList);
  }
  if (schema.nodes.listItem) {
    var type = schema.nodes.listItem;
    keys.Enter = splitListItem(type);
    keys['Mod-['] = liftListItem(type);
    keys['Mod-]'] = sinkListItem(type);
  }
  return keys;
};
exports.buildKeymap = buildKeymap;
