'use strict';

var tslib = require('tslib');
var prosemirrorSchemaBasic = require('prosemirror-schema-basic');
var validation = require('../plugins/LinkManager/validation.cjs');
var getMarks = function () {
  return tslib.__assign(tslib.__assign({}, prosemirrorSchemaBasic.marks), {
    // An underline mark. Rendered as a `<u>` element. Has parse rules that also
    // matches `font-style: underline`.
    underline: {
      parseDOM: [{
        tag: 'u'
      }, {
        style: 'font-style=underline'
      }],
      toDOM: function () {
        return ['u', 0];
      }
    },
    // A link. Rendered and parsed as an `<a>` element.
    link: {
      attrs: {
        href: {
          default: null
        },
        _metadata: {
          default: {
            added: true
          }
        },
        target: {
          default: '_blank'
        },
        rel: {
          default: 'noreferrer'
        }
      },
      inclusive: false,
      parseDOM: [{
        tag: 'a[href]',
        getAttrs: function (dom) {
          var anchor = dom;
          return {
            href: getAttributeWithDefault(anchor, 'href'),
            target: getAttributeWithDefault(anchor, 'target'),
            rel: getAttributeWithDefault(anchor, 'rel'),
            _metadata: null
          };
        }
      }],
      toDOM: function (mark) {
        var _a = mark.attrs,
          href = _a.href,
          target = _a.target,
          rel = _a.rel;
        var validationStatus = validation.validateLink(href);
        if (validationStatus.status === 'error') {
          return ['span', 0];
        }
        return ['a', {
          href: href,
          target: target,
          rel: rel
        }, 0];
      }
    }
  });
};
var getAttributeWithDefault = function (node, attributeName) {
  var value = node.getAttribute(attributeName);
  return value && value !== '' ? value : null;
};
exports.getMarks = getMarks;
