'use strict';

var tslib = require('tslib');
var React = require('react');
var tabs = require('@reach/tabs');
var classnames = require('classnames');
var reactAria = require('react-aria');
var Badge = require('../../Badge/Badge.cjs');
var Tab_module = require('./Tab.module.scss.cjs');
function _interopDefault(e) {
  return e && e.__esModule ? e : {
    default: e
  };
}
var React__default = /*#__PURE__*/_interopDefault(React);
var classnames__default = /*#__PURE__*/_interopDefault(classnames);

/**
 * A tab button
 */
var Tab = function (props) {
  var isSelected = props.isSelected,
    badge = props.badge,
    disabled = props.disabled,
    children = props.children,
    classNameOverride = props.classNameOverride,
    restProps = tslib.__rest(props, ["isSelected", "badge", "disabled", "children", "classNameOverride"]);
  var ref = React.useRef(null);
  var _a = React.useState(false),
    isHovered = _a[0],
    setIsHovered = _a[1];
  var _b = React.useState(false),
    isFocused = _b[0],
    setIsFocused = _b[1];
  var showActiveBadge = Boolean(isSelected || isHovered || isFocused);
  var tabProps = tslib.__assign({
    disabled: disabled,
    className: classnames__default.default(Tab_module.tab, classNameOverride, isSelected && Tab_module.selected),
    onFocus: function (event) {
      var _a;
      setIsFocused(true);
      (_a = props.onFocus) === null || _a === void 0 ? void 0 : _a.call(props, event);
    },
    onBlur: function (event) {
      var _a;
      setIsFocused(false);
      (_a = props.onBlur) === null || _a === void 0 ? void 0 : _a.call(props, event);
    },
    onMouseEnter: function () {
      return setIsHovered(true);
    },
    onMouseLeave: function () {
      return setIsHovered(false);
    }
  }, restProps);
  var focusableProps = reactAria.useFocusable(tabProps, ref).focusableProps;
  // Reach is setting and managing tabIndex for us here, so we remove it from the focusableProps (also it needs to be non-defined, undefined is not enough)
  delete focusableProps.tabIndex;
  return React__default.default.createElement(tabs.Tab, tslib.__assign({
    ref: ref
  }, tabProps, focusableProps), children, badge && React__default.default.createElement("span", {
    className: Tab_module.badge
  }, React__default.default.createElement(Badge.Badge, {
    variant: showActiveBadge ? 'active' : 'default'
  }, badge)));
};
exports.Tab = Tab;
