'use strict';

var tslib = require('tslib');
var React = require('react');
var classnames = require('classnames');
var FieldGroup = require('../FieldGroup/FieldGroup.cjs');
var FieldMessage = require('../FieldMessage/FieldMessage.cjs');
var Input = require('../Input/Input/Input.cjs');
require('../Input/InputRange/InputRange.cjs');
require('../Input/InputSearch/InputSearch.cjs');
var Label = require('../Label/Label.cjs');
var Icon = require('../__next__/Icon/Icon.cjs');
var TextField_module = require('./TextField.module.scss.cjs');
function _interopDefault(e) {
  return e && e.__esModule ? e : {
    default: e
  };
}
var React__default = /*#__PURE__*/_interopDefault(React);
var classnames__default = /*#__PURE__*/_interopDefault(classnames);

/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3081928705/Text+Field Guidance} |
 * {@link https://cultureamp.design/?path=/docs/components-text-field--docs Storybook}
 */
var TextField = function (_a) {
  var propsId = _a.id,
    labelText = _a.labelText,
    _b = _a.inline,
    inline = _b === void 0 ? false : _b,
    icon = _a.icon,
    validationMessage = _a.validationMessage,
    description = _a.description,
    status = _a.status,
    _c = _a.reversed,
    reversed = _c === void 0 ? false : _c,
    disabled = _a.disabled,
    restProps = tslib.__rest(_a, ["id", "labelText", "inline", "icon", "validationMessage", "description", "status", "reversed", "disabled"]);
  var fallbackId = React.useId();
  var id = propsId !== null && propsId !== void 0 ? propsId : fallbackId;
  var validationMessageAria = validationMessage ? "".concat(id, "-field-validation-message") : '';
  var descriptionAria = description ? "".concat(id, "-field-description") : '';
  var ariaDescribedBy = [validationMessageAria, descriptionAria].reduce(function (prev, curr) {
    return curr ? [curr, prev].join(' ') : prev;
  }, '');
  return React__default.default.createElement(FieldGroup.FieldGroup, {
    id: "".concat(id, "-field-group"),
    "data-testid": "".concat(id, "-field-group"),
    inline: inline,
    classNameOverride: classnames__default.default(reversed && TextField_module.reversed)
  }, React__default.default.createElement(Label.Label, {
    id: "".concat(id, "-field-label"),
    "data-testid": "".concat(id, "-field-label"),
    htmlFor: "".concat(id, "-field-input"),
    labelText: labelText,
    reversed: reversed,
    disabled: disabled
  }), React__default.default.createElement(Input.Input, tslib.__assign({
    id: "".concat(id, "-field-input"),
    "data-testid": "".concat(id, "-field-input"),
    "aria-describedby": ariaDescribedBy,
    classNameOverride: TextField_module.input,
    disabled: disabled,
    reversed: reversed,
    status: status,
    startIconAdornment: icon,
    endIconAdornment: status === 'success' && React__default.default.createElement("div", {
      className: classnames__default.default(TextField_module.icon, TextField_module.success, disabled && TextField_module.disabled)
    }, React__default.default.createElement(Icon.Icon, {
      name: "check_circle",
      isPresentational: true,
      isFilled: true
    }))
  }, restProps)), validationMessage && React__default.default.createElement("div", {
    className: classnames__default.default(TextField_module.message, disabled && TextField_module.disabled)
  }, React__default.default.createElement(FieldMessage.FieldMessage, {
    id: validationMessageAria,
    message: validationMessage,
    status: status,
    reversed: reversed
  })), description && React__default.default.createElement("div", {
    className: classnames__default.default(TextField_module.message, disabled && TextField_module.disabled)
  }, React__default.default.createElement(FieldMessage.FieldMessage, {
    id: descriptionAria,
    message: description,
    reversed: reversed
  })));
};
TextField.displayName = 'TextField';
exports.TextField = TextField;
