'use strict';

var tslib = require('tslib');
var React = require('react');
var i18nReactIntl = require('@cultureamp/i18n-react-intl');
var classnames = require('classnames');
var Button = require('../../../Button/Button/Button.cjs');
var IconButton = require('../../../Button/IconButton/IconButton.cjs');
var Heading = require('../../../Heading/Heading.cjs');
var Text = require('../../../Text/Text.cjs');
var Icon = require('../../../__next__/Icon/Icon.cjs');
var GenericTile_module = require('./GenericTile.module.scss.cjs');
function _interopDefault(e) {
  return e && e.__esModule ? e : {
    default: e
  };
}
var React__default = /*#__PURE__*/_interopDefault(React);
var classnames__default = /*#__PURE__*/_interopDefault(classnames);
var GenericTile = function (_a) {
  var children = _a.children,
    title = _a.title,
    _b = _a.titleTag,
    titleTag = _b === void 0 ? 'h3' : _b,
    metadata = _a.metadata,
    information = _a.information,
    infoButtonLabel = _a.infoButtonLabel,
    mood = _a.mood,
    _c = _a.variant,
    variant = _c === void 0 ? 'default' : _c,
    footer = _a.footer,
    classNameOverride = _a.classNameOverride,
    restProps = tslib.__rest(_a, ["children", "title", "titleTag", "metadata", "information", "infoButtonLabel", "mood", "variant", "footer", "classNameOverride"]);
  var _d = React.useState(),
    isFlipped = _d[0],
    setIsFlipped = _d[1];
  var formatMessage = i18nReactIntl.useIntl().formatMessage;
  var infoButtonRef = React.useRef(null);
  var infoButtonReturnRef = React.useRef(null);
  React.useEffect(function () {
    if (isFlipped === true) return infoButtonReturnRef.current.focus();
    if (isFlipped === false) return infoButtonRef.current.focus();
  }, [isFlipped]);
  var translatedInfoLabel = formatMessage({
    id: 'kzGenericTile.infoButtonLabel',
    defaultMessage: 'View more information:',
    description: 'Prompts user to interact with button to reveal more information'
  });
  var renderTitle = function () {
    return React__default.default.createElement("div", {
      className: GenericTile_module.title
    }, React__default.default.createElement(Heading.Heading, {
      variant: "heading-3",
      tag: titleTag
    }, title), metadata && React__default.default.createElement("div", {
      className: GenericTile_module.titleMeta
    }, React__default.default.createElement(Text.Text, {
      variant: "small",
      color: "dark-reduced-opacity"
    }, metadata)));
  };
  var renderFront = function () {
    return React__default.default.createElement("div", {
      className: classnames__default.default(GenericTile_module.face, GenericTile_module.faceFront, mood ? GenericTile_module[mood] : GenericTile_module[variant])
    }, information && React__default.default.createElement("div", {
      className: GenericTile_module.informationBtn
    }, React__default.default.createElement(IconButton.IconButton, {
      label: infoButtonLabel !== null && infoButtonLabel !== void 0 ? infoButtonLabel : "".concat(translatedInfoLabel, " ").concat(title),
      icon: React__default.default.createElement(Icon.Icon, {
        name: "info",
        isPresentational: true,
        isFilled: true
      }),
      onClick: function () {
        return setIsFlipped(true);
      },
      disabled: isFlipped,
      "aria-hidden": isFlipped,
      ref: infoButtonRef
    })), renderTitle(), React__default.default.createElement("div", {
      className: GenericTile_module.children
    }, children && children), footer && React__default.default.createElement("div", {
      className: GenericTile_module.footer
    }, footer));
  };
  var renderInformation = function (informationProp) {
    var _a;
    if (informationProp && typeof informationProp === 'object' && 'text' in informationProp) {
      return React__default.default.createElement(React__default.default.Fragment, null, React__default.default.createElement(Text.Text, {
        variant: "body"
      }, informationProp.text), ((_a = informationProp.primaryAction) !== null && _a !== void 0 ? _a : informationProp.secondaryAction) && React__default.default.createElement("div", {
        className: GenericTile_module.footer
      }, React__default.default.createElement("div", {
        className: GenericTile_module.actions
      }, informationProp.secondaryAction && React__default.default.createElement(Button.Button, tslib.__assign({
        secondary: true,
        disabled: !isFlipped
      }, informationProp.secondaryAction)), informationProp.primaryAction && React__default.default.createElement(Button.Button, tslib.__assign({
        disabled: !isFlipped
      }, informationProp.primaryAction)))));
    }
    return informationProp;
  };
  var renderBack = function () {
    if (!information) return null;
    var returnButtonLabel = formatMessage({
      id: 'kzGenericTile.infoButtonReturnLabel',
      defaultMessage: 'Hide information:',
      description: 'Prompts user to interact with button to hide information'
    });
    return React__default.default.createElement("div", {
      className: classnames__default.default(GenericTile_module.face, GenericTile_module.faceBack)
    }, React__default.default.createElement("div", {
      className: GenericTile_module.informationBtn
    }, React__default.default.createElement(IconButton.IconButton, {
      label: "".concat(returnButtonLabel, " ").concat(title),
      icon: React__default.default.createElement(Icon.Icon, {
        name: "arrow_back",
        isPresentational: true
      }),
      onClick: function () {
        return setIsFlipped(false);
      },
      disabled: !isFlipped,
      "aria-hidden": !isFlipped,
      ref: infoButtonReturnRef
    })), React__default.default.createElement("div", {
      className: GenericTile_module.information
    }, renderInformation(information)));
  };
  return React__default.default.createElement("div", tslib.__assign({
    className: classnames__default.default(GenericTile_module.root, classNameOverride)
  }, restProps), React__default.default.createElement("div", {
    className: classnames__default.default(GenericTile_module.tile, isFlipped && GenericTile_module.isFlipped)
  }, React__default.default.createElement(React__default.default.Fragment, null, renderFront(), renderBack())));
};
GenericTile.displayName = 'GenericTile';
exports.GenericTile = GenericTile;
