'use strict';

var tslib = require('tslib');
var React = require('react');
var date = require('@internationalized/date');
var datepicker$1 = require('@react-aria/datepicker');
var i18n = require('@react-aria/i18n');
var datepicker = require('@react-stately/datepicker');
var classnames = require('classnames');
var FieldMessage = require('../FieldMessage/FieldMessage.cjs');
var Label = require('../Label/Label.cjs');
var TimeSegment = require('./subcomponents/TimeSegment/TimeSegment.cjs');
var TimeField_module = require('./TimeField.module.scss.cjs');
function _interopDefault(e) {
  return e && e.__esModule ? e : {
    default: e
  };
}
var React__default = /*#__PURE__*/_interopDefault(React);
var classnames__default = /*#__PURE__*/_interopDefault(classnames);

// This needed to be placed directly below the props because
// the prop descriptions wouldn't show in Storybook otherwise.
var TimeField = function (props) {
  return React__default.default.createElement(i18n.I18nProvider, {
    locale: props.locale
  }, React__default.default.createElement(TimeFieldComponent, tslib.__assign({}, props)));
};
TimeField.displayName = 'TimeField';
var TimeFieldComponent = function (_a) {
  var propsId = _a.id,
    label = _a.label,
    locale = _a.locale,
    onChange = _a.onChange,
    value = _a.value,
    _b = _a.status,
    status = _b === void 0 ? 'default' : _b,
    validationMessage = _a.validationMessage,
    isDisabled = _a.isDisabled,
    classNameOverride = _a.classNameOverride,
    restProps = tslib.__rest(_a, ["id", "label", "locale", "onChange", "value", "status", "validationMessage", "isDisabled", "classNameOverride"]);
  var reactId = React.useId();
  var id = propsId !== null && propsId !== void 0 ? propsId : reactId;
  var handleOnChange = function (timeValue) {
    if (timeValue === null) {
      return onChange(null);
    }
    onChange({
      hour: timeValue.hour,
      minutes: timeValue.minute
    });
  };
  var state = datepicker.useTimeFieldState(tslib.__assign(tslib.__assign({}, restProps), {
    value: value ? new date.Time(value.hour, value.minutes) : null,
    onChange: handleOnChange,
    isDisabled: isDisabled,
    hideTimeZone: true,
    locale: locale,
    validationState: status === 'default' ? 'valid' : 'invalid'
  }));
  var hasError = !!validationMessage && status === 'error';
  var descriptionId = hasError ? "".concat(id, "-field-message") : undefined;
  var inputRef = React__default.default.useRef(null);
  var _c = datepicker$1.useTimeField(tslib.__assign(tslib.__assign({}, restProps), {
      label: label,
      isDisabled: isDisabled,
      'aria-describedby': descriptionId
    }), state, inputRef),
    fieldProps = _c.fieldProps,
    labelProps = _c.labelProps;
  return React__default.default.createElement("div", {
    className: classNameOverride
  }, React__default.default.createElement(Label.Label, tslib.__assign({
    disabled: state.isDisabled
  }, labelProps, {
    classNameOverride: TimeField_module.label
  }), label), React__default.default.createElement("div", {
    className: TimeField_module.wrapper
  }, React__default.default.createElement("div", tslib.__assign({}, fieldProps, {
    id: id,
    ref: inputRef,
    className: classnames__default.default(TimeField_module.input, state.isDisabled && TimeField_module.isDisabled, state.validationState === 'invalid' && TimeField_module.error)
  }), state.segments.map(function (segment, i) {
    return React__default.default.createElement(TimeSegment.TimeSegment, {
      key: i,
      segment: segment,
      state: state,
      hasPadding: ![8294, 8297].includes(segment.text.charCodeAt(0))
    });
  }), React__default.default.createElement("div", {
    className: TimeField_module.focusRing
  }))), hasError && React__default.default.createElement(FieldMessage.FieldMessage, {
    id: descriptionId,
    message: validationMessage,
    status: status
  }));
};
TimeFieldComponent.displayName = 'TimeFieldComponent';
exports.TimeField = TimeField;
