'use strict';

var tslib = require('tslib');
var React = require('react');
var classnames = require('classnames');
var reactFocusOn = require('react-focus-on');
var index = require('../../Menu/index.cjs');
var Icon = require('../../__next__/Icon/Icon.cjs');
var constants = require('../constants.cjs');
var utils = require('../utils.cjs');
var TitleBlockMenuItem = require('./TitleBlockMenuItem.cjs');
var MobileActions_module = require('./MobileActions.module.scss.cjs');
function _interopDefault(e) {
  return e && e.__esModule ? e : {
    default: e
  };
}
var React__default = /*#__PURE__*/_interopDefault(React);
var classnames__default = /*#__PURE__*/_interopDefault(classnames);
var menuItemIsLink = function (item) {
  return 'href' in item;
};
var defaultActionIsLink = function (action) {
  return 'href' in action;
};
var defaultActionIsButton = function (action) {
  return !('href' in action) && 'onClick' in action || 'component' in action;
};
var filterActions = function (menuItems, filterType) {
  return menuItems.filter(function (item) {
    return filterType === 'link' ? menuItemIsLink(item) : !menuItemIsLink(item);
  });
};
/** Returns a filtered array of TitleBlockMenuItem based on actionType
 * This is use to sort a selectively render the action into a specifc order
 */
var renderPrimaryActionDrawerContent = function (primaryAction, actionType) {
  if (!primaryAction) return null;
  if (utils.isMenuGroupNotButton(primaryAction)) {
    var filteredActions = filterActions(primaryAction.menuItems, actionType);
    return filteredActions.map(function (item, idx) {
      var itemType = menuItemIsLink(item) ? 'link' : 'action';
      return React__default.default.createElement(TitleBlockMenuItem.TitleBlockMenuItem, tslib.__assign({}, item, {
        key: "title-block-mobile-actions-primary-".concat(itemType, "-").concat(idx),
        "data-automation-id": "title-block-mobile-actions-primary-".concat(itemType, "-").concat(idx),
        "data-testid": "title-block-mobile-actions-primary-".concat(itemType, "-").concat(idx)
      }));
    });
  }
  return null;
};
var renderDefaultLink = function (defaultAction) {
  if (!defaultActionIsLink(defaultAction)) return;
  if ('component' in defaultAction) {
    return React__default.default.createElement(TitleBlockMenuItem.TitleBlockMenuItem, tslib.__assign({}, defaultAction, {
      key: "title-block-mobile-actions-default-link",
      "data-automation-id": "title-block-mobile-actions-default-link",
      "data-testid": "title-block-mobile-actions-default-link"
    }));
  }
  return React__default.default.createElement(index.MenuItem, {
    href: defaultAction.href,
    label: defaultAction.label,
    icon: defaultAction.icon,
    disabled: defaultAction.disabled,
    key: "title-block-mobile-actions-default-link",
    "data-automation-id": "title-block-mobile-actions-default-link",
    "data-testid": "title-block-mobile-actions-default-link",
    id: defaultAction.id
  });
};
var renderDefaultAction = function (defaultAction) {
  if (!defaultActionIsLink(defaultAction)) {
    return React__default.default.createElement(TitleBlockMenuItem.TitleBlockMenuItem, tslib.__assign({}, defaultAction, {
      key: "title-block-mobile-actions-default-action",
      "data-automation-id": "title-block-mobile-actions-default-action",
      "data-testid": "title-block-mobile-actions-default-action"
    }));
  }
  return null;
};
var renderSecondaryActions = function (secondaryActions) {
  if (!secondaryActions) return null;
  var secondaryActionMenuItems = utils.convertSecondaryActionsToMenuItems(secondaryActions);
  return secondaryActionMenuItems.map(function (item, idx) {
    return React__default.default.createElement(TitleBlockMenuItem.TitleBlockMenuItem, tslib.__assign({}, item, {
      key: "title-block-mobile-actions-secondary-action-".concat(idx),
      "data-testid": "title-block-mobile-actions-secondary-action"
    }));
  });
};
var renderSecondaryOverflowMenuItems = function (secondaryOverflowMenuItems) {
  return secondaryOverflowMenuItems.map(function (item, idx) {
    return React__default.default.createElement(TitleBlockMenuItem.TitleBlockMenuItem, tslib.__assign({}, item, {
      key: "title-block-mobile-actions-overflow-menu-item-".concat(idx),
      "data-testid": "title-block-mobile-actions-overflow-menu-item"
    }));
  });
};
var DrawerMenuContent = function (_a) {
  var _b, _c, _d;
  var primaryAction = _a.primaryAction,
    defaultAction = _a.defaultAction,
    secondaryActions = _a.secondaryActions,
    secondaryOverflowMenuItems = _a.secondaryOverflowMenuItems;
  var showOtherActionsHeading = (_c = (_b = defaultAction && defaultActionIsButton(defaultAction)) !== null && _b !== void 0 ? _b : secondaryActions) !== null && _c !== void 0 ? _c : secondaryOverflowMenuItems;
  return React__default.default.createElement(React__default.default.Fragment, null, React__default.default.createElement(index.MenuList, null, primaryAction && renderPrimaryActionDrawerContent(primaryAction, 'link'), defaultAction && renderDefaultLink(defaultAction), primaryAction && renderPrimaryActionDrawerContent(primaryAction, 'action')), ((_d = defaultAction !== null && defaultAction !== void 0 ? defaultAction : secondaryActions) !== null && _d !== void 0 ? _d : secondaryOverflowMenuItems) && React__default.default.createElement(index.MenuList, {
    heading: showOtherActionsHeading ? React__default.default.createElement(index.MenuHeading, null, "Other actions") : undefined
  }, defaultAction && renderDefaultAction(defaultAction), secondaryActions && renderSecondaryActions(secondaryActions), secondaryOverflowMenuItems && renderSecondaryOverflowMenuItems(secondaryOverflowMenuItems)));
};
var renderDrawerHandleLabel = function (label, icon, drawerHandleLabelIconPosition) {
  if (drawerHandleLabelIconPosition === 'end') {
    return React__default.default.createElement(React__default.default.Fragment, null, React__default.default.createElement("span", {
      className: MobileActions_module.drawerHandleLabelText,
      "data-testid": "drawer-handle-lable-text"
    }, label), React__default.default.createElement(React__default.default.Fragment, null, icon && React__default.default.createElement("span", {
      className: MobileActions_module.drawerHandleIcon
    }, icon)));
  } else {
    return React__default.default.createElement(React__default.default.Fragment, null, React__default.default.createElement(React__default.default.Fragment, null, icon && React__default.default.createElement("span", {
      className: MobileActions_module.drawerHandleIcon
    }, icon)), React__default.default.createElement("span", {
      className: MobileActions_module.drawerHandleLabelText,
      "data-testid": "drawer-handle-lable-text"
    }, label));
  }
};
var ButtonOrLink = function (_a) {
  var action = _a.action,
    children = _a.children;
  if (typeof action === 'object' && 'onClick' in action && 'href' in action) {
    return React__default.default.createElement("a", {
      onClick: action.onClick,
      href: action.href,
      className: classnames__default.default(MobileActions_module.mobileActionsPrimaryLabel, MobileActions_module.mobileActionsPrimaryButton),
      "data-testid": "title-block-mobile-actions-primary-button"
    }, children);
  }
  if (typeof action === 'function') {
    return React__default.default.createElement("button", {
      type: "button",
      onClick: action,
      className: classnames__default.default(MobileActions_module.mobileActionsPrimaryLabel, MobileActions_module.mobileActionsPrimaryButton),
      "data-testid": "title-block-mobile-actions-primary-button"
    }, children);
  }
  if (typeof action === 'string') {
    return React__default.default.createElement("a", {
      href: action,
      className: classnames__default.default(MobileActions_module.mobileActionsPrimaryLabel, MobileActions_module.mobileActionsPrimaryButton),
      "data-testid": "title-block-mobile-actions-primary-button"
    }, children);
  }
  // when there's no action (e.g. primary button is disabled)
  return React__default.default.createElement("button", {
    type: "button",
    className: classnames__default.default(MobileActions_module.mobileActionsPrimaryLabel, MobileActions_module.mobileActionsPrimaryButton),
    "data-testid": "title-block-mobile-actions-primary-button"
  }, children);
};
var getAction = function (primaryAction) {
  if (primaryAction && !primaryAction.disabled) {
    if (primaryAction.onClick && primaryAction.href) {
      return {
        href: primaryAction.href,
        onClick: primaryAction.onClick
      };
    }
    if (primaryAction.onClick) {
      return primaryAction.onClick;
    }
    if (primaryAction.href) {
      return primaryAction.href;
    }
  }
  return undefined;
};
var DrawerHandle = function (_a) {
  var _b;
  var primaryAction = _a.primaryAction,
    secondaryActions = _a.secondaryActions,
    defaultAction = _a.defaultAction,
    secondaryOverflowMenuItems = _a.secondaryOverflowMenuItems,
    drawerHandleLabelIconPosition = _a.drawerHandleLabelIconPosition,
    toggleDisplay = _a.toggleDisplay,
    isOpen = _a.isOpen;
  var showDrawer = (_b = defaultAction !== null && defaultAction !== void 0 ? defaultAction : secondaryActions) !== null && _b !== void 0 ? _b : secondaryOverflowMenuItems;
  if (primaryAction) {
    // If the primary action is a menu
    if (utils.isMenuGroupNotButton(primaryAction)) {
      return React__default.default.createElement("div", {
        className: classnames__default.default(MobileActions_module.mobileActionsTopRow, MobileActions_module.mobileActionsTopRowSingleButton),
        "data-testid": "title-block-mobile-actions-drawer-handle"
      }, React__default.default.createElement("button", {
        type: "button",
        className: classnames__default.default(MobileActions_module.mobileActionsExpandButton, MobileActions_module.mobileActionsPrimaryLabel),
        onClick: toggleDisplay,
        "aria-expanded": isOpen
      }, primaryAction.label, React__default.default.createElement("span", {
        className: MobileActions_module.mobileActionsChevronSquare
      }, React__default.default.createElement(Icon.Icon, {
        name: isOpen ? 'keyboard_arrow_down' : 'keyboard_arrow_up',
        isPresentational: true
      }))));
    }
    // If the primary action is a button, or has no onClick/href/action
    return React__default.default.createElement("div", {
      className: classnames__default.default(MobileActions_module.mobileActionsTopRow, !showDrawer && MobileActions_module.mobileActionsTopRowSingleButton),
      "data-testid": "title-block-mobile-actions-drawer-handle"
    }, 'component' in primaryAction ? React__default.default.createElement(primaryAction.component, tslib.__assign({
      className: classnames__default.default(MobileActions_module.mobileActionsPrimaryLabel, MobileActions_module.mobileActionsPrimaryButton)
    }, primaryAction), primaryAction.label && renderDrawerHandleLabel(primaryAction.label, primaryAction.icon, drawerHandleLabelIconPosition)) : React__default.default.createElement(ButtonOrLink, {
      action: getAction(primaryAction)
    }, renderDrawerHandleLabel(primaryAction.label, primaryAction.icon, drawerHandleLabelIconPosition)), showDrawer && React__default.default.createElement("button", {
      type: "button",
      className: MobileActions_module.mobileActionsExpandButton,
      onClick: toggleDisplay,
      "aria-expanded": isOpen,
      id: constants.TITLE_BLOCK_ZEN_OTHER_ACTIONS_HTML_ID,
      "aria-label": "Other actions"
    }, React__default.default.createElement(Icon.Icon, {
      name: isOpen ? 'keyboard_arrow_down' : 'keyboard_arrow_up',
      isPresentational: true
    })));
  }
  // if there are default/secondary actions but no primary action
  if (showDrawer) {
    return React__default.default.createElement("div", {
      className: classnames__default.default(MobileActions_module.mobileActionsTopRow, MobileActions_module.mobileActionsTopRowSingleButton),
      "data-testid": "title-block-mobile-actions-drawer-handle"
    }, React__default.default.createElement("button", {
      type: "button",
      className: classnames__default.default(MobileActions_module.mobileActionsExpandButton, MobileActions_module.mobileActionsPrimaryLabel),
      onClick: toggleDisplay,
      "aria-expanded": isOpen,
      id: constants.TITLE_BLOCK_ZEN_OTHER_ACTIONS_HTML_ID
    }, renderDrawerHandleLabel('Other actions'), React__default.default.createElement("span", {
      className: MobileActions_module.mobileActionsChevronSquare
    }, React__default.default.createElement(Icon.Icon, {
      name: isOpen ? 'keyboard_arrow_down' : 'keyboard_arrow_up',
      isPresentational: true
    }))));
  }
  return null;
};
var MobileActions = function (_a) {
  var _b, _c;
  var primaryAction = _a.primaryAction,
    defaultAction = _a.defaultAction,
    secondaryActions = _a.secondaryActions,
    secondaryOverflowMenuItems = _a.secondaryOverflowMenuItems,
    drawerHandleLabelIconPosition = _a.drawerHandleLabelIconPosition,
    _d = _a.autoHide,
    autoHide = _d === void 0 ? false : _d;
  var _e = React.useState(false),
    isOpen = _e[0],
    setIsOpen = _e[1];
  var menuContent = React__default.default.createRef();
  var toggleDisplay = function () {
    setIsOpen(!isOpen);
  };
  // This callback handler will not run when autoHide === "off"
  var handleDocumentClickForAutoHide = React.useCallback(function (e) {
    var _a;
    if (isOpen && e.target instanceof Node && ((_a = menuContent.current) === null || _a === void 0 ? void 0 : _a.contains(e.target))) {
      setIsOpen(false);
    }
  },
  // @todo: Fix if possible - avoiding breaking in eslint upgrade
  // eslint-disable-next-line react-hooks/exhaustive-deps
  [menuContent]);
  React.useEffect(function () {
    if (autoHide) {
      document.addEventListener('click', handleDocumentClickForAutoHide, true);
    }
    return function () {
      if (autoHide) {
        document.removeEventListener('click', handleDocumentClickForAutoHide, true);
      }
    };
  }, [autoHide, handleDocumentClickForAutoHide]);
  return React__default.default.createElement("div", {
    className: classnames__default.default(MobileActions_module.mobileActionsContainer, isOpen && MobileActions_module.isOpen)
  }, React__default.default.createElement(reactFocusOn.FocusOn, {
    enabled: isOpen,
    scrollLock: false
  }, React__default.default.createElement(DrawerHandle, {
    primaryAction: primaryAction,
    secondaryActions: secondaryActions,
    defaultAction: defaultAction,
    secondaryOverflowMenuItems: secondaryOverflowMenuItems,
    drawerHandleLabelIconPosition: drawerHandleLabelIconPosition,
    toggleDisplay: toggleDisplay,
    isOpen: isOpen
  }), ((_c = (_b = defaultAction !== null && defaultAction !== void 0 ? defaultAction : secondaryActions) !== null && _b !== void 0 ? _b : secondaryOverflowMenuItems) !== null && _c !== void 0 ? _c : primaryAction && utils.isMenuGroupNotButton(primaryAction)) && React__default.default.createElement("div", {
    ref: menuContent,
    className: MobileActions_module.mobileActionsMenuContainer
  }, React__default.default.createElement(DrawerMenuContent, {
    primaryAction: primaryAction,
    defaultAction: defaultAction,
    secondaryActions: secondaryActions,
    secondaryOverflowMenuItems: secondaryOverflowMenuItems
  }))));
};
MobileActions.displayName = 'MobileActions';
exports.MobileActions = MobileActions;
