'use strict';

var tslib = require('tslib');
var React = require('react');
var Button = require('../../Button/Button/Button.cjs');
var IconButton = require('../../Button/IconButton/IconButton.cjs');
var index = require('../../Menu/index.cjs');
var Icon = require('../../__next__/Icon/Icon.cjs');
var TitleBlockZen_module = require('../TitleBlockZen.module.scss.cjs');
var constants = require('../constants.cjs');
var TitleBlockMenuItem = require('./TitleBlockMenuItem.cjs');
var Toolbar = require('./Toolbar.cjs');
function _interopDefault(e) {
  return e && e.__esModule ? e : {
    default: e
  };
}
var React__default = /*#__PURE__*/_interopDefault(React);
var renderSecondaryOverflowMenu = function (secondaryOverflowMenuItems, reversed) {
  if (!secondaryOverflowMenuItems) return undefined;
  return React__default.default.createElement(index.Menu, {
    align: "right",
    button: React__default.default.createElement(IconButton.IconButton, {
      label: "Open secondary menu",
      reversed: reversed,
      icon: React__default.default.createElement(Icon.Icon, {
        name: "more_horiz",
        isPresentational: true
      }),
      id: constants.TITLE_BLOCK_ZEN_SECONDARY_MENU_HTML_ID
    })
  }, React__default.default.createElement(index.MenuList, null, secondaryOverflowMenuItems.map(function (menuItem, i) {
    return React__default.default.createElement(TitleBlockMenuItem.TitleBlockMenuItem, tslib.__assign({
      key: i
    }, menuItem));
  })));
};
// Unfortunately, you'll notice below, that I needed to use the array index,
// against react best practices (https://reactjs.org/docs/lists-and-keys.html)
// This is because the menu items have no unique identifier.
var SecondaryActions = function (_a) {
  var secondaryActions = _a.secondaryActions,
    secondaryOverflowMenuItems = _a.secondaryOverflowMenuItems,
    _b = _a.reversed,
    reversed = _b === void 0 ? false : _b;
  if (!secondaryActions && !secondaryOverflowMenuItems) return null;
  var secondaryActionsAsToolbarItems = secondaryActions ? secondaryActions.map(function (action, i) {
    if ('menuItems' in action) {
      return {
        key: "".concat(i),
        // We shouldn't use an index here, see note above
        node: React__default.default.createElement(index.Menu, {
          align: "right",
          button: React__default.default.createElement(Button.Button, {
            secondary: true,
            label: action.label,
            reversed: reversed,
            icon: React__default.default.createElement(Icon.Icon, {
              name: "keyboard_arrow_down",
              isPresentational: true
            }),
            iconPosition: "end"
          })
        }, React__default.default.createElement(index.MenuList, null, action.menuItems.map(function (menuItem, i2) {
          return React__default.default.createElement(TitleBlockMenuItem.TitleBlockMenuItem, tslib.__assign({
            key: i2
          }, menuItem));
        })))
      };
    } else {
      if ('onClick' in action && 'href' in action) {
        // eslint-disable-next-line no-console
        console.warn('\u001b[33m \nTITLE BLOCK WARNING:\nSecondary actions only support ' + 'either an href or an onClick, not both simultaneously.\n');
      }
      return {
        key: "".concat(i),
        // We shouldn't use an index here, see note above
        node: React__default.default.createElement(Button.Button, tslib.__assign({
          secondary: true,
          reversed: reversed
        }, action, {
          "data-automation-id": "title-block-secondary-actions-button",
          "data-testid": "title-block-secondary-actions-button"
        }))
      };
    }
  }) : [];
  var overflowMenu = renderSecondaryOverflowMenu(secondaryOverflowMenuItems, reversed);
  var toolbarItems = tslib.__spreadArray(tslib.__spreadArray([], secondaryActionsAsToolbarItems, true), overflowMenu ? [{
    key: 'overflowMenu',
    node: overflowMenu
  }] : [], true);
  return React__default.default.createElement("div", {
    className: TitleBlockZen_module.secondaryActionsContainer
  }, React__default.default.createElement(Toolbar.Toolbar, {
    items: toolbarItems,
    noGap: true,
    automationId: "title-block-secondary-actions-toolbar"
  }));
};
SecondaryActions.displayName = 'SecondaryActions';
exports.SecondaryActions = SecondaryActions;
