'use strict';

var tslib = require('tslib');
var React = require('react');
var ReactDOM = require('react-dom');
var classnames = require('classnames');
var reactPopper = require('react-popper');
var AppearanceAnim = require('./subcomponents/AppearanceAnim.cjs');
var isSemanticElement = require('./utils/isSemanticElement.cjs');
var Tooltip_module = require('./Tooltip.module.scss.cjs');
function _interopDefault(e) {
  return e && e.__esModule ? e : {
    default: e
  };
}
var React__default = /*#__PURE__*/_interopDefault(React);
var ReactDOM__default = /*#__PURE__*/_interopDefault(ReactDOM);
var classnames__default = /*#__PURE__*/_interopDefault(classnames);
var positionToPlacement = new Map([['above', 'top'], ['below', 'bottom'], ['left', 'left'], ['right', 'right']]);
// Sync with Tooltip.scss
var arrowHeight = 7;
var arrowWidth = 14;
var TooltipContent = function (_a) {
  var position = _a.position,
    text = _a.text,
    referenceElement = _a.referenceElement,
    tooltipId = _a.tooltipId,
    _b = _a.mood,
    mood = _b === void 0 ? 'default' : _b;
  var _c = React.useState(null),
    popperElement = _c[0],
    setPopperElement = _c[1];
  var _d = React.useState(null),
    arrowElement = _d[0],
    setArrowElement = _d[1];
  var _e = reactPopper.usePopper(referenceElement, popperElement, {
      modifiers: [{
        name: 'arrow',
        options: {
          element: arrowElement,
          // Ensures that the arrow doesn't go too far to the left or right
          // of the tooltip.
          padding: arrowWidth / 2 + 10
        }
      }, {
        name: 'offset',
        options: {
          offset: [0, arrowHeight + 6]
        }
      }, {
        name: 'preventOverflow',
        options: {
          // Makes sure that the tooltip isn't flush up against the end of the
          // viewport
          padding: 8,
          altAxis: true,
          altBoundary: true,
          tetherOffset: 50
        }
      }, {
        name: 'flip',
        options: {
          padding: 8,
          altBoundary: true,
          fallbackPlacements: ['left', 'top', 'bottom', 'right']
        }
      }],
      placement: position ? positionToPlacement.get(position) : undefined
    }),
    popperStyles = _e.styles,
    attributes = _e.attributes;
  var _f = AppearanceAnim.useAnimation(),
    isVisible = _f.isVisible,
    isAnimIn = _f.isAnimIn,
    isAnimOut = _f.isAnimOut;
  return isVisible || isAnimOut || isAnimIn ? React__default.default.createElement("div", tslib.__assign({
    ref: setPopperElement,
    className: Tooltip_module.tooltip,
    style: popperStyles.popper
  }, attributes.popper, {
    role: "tooltip",
    id: tooltipId
  }), React__default.default.createElement("div", {
    className: classnames__default.default(Tooltip_module.tooltipContent, Tooltip_module[mood])
  }, text), React__default.default.createElement("div", {
    ref: setArrowElement,
    className: Tooltip_module.arrow,
    style: popperStyles.arrow
  }, React__default.default.createElement("div", {
    className: Tooltip_module.arrowInner
  }, React__default.default.createElement("div", {
    className: classnames__default.default(Tooltip_module.arrowMain, Tooltip_module[mood])
  }), React__default.default.createElement("div", {
    className: Tooltip_module.arrowShadow
  })))) : null;
};
var renderChildren = function (content, tooltipId, hasActiveTooltip) {
  if (isSemanticElement.isSemanticElement(content)) {
    return React.cloneElement(content, {
      'aria-describedby': hasActiveTooltip ? tooltipId : undefined
    });
  }
  // We don't want to block them from this but just provide context for better a11y guidance
  // eslint-disable-next-line no-console
  console.warn('<Tooltip /> is not directly wrapping a semantic element, screen reader users will not be able to access the tooltip info. To ensure accessibility, Tooltip should be wrapping a semantic and focusable element directly.');
  return content;
};
var Tooltip = function (_a) {
  var children = _a.children,
    text = _a.text,
    _b = _a.display,
    display = _b === void 0 ? 'block' : _b,
    _c = _a.position,
    position = _c === void 0 ? 'above' : _c,
    classNameOverride = _a.classNameOverride,
    portalSelector = _a.portalSelector,
    animationDuration = _a.animationDuration,
    _d = _a.isInitiallyVisible,
    isInitiallyVisible = _d === void 0 ? false : _d,
    _e = _a.mood,
    mood = _e === void 0 ? 'default' : _e;
  var _f = React.useState(isInitiallyVisible),
    isHover = _f[0],
    setIsHover = _f[1];
  var _g = React.useState(false),
    isFocus = _g[0],
    setIsFocus = _g[1];
  var _h = React.useState(null),
    referenceElement = _h[0],
    setReferenceElement = _h[1];
  var tooltipId = React.useId();
  var hasActiveTooltip = isHover || isFocus;
  var tooltip = React__default.default.createElement(TooltipContent, {
    text: text,
    position: position,
    referenceElement: referenceElement,
    tooltipId: tooltipId,
    mood: mood
  });
  var portalSelectorElementRef = React.useRef(null);
  React.useEffect(function () {
    portalSelectorElementRef.current = portalSelector ? document.querySelector(portalSelector) : null;
  }, [portalSelector]);
  React.useEffect(function () {
    if (portalSelector && !portalSelectorElementRef.current) {
      // eslint-disable-next-line no-console
      console.warn('The portal could not be created using the selector: ' + portalSelector);
    }
  }, [portalSelectorElementRef, portalSelector]);
  var getDisplayClassName = function () {
    switch (display) {
      case 'inline':
        return Tooltip_module.displayInline;
      case 'block':
        return Tooltip_module.displayBlock;
      case 'inline-block':
        return Tooltip_module.displayInlineBlock;
      case 'flex':
        return Tooltip_module.displayFlex;
      case 'inline-flex':
        return Tooltip_module.displayInlineFlex;
      default:
        return undefined;
    }
  };
  return React__default.default.createElement(AppearanceAnim.AnimationProvider, {
    isVisible: hasActiveTooltip,
    animationDuration: animationDuration
  }, React__default.default.createElement(React__default.default.Fragment, null, React__default.default.createElement("div", {
    ref: setReferenceElement,
    className: classnames__default.default(classNameOverride, getDisplayClassName()),
    onMouseEnter: function () {
      return setIsHover(true);
    },
    onMouseLeave: function () {
      return setIsHover(false);
    },
    onFocusCapture: function () {
      return setIsFocus(true);
    },
    onBlurCapture: function () {
      return setIsFocus(false);
    }
  }, renderChildren(children, tooltipId, hasActiveTooltip)), portalSelector && portalSelectorElementRef.current ? ReactDOM__default.default.createPortal(tooltip, portalSelectorElementRef.current) : tooltip));
};
Tooltip.displayName = 'Tooltip';
exports.Tooltip = Tooltip;
