'use strict';

var tslib = require('tslib');
var React = require('react');
var button = require('@react-aria/button');
var select$1 = require('@react-aria/select');
var select = require('@react-stately/select');
var classnames = require('classnames');
var FieldMessage = require('../../FieldMessage/FieldMessage.cjs');
var Popover = require('../../MultiSelect/subcomponents/Popover/Popover.cjs');
var reactDom = require('@floating-ui/react-dom');
var SelectContext = require('./context/SelectContext.cjs');
var ListBox = require('./subcomponents/ListBox/ListBox.cjs');
var ListBoxSection = require('./subcomponents/ListBoxSection/ListBoxSection.cjs');
var ListItem = require('./subcomponents/ListItem/ListItem.cjs');
require('./subcomponents/ListItems/ListItems.cjs');
var Option = require('./subcomponents/Option/Option.cjs');
require('./subcomponents/Overlay/Overlay.cjs');
var SectionDivider = require('./subcomponents/SectionDivider/SectionDivider.cjs');
var SelectPopoverContents = require('./subcomponents/SelectPopoverContents/SelectPopoverContents.cjs');
var SelectToggle = require('./subcomponents/SelectToggle/SelectToggle.cjs');
var getDisabledKeysFromItems = require('./utils/getDisabledKeysFromItems.cjs');
var transformSelectItemToCollectionElement = require('./utils/transformSelectItemToCollectionElement.cjs');
var Select_module = require('./Select.module.scss.cjs');
function _interopDefault(e) {
  return e && e.__esModule ? e : {
    default: e
  };
}
var React__default = /*#__PURE__*/_interopDefault(React);
var classnames__default = /*#__PURE__*/_interopDefault(classnames);

/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3081896474/Select Guidance} |
 * {@link https://cultureamp.design/?path=/docs/components-select--docs Storybook}
 */
var Select = function (_a) {
  var _b;
  var label = _a.label,
    items = _a.items,
    propsId = _a.id,
    trigger = _a.trigger,
    children = _a.children,
    status = _a.status,
    validationMessage = _a.validationMessage,
    isReversed = _a.isReversed,
    isFullWidth = _a.isFullWidth,
    disabledValues = _a.disabledValues,
    classNameOverride = _a.classNameOverride,
    selectedKey = _a.selectedKey,
    description = _a.description,
    _c = _a.placeholder,
    placeholder = _c === void 0 ? '' : _c,
    isDisabled = _a.isDisabled,
    onSelectionChange = _a.onSelectionChange,
    portalContainerId = _a.portalContainerId,
    restProps = tslib.__rest(_a, ["label", "items", "id", "trigger", "children", "status", "validationMessage", "isReversed", "isFullWidth", "disabledValues", "classNameOverride", "selectedKey", "description", "placeholder", "isDisabled", "onSelectionChange", "portalContainerId"]);
  var refs = reactDom.useFloating().refs;
  var triggerRef = refs.reference;
  var fallbackId = React.useId();
  var id = propsId !== null && propsId !== void 0 ? propsId : fallbackId;
  var descriptionId = "".concat(id, "--description");
  var validationId = "".concat(id, "--validation");
  var popoverId = "".concat(id, "--popover");
  var disabledKeys = getDisabledKeysFromItems.getDisabledKeysFromItems(items);
  var ariaSelectProps = tslib.__assign({
    label: label,
    items: items,
    children: transformSelectItemToCollectionElement.transformSelectItemToCollectionElement,
    disabledKeys: disabledValues !== null && disabledValues !== void 0 ? disabledValues : disabledKeys,
    selectedKey: typeof selectedKey === 'number' ? selectedKey.toString() : selectedKey,
    description: description,
    placeholder: placeholder,
    isDisabled: isDisabled,
    onSelectionChange: onSelectionChange ? function (key) {
      return onSelectionChange(key);
    } : undefined
  }, restProps);
  var state = select.useSelectState(ariaSelectProps);
  var _d = select$1.useSelect(ariaSelectProps, state, triggerRef),
    labelProps = _d.labelProps,
    reactAriaTriggerProps = _d.triggerProps,
    valueProps = _d.valueProps,
    menuProps = _d.menuProps,
    errorMessageProps = _d.errorMessageProps,
    descriptionProps = _d.descriptionProps;
  // Hack incoming:
  // react-aria/useSelect wants to prefix the combobox's accessible name with the value of the select.
  // We use role=combobox, meaning screen readers will read the value.
  // So we're modifying the `aria-labelledby` property to remove the value element id.
  // Issue: https://github.com/adobe/react-spectrum/issues/4091
  var reactAriaLabelledBy = reactAriaTriggerProps['aria-labelledby'];
  var triggerProps = tslib.__assign(tslib.__assign({}, reactAriaTriggerProps), {
    'aria-labelledby': reactAriaLabelledBy === null || reactAriaLabelledBy === void 0 ? void 0 : reactAriaLabelledBy.substring(reactAriaLabelledBy.indexOf(' ') + 1)
  });
  var buttonProps = button.useButton(triggerProps, triggerRef).buttonProps;
  var selectToggleProps = tslib.__assign(tslib.__assign({}, buttonProps), {
    label: label,
    labelProps: labelProps,
    'value': (_b = state === null || state === void 0 ? void 0 : state.selectedItem) === null || _b === void 0 ? void 0 : _b.rendered,
    valueProps: valueProps,
    'isOpen': state.isOpen,
    placeholder: placeholder,
    status: status,
    'isDisabled': triggerProps.isDisabled,
    isReversed: isReversed,
    'ref': refs.setReference,
    'aria-describedby': classnames__default.default(validationMessage && validationId, description && descriptionId)
  });
  var _e = React.useState(),
    portalContainer = _e[0],
    setPortalContainer = _e[1];
  React.useEffect(function () {
    if (portalContainerId) {
      var portalElement = document.getElementById(portalContainerId);
      if (portalElement) setPortalContainer(portalElement);
    }
  }, [portalContainerId]);
  return React__default.default.createElement("div", {
    className: classnames__default.default(!isFullWidth && Select_module.notFullWidth, classNameOverride)
  }, React__default.default.createElement(select$1.HiddenSelect, {
    label: label,
    name: id,
    state: state,
    triggerRef: triggerRef
  }), React__default.default.createElement("div", {
    className: Select_module.container
  }, trigger === undefined ? React__default.default.createElement(SelectToggle.SelectToggle, tslib.__assign({}, selectToggleProps)) : trigger(selectToggleProps, selectToggleProps.ref), state.isOpen && React__default.default.createElement(Popover.Popover, {
    id: popoverId,
    portalContainer: portalContainer,
    refs: refs
  }, React__default.default.createElement(SelectContext.SelectProvider, {
    state: state
  }, React__default.default.createElement(SelectPopoverContents.SelectPopoverContents, {
    menuProps: menuProps,
    popoverRef: refs.floating
  }, children)))), validationMessage && React__default.default.createElement(FieldMessage.FieldMessage, tslib.__assign({}, errorMessageProps, {
    id: validationId,
    message: validationMessage,
    status: status,
    reversed: isReversed
  })), description && React__default.default.createElement(FieldMessage.FieldMessage, tslib.__assign({}, descriptionProps, {
    id: descriptionId,
    message: description,
    reversed: isReversed
  })));
};
Select.displayName = 'Select';
Select.Section = ListBoxSection.ListBoxSection;
Select.SectionDivider = SectionDivider.SectionDivider;
Select.Option = Option.Option;
Select.ItemDefaultRender = ListItem.ListItem;
// @deprecated Legacy exported aliases
Select.TriggerButton = SelectToggle.SelectToggle;
Select.ListBox = ListBox.ListBox;
exports.Select = Select;
