'use strict';

var tslib = require('tslib');
var React = require('react');
var classnames = require('classnames');
var reactAriaComponents = require('react-aria-components');
var Icon = require('../../../Icon/Icon.cjs');
var isRTL = require('../../../../utils/isRTL/isRTL.cjs');
var constants = require('../../constants.cjs');
var TabList_module = require('./TabList.module.css.cjs');
function _interopDefault(e) {
  return e && e.__esModule ? e : {
    default: e
  };
}
var React__default = /*#__PURE__*/_interopDefault(React);
var classnames__default = /*#__PURE__*/_interopDefault(classnames);

/**
 * Wrapper for the tabs themselves
 */
var TabList = function (props) {
  var ariaLabel = props["aria-label"],
    _a = props.noPadding,
    noPadding = _a === void 0 ? false : _a,
    children = props.children,
    className = props.className,
    testId = props["data-testid"],
    restProps = tslib.__rest(props, ['aria-label', "noPadding", "children", "className", 'data-testid']);
  var _b = React.useState(false),
    isDocumentReady = _b[0],
    setIsDocumentReady = _b[1];
  var _c = React.useState(false),
    leftArrowEnabled = _c[0],
    setLeftArrowEnabled = _c[1];
  var _d = React.useState(false),
    rightArrowEnabled = _d[0],
    setRightArrowEnabled = _d[1];
  var tabListRef = React.useRef(null);
  var tabListId = React.useId();
  var _e = React.useState(false),
    isRTL$1 = _e[0],
    setIsRTL = _e[1];
  var _f = React.useState(),
    containerElement = _f[0],
    setContainerElement = _f[1];
  var tabListContext = React.useContext(reactAriaComponents.TabListStateContext);
  var selectedKey = tabListContext === null || tabListContext === void 0 ? void 0 : tabListContext.selectedKey;
  React.useEffect(function () {
    if (!isDocumentReady) {
      setIsDocumentReady(true);
      return;
    }
    var container = document.getElementById(tabListId);
    setContainerElement(container);
    setIsRTL(container ? isRTL.isRTL(container) : false);
  }, [isDocumentReady, tabListId]);
  React.useEffect(function () {
    if (!isDocumentReady) {
      return;
    }
    var tabs = containerElement === null || containerElement === void 0 ? void 0 : containerElement.querySelectorAll('[data-kz-tab]');
    if (!tabs || tabs.length === 0) {
      return;
    }
    var firstTabObserver = new IntersectionObserver(function (entries) {
      if (!entries[0].isIntersecting) {
        setLeftArrowEnabled(true);
        return;
      }
      setLeftArrowEnabled(false);
    }, {
      threshold: 0.75,
      root: containerElement
    });
    firstTabObserver.observe(isRTL$1 ? tabs[tabs.length - 1] : tabs[0]);
    var lastTabObserver = new IntersectionObserver(function (entries) {
      if (!entries[0].isIntersecting) {
        setRightArrowEnabled(true);
        return;
      }
      setRightArrowEnabled(false);
    }, {
      threshold: 0.75,
      root: containerElement
    });
    lastTabObserver.observe(isRTL$1 ? tabs[0] : tabs[tabs.length - 1]);
    return function () {
      firstTabObserver.disconnect();
      lastTabObserver.disconnect();
    };
  }, [isDocumentReady, containerElement, isRTL$1]);
  React.useEffect(function () {
    var _a;
    if (!isDocumentReady) {
      return;
    }
    // Scroll selected tab into view
    (_a = containerElement === null || containerElement === void 0 ? void 0 : containerElement.querySelector('[role="tab"][data-selected=true]')) === null || _a === void 0 ? void 0 : _a.scrollIntoView({
      block: 'nearest',
      inline: 'center'
    });
  }, [selectedKey, containerElement, isDocumentReady]);
  var handleArrowPress = function (direction) {
    if (tabListRef.current) {
      var tabListScrollPos = tabListRef.current.scrollLeft;
      var newSpot = direction === 'left' ? tabListScrollPos - constants.SCROLL_AMOUNT : tabListScrollPos + constants.SCROLL_AMOUNT;
      tabListRef.current.scrollLeft = newSpot;
    }
  };
  return React__default.default.createElement("div", {
    className: TabList_module.container,
    id: tabListId
  }, leftArrowEnabled &&
  // making a conscious decision to use <div onClick> over <button> here, because:
  // - <button> would add pointless noise for a screen reader user
  // - keyboard only user can toggle through tabs with left/right arrow keys already
  // eslint-disable-next-line jsx-a11y/click-events-have-key-events, jsx-a11y/no-static-element-interactions
  React__default.default.createElement("div", {
    onClick: function () {
      return handleArrowPress('left');
    },
    className: TabList_module.leftArrow,
    "data-testid": testId ? "".concat(testId, "-kz-tablist-left-arrow") : undefined
  }, React__default.default.createElement(Icon.Icon, {
    name: "chevron_left",
    isPresentational: true
  })), React__default.default.createElement(reactAriaComponents.TabList, tslib.__assign({
    "aria-label": ariaLabel,
    ref: tabListRef,
    className: classnames__default.default(TabList_module.tabList, className, noPadding && TabList_module.noPadding)
  }, restProps), children), rightArrowEnabled &&
  // eslint-disable-next-line jsx-a11y/click-events-have-key-events, jsx-a11y/no-static-element-interactions
  React__default.default.createElement("div", {
    onClick: function () {
      return handleArrowPress('right');
    },
    className: TabList_module.rightArrow,
    "data-testid": testId ? "".concat(testId, "-kz-tablist-right-arrow") : undefined
  }, React__default.default.createElement(Icon.Icon, {
    name: "chevron_right",
    isPresentational: true
  })));
};
exports.TabList = TabList;
