import { __rest, __assign } from 'tslib';
import React, { useState, useRef, useEffect } from 'react';
import classnames from 'classnames';
import { Textfit } from 'react-textfit';
import { Icon } from '../__next__/Icon/Icon.mjs';
import styles from './Avatar.module.css.mjs';
var getInitials = function (fullName, max2Characters) {
  if (max2Characters === void 0) {
    max2Characters = false;
  }
  return fullName == null ? '' : fullName.split(/\s/).reduce(function (acc, name) {
    return "".concat(acc).concat(name.slice(0, 1));
  }, '').toUpperCase().substring(0, max2Characters ? 2 : 8);
};
var getMaxFontSizePixels = function (size) {
  if (size === 'small') return 8;
  if (size === 'medium') return 16;
  if (size === 'xlarge' || size === 'xxlarge') return 34;
  return 22;
};
var FallbackIcon = function (_a) {
  var alt = _a.alt;
  if (alt) {
    return /*#__PURE__*/React.createElement(Icon, {
      name: "person",
      alt: alt,
      isFilled: true,
      className: styles.fallbackIcon
    });
  }
  return /*#__PURE__*/React.createElement(Icon, {
    name: "person",
    isPresentational: true,
    isFilled: true,
    className: styles.fallbackIcon
  });
};
var renderInitials = function (fullName, alt, size, disableInitials) {
  if (fullName === void 0) {
    fullName = '';
  }
  if (disableInitials === void 0) {
    disableInitials = false;
  }
  var initials = getInitials(fullName);
  var isLongName = initials.length > 2 && size !== 'small';
  var renderFallback = disableInitials || initials === '';
  return renderFallback ? (/*#__PURE__*/React.createElement(FallbackIcon, {
    alt: alt
  })) : (/*#__PURE__*/React.createElement("abbr", {
    className: classnames(styles.initials, isLongName && styles.longName),
    title: alt
  }, isLongName ? (
  /*#__PURE__*/
  // Only called if 3 or more initials, fits text width for long names
  React.createElement(Textfit, {
    mode: "single",
    max: getMaxFontSizePixels(size)
  }, initials)) : getInitials(fullName, size === 'small')));
};
/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3064857475/Avatar Guidance} |
 * {@link https://cultureamp.design/?path=/docs/components-avatar-avatar--docs Storybook}
 */
var Avatar = function (_a) {
  var fullName = _a.fullName,
    _b = _a.size,
    size = _b === void 0 ? 'medium' : _b,
    avatarSrc = _a.avatarSrc,
    _c = _a.disableInitials,
    disableInitials = _c === void 0 ? false : _c,
    _d = _a.isCompany,
    isCompany = _d === void 0 ? false : _d,
    _e = _a.isCurrentUser,
    isCurrentUser = _e === void 0 ? true : _e,
    _f = _a.alt,
    alt = _f === void 0 ? fullName !== null && fullName !== void 0 ? fullName : '' : _f,
    classNameOverride = _a.classNameOverride,
    restProps = __rest(_a, ["fullName", "size", "avatarSrc", "disableInitials", "isCompany", "isCurrentUser", "alt", "classNameOverride"]);
  var _g = useState(avatarSrc ? 'loading' : 'none'),
    avatarState = _g[0],
    setAvatarState = _g[1];
  var image = useRef(null);
  var renderInitialAvatar = !isCompany && (avatarState === 'none' || avatarState === 'error');
  useEffect(function () {
    setAvatarState(avatarSrc ? 'loading' : 'none');
  }, [avatarSrc]);
  var onImageFailure = function () {
    return setAvatarState('error');
  };
  var onImageSuccess = function () {
    return setAvatarState('success');
  };
  // if the image is cached onLoad may not trigger: https://stackoverflow.com/a/59809184
  useEffect(function () {
    var _a;
    if ((_a = image === null || image === void 0 ? void 0 : image.current) === null || _a === void 0 ? void 0 : _a.complete) onImageSuccess();
  }, [image]);
  var isNoneOrError = avatarState === 'none' || avatarState === 'error';
  var isPersonal = isNoneOrError && isCurrentUser;
  var isOtherUser = isNoneOrError && !isCurrentUser;
  return /*#__PURE__*/React.createElement("span", __assign({
    className: classnames(styles.wrapper, styles[size], classNameOverride, isCompany && styles.company, isPersonal && styles.personal, isOtherUser && styles.otherUser)
  }, restProps), avatarState !== 'none' && (/*#__PURE__*/React.createElement("img", {
    ref: image,
    className: classnames(styles.avatarImage, isCompany && styles.companyAvatarImage, (avatarState === 'loading' || avatarState === 'error') && styles.loading),
    src: avatarSrc,
    onError: onImageFailure,
    onLoad: onImageSuccess,
    alt: alt
  })), renderInitialAvatar && renderInitials(fullName, alt, size, disableInitials));
};
export { Avatar };
