import { __rest, __assign } from 'tslib';
import React from 'react';
import classnames from 'classnames';
import { Button } from '../Button/Button/Button.mjs';
import '../Button/IconButton/IconButton.mjs';
import { Heading } from '../Heading/Heading.mjs';
import { Text } from '../Text/Text.mjs';
import { assetUrl } from '../utils/hostedAssets.mjs';
import { useMediaQueries } from '../utils/useMediaQueries.mjs';
import styles from './BrandMoment.module.css.mjs';

/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3082061589/Brand+Moment Guidance} |
 * {@link https://cultureamp.design/?path=/docs/components-brand-moment--docs Storybook}
 */
const BrandMoment = /*#__PURE__*/function () {
  const BrandMoment = function (_a) {
    var mood = _a.mood,
      variant = _a.variant,
      illustration = _a.illustration,
      header = _a.header,
      body = _a.body,
      primaryAction = _a.primaryAction,
      secondaryAction = _a.secondaryAction,
      text = _a.text,
      classNameOverride = _a.classNameOverride,
      restProps = __rest(_a, ["mood", "variant", "illustration", "header", "body", "primaryAction", "secondaryAction", "text", "classNameOverride"]);
    var queries = useMediaQueries().queries;
    return /*#__PURE__*/React.createElement("div", __assign({
      className: classnames(styles.body, variant ? styles[variant] : styles[mood], classNameOverride)
    }, restProps), /*#__PURE__*/React.createElement("header", {
      className: styles.header
    }, header), /*#__PURE__*/React.createElement("main", {
      className: styles.main
    }, /*#__PURE__*/React.createElement("div", {
      className: styles.container
    }, /*#__PURE__*/React.createElement("div", {
      className: styles.mainInner
    }, /*#__PURE__*/React.createElement("div", {
      className: styles.left
    }, /*#__PURE__*/React.createElement("div", {
      className: styles.leftInner
    }, illustration)), /*#__PURE__*/React.createElement("div", {
      className: styles.right
    }, /*#__PURE__*/React.createElement("div", {
      className: styles.rightInner
    }, text.subtitle && (/*#__PURE__*/React.createElement(Heading, {
      variant: "heading-3",
      tag: "h1",
      classNameOverride: styles.subtitle
    }, text.subtitle)), /*#__PURE__*/React.createElement(Heading, {
      variant: "display-0",
      tag: text.subtitle ? 'h2' : 'h1',
      classNameOverride: styles.title
    }, text.title), text.body && (/*#__PURE__*/React.createElement(Text, {
      variant: "intro-lede",
      classNameOverride: styles.textBody
    }, text.body)), body && /*#__PURE__*/React.createElement("div", {
      className: styles.textBody
    }, body), /*#__PURE__*/React.createElement("div", {
      className: styles.actions
    }, primaryAction && (/*#__PURE__*/React.createElement(Button, __assign({
      primary: true,
      fullWidth: queries.isSmall
    }, primaryAction))), secondaryAction && (/*#__PURE__*/React.createElement("div", {
      className: styles.secondaryAction
    }, /*#__PURE__*/React.createElement(Button, __assign({
      secondary: true,
      fullWidth: queries.isSmall
    }, secondaryAction)))))))))), text.footer && (/*#__PURE__*/React.createElement("footer", {
      className: styles.footer
    }, /*#__PURE__*/React.createElement("div", {
      className: styles.container
    }, /*#__PURE__*/React.createElement("div", {
      className: styles.footerInner
    }, /*#__PURE__*/React.createElement("div", {
      className: styles.poweredByContainer
    }, /*#__PURE__*/React.createElement(Text, {
      variant: "extra-small",
      color: "dark-reduced-opacity"
    }, "Powered by"), /*#__PURE__*/React.createElement("a", {
      href: "https://www.cultureamp.com",
      className: styles.poweredByLogo
    }, /*#__PURE__*/React.createElement("img", {
      src: assetUrl('brand/logo-horizontal-default.svg'),
      alt: "Culture Amp"
    }))), /*#__PURE__*/React.createElement("div", {
      className: styles.footerTextContainer
    }, /*#__PURE__*/React.createElement(Text, {
      variant: "extra-small"
    }, text.footer)))))));
  };
  BrandMoment.displayName = 'BrandMoment';
  return BrandMoment;
}();
export { BrandMoment };
