import { __rest, __assign } from 'tslib';
import React, { useState, useEffect } from 'react';
import { useFloating, autoUpdate, size, offset, autoPlacement } from '@floating-ui/react-dom';
import classnames from 'classnames';
import styles from './CalendarPopover.module.scss.mjs';

/**
 * Only for use with Calendar components.
 * @todo: Replace with Popover when we have a reusable one.
 */
const CalendarPopover = /*#__PURE__*/function () {
  const CalendarPopover = function (_a) {
    var children = _a.children,
      referenceElement = _a.referenceElement,
      floatingOptions = _a.floatingOptions,
      classNameOverride = _a.classNameOverride,
      restProps = __rest(_a, ["children", "referenceElement", "floatingOptions", "classNameOverride"]);
    var _b = useState(null),
      floatingElement = _b[0],
      setFloatingElement = _b[1];
    var _c = useFloating(__assign({
        placement: 'bottom-start',
        elements: {
          reference: referenceElement,
          floating: floatingElement
        },
        strategy: 'fixed',
        middleware: [size({
          apply: function (_a) {
            var availableHeight = _a.availableHeight,
              availableWidth = _a.availableWidth,
              elements = _a.elements;
            Object.assign(elements.floating.style, {
              // 155 is enough of a minimum to cut off half of the second row of dates.
              // This indicates to users that there is more content that is scrollable
              maxHeight: "".concat(Math.max(availableHeight - 25, 155), "px"),
              maxWidth: "".concat(availableWidth, "px")
            });
          }
        }), offset(15), autoPlacement({
          allowedPlacements: ['bottom-start', 'bottom', 'top-start', 'top']
        })],
        whileElementsMounted: autoUpdate
      }, floatingOptions)),
      floatingStyles = _c.floatingStyles,
      update = _c.update;
    useEffect(function () {
      var _a;
      if (floatingElement && referenceElement) {
        // @ts-expect-error this can be removed when we update to react 19
        referenceElement.popoverTargetElement = floatingElement;
        (_a = floatingElement.showPopover) === null || _a === void 0 ? void 0 : _a.call(floatingElement);
        update();
      }
    }, [referenceElement, floatingElement, update]);
    return /*#__PURE__*/React.createElement("div", __assign({
      ref: setFloatingElement,
      style: floatingStyles,
      className: classnames(styles.calendarPopover, classNameOverride),
      role: "dialog",
      "aria-modal": "true",
      // @ts-expect-error this can be removed when we update to react 19
      popover: "manual"
    }, restProps), children);
  };
  CalendarPopover.displayName = 'CalendarPopover';
  return CalendarPopover;
}();
export { CalendarPopover };
