import { __rest, __assign } from 'tslib';
import React, { useRef, useId, useState } from 'react';
import classnames from 'classnames';
import { enUS } from 'date-fns/locale';
import { isMatch } from 'react-day-picker';
import { FocusOn } from 'react-focus-on';
import '../Calendar/CalendarSingle/CalendarSingle.mjs';
import '../Calendar/CalendarRange/CalendarRange.mjs';
import { calculateDisabledDays } from '../Calendar/utils/calculateDisabledDays.mjs';
import 'date-fns';
import { isDisabledDate } from '../Calendar/utils/isDisabledDate.mjs';
import { CalendarPopover } from '../Calendar/CalendarPopover/CalendarPopover.mjs';
import { LegacyCalendarRange } from '../Calendar/LegacyCalendarRange/LegacyCalendarRange.mjs';
import { Label } from '../Label/Label.mjs';
import { VisuallyHidden } from '../VisuallyHidden/VisuallyHidden.mjs';
import { Icon } from '../__next__/Icon/Icon.mjs';
import styles from './DateRangePicker.module.scss.mjs';

/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3082094237/Date+Range+Picker Guidance} |
 * {@link https://cultureamp.design/storybook/?path=/docs/components-date-controls-daterangepicker--docs Storybook}
 */
const DateRangePicker = /*#__PURE__*/function () {
  const DateRangePicker = function (_a) {
    var _b;
    var propsId = _a.id,
      buttonRef = _a.buttonRef;
    _a.description; // not used
    var labelText = _a.labelText,
      _c = _a.isDisabled,
      isDisabled = _c === void 0 ? false : _c,
      classNameOverride = _a.classNameOverride,
      disabledDates = _a.disabledDates,
      disabledDaysOfWeek = _a.disabledDaysOfWeek,
      disabledRange = _a.disabledRange,
      disabledBeforeAfter = _a.disabledBeforeAfter,
      disabledBefore = _a.disabledBefore,
      disabledAfter = _a.disabledAfter,
      weekStartsOn = _a.weekStartsOn,
      defaultMonth = _a.defaultMonth,
      selectedDateRange = _a.selectedDateRange,
      value = _a.value,
      onChange = _a.onChange,
      inputProps = __rest(_a, ["id", "buttonRef", "description", "labelText", "isDisabled", "classNameOverride", "disabledDates", "disabledDaysOfWeek", "disabledRange", "disabledBeforeAfter", "disabledBefore", "disabledAfter", "weekStartsOn", "defaultMonth", "selectedDateRange", "value", "onChange"]);
    var fallbackRef = useRef(null);
    var ref = buttonRef !== null && buttonRef !== void 0 ? buttonRef : fallbackRef;
    var reactId = useId();
    var id = propsId !== null && propsId !== void 0 ? propsId : reactId;
    var containerRef = useRef(null);
    var _d = useState(false),
      isOpen = _d[0],
      setIsOpen = _d[1];
    var disabledDays = calculateDisabledDays({
      disabledDates: disabledDates,
      disabledDaysOfWeek: disabledDaysOfWeek,
      disabledRange: disabledRange,
      disabledBeforeAfter: disabledBeforeAfter,
      disabledBefore: disabledBefore,
      disabledAfter: disabledAfter
    });
    var handleOpenClose = function () {
      setIsOpen(!isOpen);
    };
    var handleReturnFocus = function () {
      if (ref.current) {
        ref.current.focus();
      }
    };
    var handleDayClick = function (day) {
      /** react-day-picker will fire events for disabled days by default.
       *  We're checking here if it includes the CSS Modules class for disabled
       *  on the modifier to then return early.
       * */
      if (isDisabledDate(day, disabledDays)) {
        return;
      }
      if (!selectedDateRange) return;
      /** If user has already selected range and then selects again, treat first
       * click as the start of the new range.
       *  */
      if (isSelectingFirstDay(selectedDateRange, day)) {
        onChange({
          from: day,
          to: undefined
        });
      } else {
        // Otherwise, treat click as the final selection.
        onChange({
          from: selectedDateRange.from,
          to: day
        });
        handleOpenClose();
      }
    };
    var isSelectingFirstDay = function (range, day) {
      var isBeforeFirstDay = !!range.from && isMatch(day, [{
        before: range.from
      }]);
      var isRangeSelected = !!range.from && !!range.to;
      return !range.from || isBeforeFirstDay || isRangeSelected;
    };
    return /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement("div", {
      ref: containerRef,
      className: classNameOverride
    }, /*#__PURE__*/React.createElement(Label, {
      id: "".concat(id, "-input-label"),
      disabled: isDisabled,
      htmlFor: id,
      labelText: labelText
    }), /*#__PURE__*/React.createElement("button", __assign({
      type: "button",
      id: id,
      className: classnames(styles.button, styles.withStartIconAdornment, (_b = {}, _b[styles.disabled] = isDisabled, _b)),
      disabled: isDisabled,
      ref: ref,
      onClick: handleOpenClose,
      "aria-label": (selectedDateRange === null || selectedDateRange === void 0 ? void 0 : selectedDateRange.from) ? "Change date: ".concat(value) : 'Choose date'
    }, inputProps), /*#__PURE__*/React.createElement("div", {
      className: styles.startIconAdornment
    }, /*#__PURE__*/React.createElement(Icon, {
      name: "today",
      isPresentational: true,
      isFilled: true
    })), /*#__PURE__*/React.createElement("span", {
      className: styles.value
    }, (selectedDateRange === null || selectedDateRange === void 0 ? void 0 : selectedDateRange.from) ? value : undefined))), isOpen && (/*#__PURE__*/React.createElement(FocusOn, {
      scrollLock: false,
      onDeactivation: handleReturnFocus,
      onClickOutside: handleOpenClose,
      onEscapeKey: handleOpenClose,
      enabled: isOpen
    }, /*#__PURE__*/React.createElement(CalendarPopover, {
      referenceElement: containerRef.current,
      "aria-labelledby": "".concat(id, "-calendar-label ").concat(id, "-input-label")
    }, /*#__PURE__*/React.createElement(VisuallyHidden, {
      id: "".concat(id, "-calendar-label")
    }, "Select dates from calendar for:"), /*#__PURE__*/React.createElement(LegacyCalendarRange, {
      selectedRange: selectedDateRange,
      defaultMonth: defaultMonth,
      weekStartsOn: weekStartsOn,
      disabledDays: disabledDays,
      onDayChange: handleDayClick,
      locale: enUS
    })))));
  };
  DateRangePicker.displayName = 'DateRangePicker';
  return DateRangePicker;
}();
export { DateRangePicker };
