import { __rest, __assign } from 'tslib';
import React from 'react';
import classnames from 'classnames';
import { Heading } from '../Heading/Heading.mjs';
import '../Illustration/subcomponents/Base/Base.mjs';
import '../Illustration/Scene/BrandMomentCaptureIntro/BrandMomentCaptureIntro.mjs';
import { EmptyStatesNegative, EmptyStatesNeutral, EmptyStatesPositive, EmptyStatesInformative } from '../Illustration/Scene/Scene.mjs';
import { Text } from '../Text/Text.mjs';
import styles from './EmptyState.module.css.mjs';
var ILLUSTRATIONS = {
  'success': EmptyStatesPositive,
  'warning': EmptyStatesNegative,
  'informative': EmptyStatesInformative,
  'expert-advice': EmptyStatesNeutral,
  /** @deprecated Replaced by success */
  'positive': EmptyStatesPositive,
  /** @deprecated Replaced by expert-advice */
  'neutral': EmptyStatesNeutral,
  /** @deprecated Replaced by warning */
  'negative': EmptyStatesNegative,
  /** @deprecated Replaced by warning */
  'action': EmptyStatesNegative
};
/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3082094098/Empty+State Guidance} |
 * {@link https://cultureamp.design/?path=/docs/components-empty-state--docs Storybook}
 */
const EmptyState = /*#__PURE__*/function () {
  const EmptyState = function (_a) {
    var children = _a.children,
      id = _a.id,
      illustrationType = _a.illustrationType,
      _b = _a.variant,
      variant = _b === void 0 ? 'informative' : _b;
    _a.layoutContext;
    var headingProps = _a.headingProps,
      bodyText = _a.bodyText,
      straightCorners = _a.straightCorners,
      _c = _a.isAnimated,
      isAnimated = _c === void 0 ? true : _c,
      _d = _a.loop,
      loop = _d === void 0 ? false : _d,
      classNameOverride = _a.classNameOverride,
      props = __rest(_a, ["children", "id", "illustrationType", "variant", "layoutContext", "headingProps", "bodyText", "straightCorners", "isAnimated", "loop", "classNameOverride"]);
    var IllustrationComponent = ILLUSTRATIONS[illustrationType !== null && illustrationType !== void 0 ? illustrationType : variant];
    return /*#__PURE__*/React.createElement("div", __assign({
      className: classnames(styles.container, illustrationType ? styles[illustrationType] : styles[variant], straightCorners && styles.straightCorners, classNameOverride),
      id: id
    }, props), /*#__PURE__*/React.createElement("div", {
      className: styles.content
    }, /*#__PURE__*/React.createElement("div", {
      className: styles.illustrationContainer
    }, isAnimated ? (/*#__PURE__*/React.createElement(IllustrationComponent, {
      isAnimated: true,
      loop: loop,
      classNameOverride: styles.illustration
    })) : (/*#__PURE__*/React.createElement(IllustrationComponent, {
      classNameOverride: styles.illustration
    }))), /*#__PURE__*/React.createElement("div", {
      className: styles.textContainer
    }, headingProps && /*#__PURE__*/React.createElement(Heading, __assign({
      classNameOverride: styles.heading
    }, headingProps)), /*#__PURE__*/React.createElement(Text, {
      variant: "body"
    }, bodyText), children && /*#__PURE__*/React.createElement("span", null, children))));
  };
  EmptyState.displayName = 'EmptyState';
  return EmptyState;
}();
export { EmptyState };
