import { __rest, __assign } from 'tslib';
import React, { useState, useRef, useEffect } from 'react';
import { FilterMultiSelect } from '../../../FilterMultiSelect/FilterMultiSelect.mjs';
import '../../../FilterMultiSelect/context/MenuTriggerProvider/MenuTriggerProvider.mjs';
import '../../../FilterMultiSelect/context/SelectionProvider/SelectionProvider.mjs';
import { getSelectedOptionLabels } from '../../../FilterMultiSelect/utils/getSelectedOptionLabels.mjs';
import { useFilterBarContext } from '../../context/FilterBarContext.mjs';
import { checkArraysMatch } from '../../utils/checkArraysMatch.mjs';
import styles from './FilterBarMultiSelect.module.css.mjs';
var convertSelectionToAConsumableFormat = function (value) {
  if (value === 'all') return 'all';
  var arrayOfValues = Array.from(value);
  return arrayOfValues.length > 0 ? Array.from(value) : undefined;
};
var convertConsumableFormatIntoSelection = function (value) {
  return new Set(value);
};
const FilterBarMultiSelect = /*#__PURE__*/function () {
  const FilterBarMultiSelect = function (_a) {
    var _b;
    var id = _a.id,
      propsItems = _a.items,
      children = _a.children,
      onSelectionChange = _a.onSelectionChange,
      props = __rest(_a, ["id", "items", "children", "onSelectionChange"]);
    var _c = useFilterBarContext(),
      getFilterState = _c.getFilterState,
      setFilterOpenState = _c.setFilterOpenState,
      updateValue = _c.updateValue,
      hideFilter = _c.hideFilter,
      focusId = _c.focusId,
      setFocus = _c.setFocus;
    var _d = useState(propsItems),
      items = _d[0],
      setItems = _d[1];
    var buttonRef = useRef(null);
    if (!id) throw Error('Missing `id` prop in FilterBarMultiSelect');
    var filterState = getFilterState(id);
    useEffect(function () {
      if (!checkArraysMatch(items, propsItems)) {
        setItems(propsItems);
      }
      // We only want to run this effect when propsItems changes
      // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [propsItems]);
    useEffect(function () {
      if (Array.isArray(filterState.value)) {
        var itemValues_1 = items.map(function (_a) {
          var value = _a.value;
          return value;
        });
        var filteredValues = filterState.value.filter(function (value) {
          return itemValues_1.includes(value);
        });
        if (!checkArraysMatch(filterState.value, filteredValues)) {
          updateValue(id, filteredValues);
        }
      }
      // We only want to run this effect when items changes
      // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [items]);
    useEffect(function () {
      var _a;
      if (focusId === id) {
        (_a = buttonRef.current) === null || _a === void 0 ? void 0 : _a.focus();
        setFocus(undefined);
      }
    }, [focusId, id, setFocus]);
    return /*#__PURE__*/React.createElement(FilterMultiSelect, __assign({
      label: filterState.name,
      // Convert the incoming FilterBar state to a Set (internal FilterMultiSelect state)
      selectedKeys: new Set((_b = filterState.value) !== null && _b !== void 0 ? _b : null),
      onSelectionChange: function (keys) {
        // Convert the internal FilterMultiSelect state (Set) to an Array for FilterBar state
        updateValue(id, convertSelectionToAConsumableFormat(keys));
        onSelectionChange === null || onSelectionChange === void 0 ? void 0 : onSelectionChange(keys);
      },
      items: items,
      isOpen: filterState.isOpen,
      onOpenChange: function (open) {
        return setFilterOpenState(id, open);
      },
      className: styles.filterMultiSelect,
      trigger: function () {
        var triggerProps = {
          selectedOptionLabels: filterState.value ? getSelectedOptionLabels(convertConsumableFormatIntoSelection(filterState.value), items) : [],
          label: filterState.name
        };
        return filterState.isRemovable ? (/*#__PURE__*/React.createElement(FilterMultiSelect.RemovableTrigger, __assign({}, triggerProps, {
          onRemove: function () {
            return hideFilter(id);
          },
          classNameOverride: styles.triggerButton
        }))) : (/*#__PURE__*/React.createElement(FilterMultiSelect.TriggerButton, __assign({
          classNameOverride: styles.triggerButton
        }, triggerProps)));
      },
      triggerRef: buttonRef
    }, props), children);
  };
  FilterBarMultiSelect.displayName = 'FilterBar.MultiSelect';
  return FilterBarMultiSelect;
}();
export { FilterBarMultiSelect };
