import { __rest, __assign } from 'tslib';
import React, { useId, useReducer, useEffect } from 'react';
import classnames from 'classnames';
import { CalendarSingle } from '../../../../Calendar/CalendarSingle/CalendarSingle.mjs';
import '../../../../Calendar/CalendarRange/CalendarRange.mjs';
import 'date-fns';
import { isInvalidDate } from '../../../../Calendar/utils/isInvalidDate.mjs';
import 'react-day-picker';
import { getLocale } from '../../../../DatePicker/utils/getLocale.mjs';
import { useDateValidation } from '../../hooks/useDateValidation.mjs';
import { transformDateToInputValue } from '../../utils/transformDateToInputValue.mjs';
import { useDateInputHandlers } from '../../hooks/useDateInputHandlers.mjs';
import { DateInputField } from '../DateInputField/DateInputField.mjs';
import { filterDatePickerFieldReducer } from './filterDatePickerFieldReducer.mjs';
import styles from './FilterDatePickerField.module.scss.mjs';
var FilterDatePickerField = function (_a) {
  var propsId = _a.id,
    inputProps = _a.inputProps,
    propsLocale = _a.locale,
    defaultMonth = _a.defaultMonth,
    selectedDate = _a.selectedDate,
    onDateChange = _a.onDateChange,
    onDateSubmit = _a.onDateSubmit,
    disabledDays = _a.disabledDays,
    description = _a.description,
    validationMessage = _a.validationMessage,
    onValidate = _a.onValidate,
    classNameOverride = _a.classNameOverride,
    restProps = __rest(_a, ["id", "inputProps", "locale", "defaultMonth", "selectedDate", "onDateChange", "onDateSubmit", "disabledDays", "description", "validationMessage", "onValidate", "classNameOverride"]);
  var reactId = useId();
  var id = propsId !== null && propsId !== void 0 ? propsId : reactId;
  var locale = getLocale(propsLocale);
  var dateValidation = useDateValidation({
    disabledDays: disabledDays,
    validationMessage: validationMessage,
    onValidate: onValidate
  });
  var validateDate = function (date, inputValue) {
    var _a = dateValidation.validateDate({
        date: date,
        inputValue: inputValue
      }),
      validationResponse = _a.validationResponse,
      newDate = _a.newDate;
    dateValidation.updateValidation(validationResponse);
    return newDate;
  };
  var _b = useReducer(filterDatePickerFieldReducer, {
      selectedDate: selectedDate,
      inputValue: transformDateToInputValue(selectedDate, disabledDays, locale) || '',
      startMonth: selectedDate && !isInvalidDate(selectedDate) ? selectedDate : defaultMonth !== null && defaultMonth !== void 0 ? defaultMonth : new Date()
    }),
    state = _b[0],
    dispatch = _b[1];
  var handleDateChange = function (date) {
    onDateChange(date);
  };
  var inputDateHandlers = useDateInputHandlers(__assign({
    locale: locale,
    disabledDays: disabledDays,
    setInputValue: function (value) {
      dispatch({
        type: 'update_input_field',
        inputValue: value
      });
    },
    onDateChange: function (date) {
      // Because the input value is being tracked in the state as the user types
      // we can reliably utilise state.inputValue as part of the validation message,
      // which is triggered by `onBlur` function
      var newDate = validateDate(date, state.inputValue);
      dispatch({
        type: 'update_selected_date',
        date: newDate
      });
      handleDateChange(newDate);
    },
    onDateSubmit: function (date) {
      // Only provide consumers with a valid date to the `onDateSubmit` function
      if (!isInvalidDate(date)) {
        onDateSubmit === null || onDateSubmit === void 0 ? void 0 : onDateSubmit(date);
      }
    }
  }, inputProps));
  var handleCalendarSelect = function (date) {
    // Transforming the date to an InputValue and validating the date with the result
    // can operate in this order because we are guaranteed a valid date from the calendar.
    //
    // In all other scenarios, this won't work as the return string from an invalid date
    // would be "Invalid Date" and not the actual value entered by the user since we want
    // the final error message to use the typed word from the user.
    var inputValue = transformDateToInputValue(date, disabledDays, locale);
    var newDate = validateDate(date, inputValue);
    dispatch({
      type: 'update_selected_date',
      date: newDate
    });
    dispatch({
      type: 'update_input_field',
      inputValue: inputValue
    });
    handleDateChange(newDate);
    onDateSubmit === null || onDateSubmit === void 0 ? void 0 : onDateSubmit(newDate);
  };
  useEffect(function () {
    validateDate(selectedDate, state.inputValue);
    // We only want to validate on first render - subsequent validations are handled by the input handlers
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);
  return /*#__PURE__*/React.createElement("div", __assign({
    className: classnames(styles.filterDatePickerField, classNameOverride)
  }, restProps), /*#__PURE__*/React.createElement(DateInputField, __assign({
    id: "".concat(id, "--input"),
    locale: locale,
    value: state.inputValue,
    description: description,
    validationMessage: dateValidation.validationMessage
  }, inputDateHandlers, inputProps)), /*#__PURE__*/React.createElement(CalendarSingle, {
    disabled: disabledDays,
    locale: locale,
    selected: state.selectedDate,
    onSelect: handleCalendarSelect,
    month: state.startMonth,
    onMonthChange: function (value) {
      return dispatch({
        type: 'navigate_months',
        date: value
      });
    }
  }));
};
export { FilterDatePickerField };
