import { __rest, __assign } from 'tslib';
import React, { useState, useCallback, useContext } from 'react';
import { useListBox } from '@react-aria/listbox';
import { Item } from '@react-stately/collections';
import { useListState } from '@react-stately/list';
import { VisuallyHidden } from '../../../../VisuallyHidden/VisuallyHidden.mjs';
import { useMenuTriggerContext } from '../MenuTriggerProvider/MenuTriggerProvider.mjs';
var SelectionContext = /*#__PURE__*/React.createContext({});
var SelectionProvider = function (props) {
  var onSearchInputChange = props.onSearchInputChange,
    otherProps = __rest(props, ["onSearchInputChange"]);
  var _a = useState(''),
    searchQuery = _a[0],
    setSearchQuery = _a[1];
  var menuProps = useMenuTriggerContext().menuProps;
  /**
   * While the onSearchInputChange  is a side-effect, this useEffect should be fine.
   * If the search input state becomes controlled, this useEffect could cause synchronisation
   * issues and should be replaced.
   */
  React.useEffect(function () {
    if (onSearchInputChange) {
      onSearchInputChange(searchQuery);
    }
  }, [searchQuery, onSearchInputChange]);
  var searchFilter = useCallback(function (nodes) {
    return searchQuery ? Array.from(nodes).filter(function (f) {
      return f.textValue.toLowerCase().includes(searchQuery.toLowerCase());
    }) : nodes;
  }, [searchQuery]);
  // Create state based on the incoming props to manage the selection
  var state = useListState(__assign(__assign({}, otherProps), {
    children: function (item) {
      return /*#__PURE__*/React.createElement(Item, {
        key: item.value
      }, item.label);
    },
    filter: onSearchInputChange ? undefined : searchFilter
  }));
  // Get A11y attributes and events for the listbox
  var ref = /*#__PURE__*/React.createRef();
  var _b = useListBox(__assign(__assign(__assign({}, menuProps), otherProps), {
      disallowEmptySelection: true
    }), state, ref),
    listBoxProps = _b.listBoxProps,
    labelProps = _b.labelProps;
  return /*#__PURE__*/React.createElement(SelectionContext.Provider, {
    value: {
      listBoxProps: listBoxProps,
      labelProps: labelProps,
      selectionState: state,
      listRef: ref,
      setSearchQuery: setSearchQuery,
      searchQuery: searchQuery
    }
  }, /*#__PURE__*/React.createElement(VisuallyHidden, __assign({}, labelProps), otherProps.label), otherProps.children);
};
var useSelectionContext = function () {
  return useContext(SelectionContext);
};
var SelectionConsumer = function (_a) {
  var children = _a.children;
  return /*#__PURE__*/React.createElement(SelectionContext.Consumer, null, children);
};
export { SelectionConsumer, SelectionProvider, useSelectionContext };
