import { __assign, __spreadArray } from 'tslib';
import React, { useState, useEffect } from 'react';
import classnames from 'classnames';
import { useSelectionContext } from '../../context/SelectionProvider/SelectionProvider.mjs';
import styles from './ListBox.module.scss.mjs';
var getItemsFromKeys = function (items, keys) {
  var itemKeys = Array.from(keys);
  return itemKeys.reduce(function (acc, itemKey) {
    var item = items.getItem(itemKey);
    return item ? __spreadArray(__spreadArray([], acc, true), [item], false) : acc;
  }, []);
};
const ListBox = /*#__PURE__*/function () {
  const ListBox = function (_a) {
    var children = _a.children;
    var _b = useSelectionContext(),
      listBoxProps = _b.listBoxProps,
      listRef = _b.listRef,
      selectionState = _b.selectionState;
    var _c = useState(false),
      isOverflown = _c[0],
      setIsOverflown = _c[1];
    useEffect(function () {
      var listElement = listRef.current;
      if (!listElement) {
        return;
      }
      setIsOverflown(listElement.scrollHeight > listElement.clientHeight);
    }, [listRef]);
    var items = selectionState.collection,
      disabledKeys = selectionState.disabledKeys,
      selectedKeys = selectionState.selectionManager.selectedKeys;
    var disabledItems = getItemsFromKeys(items, disabledKeys);
    var selectedItems = getItemsFromKeys(items, selectedKeys);
    var unselectedItems = Array.from(items).filter(function (item) {
      return !disabledKeys.has(item.key) && !selectedKeys.has(item.key);
    });
    var allItems = Array.from(items);
    var hasNoItems = allItems.length === 0;
    var _d = useState({
        selectedItems: selectedItems,
        unselectedItems: unselectedItems,
        disabledItems: disabledItems,
        allItems: allItems,
        hasNoItems: hasNoItems
      }),
      itemsState = _d[0],
      setItemsState = _d[1];
    // Only update rendering of items when filtering.
    // Avoids re-ordering of items when making a selection
    useEffect(function () {
      setItemsState({
        selectedItems: selectedItems,
        disabledItems: disabledItems,
        unselectedItems: unselectedItems,
        allItems: allItems,
        hasNoItems: hasNoItems
      });
      // @todo: Fix if possible - avoiding breaking in eslint upgrade
      // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [selectionState.collection.size]);
    if (hasNoItems) {
      return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("div", {
        className: styles.noResultsWrapper
      }, children(itemsState)), /*#__PURE__*/React.createElement("ul", {
        ref: listRef,
        className: styles.hidden
      }));
    }
    return /*#__PURE__*/React.createElement("ul", __assign({}, listBoxProps, {
      ref: listRef,
      className: classnames(styles.listBox, isOverflown && styles.overflown)
    }), children(itemsState));
  };
  ListBox.displayName = 'FilterMultiSelect.ListBox';
  return ListBox;
}();
export { ListBox };
