import { __assign } from 'tslib';
import React from 'react';
import { FocusScope } from '@react-aria/focus';
import { useOverlay, DismissButton } from '@react-aria/overlays';
import { useMenuTriggerContext } from '../../context/MenuTriggerProvider/MenuTriggerProvider.mjs';
import '../../context/SelectionProvider/SelectionProvider.mjs';
import styles from './MenuPopup.module.scss.mjs';
const MenuPopup = /*#__PURE__*/function () {
  const MenuPopup = function (_a) {
    var isLoading = _a.isLoading,
      loadingSkeleton = _a.loadingSkeleton,
      children = _a.children;
    var menuTriggerState = useMenuTriggerContext().menuTriggerState;
    var onClose = function () {
      return menuTriggerState.close();
    };
    // Handle events that should cause the menu to close,
    // e.g. blur, clicking outside, or pressing the escape key.
    var overlayRef = /*#__PURE__*/React.createRef();
    var overlayProps = useOverlay({
      onClose: onClose,
      isOpen: menuTriggerState.isOpen,
      isDismissable: true
    }, overlayRef).overlayProps;
    // Wrap in <FocusScope> so that focus is restored back to the trigger when the menu is closed
    // and auto focus on the first focusable item after loading. (disable eslint no-autofocus error for it)
    // In addition, add hidden <DismissButton> components at the start and end of the list
    // to allow screen reader users to dismiss the popup easily.
    return menuTriggerState.isOpen ? (/*#__PURE__*/React.createElement("div", __assign({}, overlayProps, {
      ref: overlayRef,
      className: styles.menuPopup
    }), isLoading && loadingSkeleton ? (/*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(DismissButton, {
      onDismiss: onClose
    }), loadingSkeleton, /*#__PURE__*/React.createElement(DismissButton, {
      onDismiss: onClose
    }))) : (
    /*#__PURE__*/
    // eslint-disable-next-line jsx-a11y/no-autofocus
    React.createElement(FocusScope, {
      contain: true,
      autoFocus: true,
      restoreFocus: true
    }, /*#__PURE__*/React.createElement(DismissButton, {
      onDismiss: onClose
    }), children, /*#__PURE__*/React.createElement(DismissButton, {
      onDismiss: onClose
    }))))) : (/*#__PURE__*/React.createElement(React.Fragment, null));
  };
  MenuPopup.displayName = 'FilterMultiSelect.MenuPopup';
  return MenuPopup;
}();
export { MenuPopup };
