import { __assign } from 'tslib';
import React, { useId } from 'react';
import { useIntl, FormattedMessage } from '@cultureamp/i18n-react-intl';
import { useFocusRing } from '@react-aria/focus';
import { useOption } from '@react-aria/listbox';
import { mergeProps } from '@react-aria/utils';
import classnames from 'classnames';
import { Badge } from '../../../../Badge/Badge.mjs';
import { VisuallyHidden } from '../../../../VisuallyHidden/VisuallyHidden.mjs';
import { Icon } from '../../../../__next__/Icon/Icon.mjs';
import '../../context/MenuTriggerProvider/MenuTriggerProvider.mjs';
import { useSelectionContext } from '../../context/SelectionProvider/SelectionProvider.mjs';
import styles from './MultiSelectOption.module.scss.mjs';
const MultiSelectOption = /*#__PURE__*/function () {
  const MultiSelectOption = function (_a) {
    var _b, _c, _d;
    var classNameOverride = _a.classNameOverride,
      item = _a.item;
    var state = useSelectionContext().selectionState;
    // Get props for the option element
    var ref = /*#__PURE__*/React.createRef();
    var _e = useOption({
        key: item.key
      }, state, ref),
      optionProps = _e.optionProps,
      isSelected = _e.isSelected,
      isDisabled = _e.isDisabled;
    // Determine whether we should show a keyboard
    // focus ring for accessibility
    var _f = useFocusRing(),
      isFocusVisible = _f.isFocusVisible,
      focusProps = _f.focusProps;
    var countElementId = useId();
    var formatNumber = useIntl().formatNumber;
    return /*#__PURE__*/React.createElement("li", __assign({}, mergeProps(optionProps, focusProps), {
      ref: ref,
      className: classnames(styles.option, classNameOverride, isSelected && styles.isSelected, isFocusVisible && styles.isFocusVisible, isDisabled && styles.isDisabled),
      "aria-label": (_b = item.value) === null || _b === void 0 ? void 0 : _b.label,
      "aria-describedby": ((_c = item.value) === null || _c === void 0 ? void 0 : _c.count) ? countElementId : undefined
    }), /*#__PURE__*/React.createElement("span", {
      className: classnames(styles.icon, isSelected && styles.isSelected)
    }, isSelected && /*#__PURE__*/React.createElement(Icon, {
      name: "check",
      isPresentational: true
    })), item.rendered, ((_d = item.value) === null || _d === void 0 ? void 0 : _d.count) && (/*#__PURE__*/React.createElement("span", {
      id: countElementId,
      className: styles.badgeContainer
    }, /*#__PURE__*/React.createElement(FormattedMessage, {
      defaultMessage: "<Badge>{count}</Badge><VisuallyHidden> available</VisuallyHidden>",
      id: "filterMultiSelectMultiSelectOption.available",
      description: "Number of filter items available",
      values: {
        count: formatNumber(parseInt(item.value.count)),
        Badge: function (children) {
          return /*#__PURE__*/React.createElement(Badge, {
            classNameOverride: styles.badge
          }, children);
        },
        VisuallyHidden: function (children) {
          return /*#__PURE__*/React.createElement(VisuallyHidden, null, children);
        }
      }
    }))));
  };
  MultiSelectOption.displayName = 'FilterMultiSelect.Option';
  return MultiSelectOption;
}();
export { MultiSelectOption };
