import React from 'react';
import { FormattedMessage } from '@cultureamp/i18n-react-intl';
import classnames from 'classnames';
import { VisuallyHidden } from '../../../../../VisuallyHidden/VisuallyHidden.mjs';
import '../../../context/MenuTriggerProvider/MenuTriggerProvider.mjs';
import { useSelectionContext } from '../../../context/SelectionProvider/SelectionProvider.mjs';
import styles from '../SelectionControlButton.module.scss.mjs';
const ClearButton = /*#__PURE__*/function () {
  const ClearButton = function () {
    var selectionState = useSelectionContext().selectionState;
    var filteredOptions = Array.from(selectionState.collection.getKeys());
    var selectedOptions = Array.from(selectionState.selectionManager.selectedKeys);
    var isDisabled = filteredOptions.length === 0 || !filteredOptions.find(function (key) {
      return selectionState.selectionManager.isSelected(key);
    });
    return /*#__PURE__*/React.createElement("button", {
      type: "button",
      className: classnames(styles.button, isDisabled && styles.isDisabled),
      "aria-disabled": isDisabled,
      onClick: function () {
        if (!isDisabled) {
          selectionState.selectionManager.setSelectedKeys(selectedOptions.filter(function (option) {
            return !filteredOptions.includes(option);
          }));
        }
      }
    }, /*#__PURE__*/React.createElement(FormattedMessage, {
      defaultMessage: "Clear<VisuallyHidden> selections</VisuallyHidden>",
      id: "filterMultiSelectClearButton.label",
      description: "Clear button label for filter multi-select",
      values: {
        VisuallyHidden: function (children) {
          return /*#__PURE__*/React.createElement(VisuallyHidden, null, children);
        }
      }
    }));
  };
  ClearButton.displayName = 'FilterMultiSelect.ClearButton';
  return ClearButton;
}();
export { ClearButton };
