import { __rest, __assign } from 'tslib';
import React, { useState } from 'react';
import classnames from 'classnames';
import { Button } from '../Button/Button/Button.mjs';
import '../Button/IconButton/IconButton.mjs';
import { Heading } from '../Heading/Heading.mjs';
import { Text } from '../Text/Text.mjs';
import { Tooltip } from '../Tooltip/Tooltip.mjs';
import { useMediaQueries } from '../utils/useMediaQueries.mjs';
import styles from './GuidanceBlock.module.css.mjs';
import { Icon } from '../__next__/Icon/Icon.mjs';
var WithTooltip = function (_a) {
  var tooltipProps = _a.tooltipProps,
    children = _a.children;
  return tooltipProps ? /*#__PURE__*/React.createElement(Tooltip, __assign({}, tooltipProps), children) : /*#__PURE__*/React.createElement(React.Fragment, null, children);
};
/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3082093807/Guidance+Block Guidance} |
 * {@link https://cultureamp.design/?path=/docs/components-guidanceblock--docs Storybook}
 */
const GuidanceBlock = /*#__PURE__*/function () {
  const GuidanceBlock = function (_a) {
    var _b, _c, _d, _e, _f;
    var _g = _a.layout,
      layout = _g === void 0 ? 'default' : _g,
      _h = _a.variant,
      variant = _h === void 0 ? 'default' : _h,
      _j = _a.withActionButtonArrow,
      withActionButtonArrow = _j === void 0 ? true : _j,
      _k = _a.noMaxWidth,
      noMaxWidth = _k === void 0 ? false : _k,
      _l = _a.illustrationType,
      illustrationType = _l === void 0 ? 'spot' : _l,
      _m = _a.smallScreenTextAlignment,
      smallScreenTextAlignment = _m === void 0 ? 'center' : _m,
      actions = _a.actions,
      illustration = _a.illustration,
      secondaryDismiss = _a.secondaryDismiss,
      actionsSlot = _a.actionsSlot,
      restProps = __rest(_a, ["layout", "variant", "withActionButtonArrow", "noMaxWidth", "illustrationType", "smallScreenTextAlignment", "actions", "illustration", "secondaryDismiss", "actionsSlot"]);
    var _o = useState(false),
      hidden = _o[0],
      setHidden = _o[1];
    var _p = useState(false),
      removed = _p[0],
      setRemoved = _p[1];
    var queries = useMediaQueries().queries;
    var containerRef = /*#__PURE__*/React.createRef();
    var handleDismissBanner = function () {
      var _a;
      setHidden(true);
      (_a = actions === null || actions === void 0 ? void 0 : actions.dismiss) === null || _a === void 0 ? void 0 : _a.onClick();
    };
    var onTransitionEnd = function (e) {
      // Be careful: this assumes the final CSS property to be animated is "margin-top".
      if (hidden && e.propertyName === 'margin-top') {
        setRemoved(true);
      }
    };
    var marginTop = function () {
      if (hidden && containerRef.current) {
        return -containerRef.current.clientHeight + 'px';
      }
      return '0';
    };
    if (removed) {
      return /*#__PURE__*/React.createElement(React.Fragment, null);
    }
    return /*#__PURE__*/React.createElement("div", {
      className: classnames(styles.banner, variant && styles[variant], layout && styles[layout], hidden && styles.hidden, queries.isSmall && styles.centerContent, noMaxWidth && styles.noMaxWidth, illustrationType === 'scene' && styles.hasSceneIllustration, smallScreenTextAlignment === 'left' && styles.smallScreenTextAlignment),
      style: {
        marginTop: marginTop()
      },
      ref: containerRef,
      onTransitionEnd: onTransitionEnd
    }, /*#__PURE__*/React.createElement("div", {
      className: styles.illustrationWrapper
    }, /*#__PURE__*/React.createElement("div", {
      className: styles.illustration
    }, illustrationType === 'scene' ? /*#__PURE__*/React.cloneElement(illustration, {
      enableAspectRatio: true
    }) : illustration)), /*#__PURE__*/React.createElement("div", {
      className: styles.descriptionAndActions
    }, /*#__PURE__*/React.createElement("div", {
      className: styles.descriptionContainer
    }, 'content' in restProps && restProps.content, 'text' in restProps && (/*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("div", {
      className: styles.headingWrapper
    }, /*#__PURE__*/React.createElement(Heading, {
      tag: (_c = (_b = restProps === null || restProps === void 0 ? void 0 : restProps.text) === null || _b === void 0 ? void 0 : _b.titleTag) !== null && _c !== void 0 ? _c : 'h3',
      variant: "heading-3"
    }, (_d = restProps === null || restProps === void 0 ? void 0 : restProps.text) === null || _d === void 0 ? void 0 : _d.title)), /*#__PURE__*/React.createElement(Text, {
      tag: "p",
      variant: "body"
    }, (_e = restProps === null || restProps === void 0 ? void 0 : restProps.text) === null || _e === void 0 ? void 0 : _e.description)))), (actions === null || actions === void 0 ? void 0 : actions.primary) || actionsSlot ? (/*#__PURE__*/React.createElement("div", {
      className: styles.buttonContainer
    }, (actions === null || actions === void 0 ? void 0 : actions.primary) && (/*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(WithTooltip, {
      tooltipProps: actions.primary.tooltip
    }, /*#__PURE__*/React.createElement(Button, __assign({
      icon: withActionButtonArrow ? (/*#__PURE__*/React.createElement(Icon, {
        name: "arrow_forward",
        isPresentational: true,
        shouldMirrorInRTL: true
      })) : undefined,
      iconPosition: "end"
    }, actions.primary, {
      fullWidth: queries.isSmall
    }))), (actions === null || actions === void 0 ? void 0 : actions.secondary) && (/*#__PURE__*/React.createElement(WithTooltip, {
      tooltipProps: actions.secondary.tooltip
    }, /*#__PURE__*/React.createElement("div", {
      className: styles.secondaryAction
    }, /*#__PURE__*/React.createElement(Button, __assign({
      secondary: true
    }, actions.secondary, {
      onClick: secondaryDismiss ? function () {
        return handleDismissBanner();
      } : (_f = actions === null || actions === void 0 ? void 0 : actions.secondary) === null || _f === void 0 ? void 0 : _f.onClick,
      fullWidth: queries.isSmall
    }))))))), !actions && actionsSlot && actionsSlot)) : null));
  };
  GuidanceBlock.displayName = 'GuidanceBlock';
  return GuidanceBlock;
}();
export { GuidanceBlock };
