import React, { useState, createRef } from 'react';
import classnames from 'classnames';
import { FieldMessage } from '../FieldMessage/FieldMessage.mjs';
import { Text } from '../Text/Text.mjs';
import { Icon } from '../__next__/Icon/Icon.mjs';
import determineSelectionFromKeyPress from './utils/determineSelectionFromKeyPress.mjs';
import styles from './LikertScaleLegacy.module.scss.mjs';
var SelectedItemIcon = function () {
  return /*#__PURE__*/React.createElement(Icon, {
    name: "check",
    isPresentational: true,
    className: styles.check
  });
};
/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3082060201/Likert+Scale Guidance} |
 * {@link https://cultureamp.design/?path=/docs/components-likertscalelegacy--docs Storybook}
 */
var LikertScaleLegacy = function (_a) {
  var _b, _c;
  var scale = _a.scale,
    selectedItem = _a.selectedItem,
    reversed = _a.reversed,
    _d = _a.colorSchema,
    colorSchema = _d === void 0 ? 'classical' : _d,
    dataTestId = _a["data-testid"],
    onSelect = _a.onSelect,
    validationMessage = _a.validationMessage,
    status = _a.status,
    labelId = _a.labelId;
  var _e = useState(null),
    hoveredItem = _e[0],
    setHoveredItem = _e[1];
  var itemRefs = scale.map(function (s) {
    return {
      value: s.value,
      ref: /*#__PURE__*/createRef()
    };
  });
  var handleRadioClick = function (item) {
    var _a;
    // Is this a click on the item that is currently selected?
    var isClickOnSelectedItem = (selectedItem === null || selectedItem === void 0 ? void 0 : selectedItem.value) === item.value;
    // Grab "Not rated" state item from the scale, its value is -1
    var notYetRated = (_a = scale.find(function (s) {
      return s.value === -1;
    })) !== null && _a !== void 0 ? _a : null;
    // Clear or set new selection
    var newItem = isClickOnSelectedItem ? notYetRated : item;
    onSelect(newItem);
    setHoveredItem(null);
  };
  /**
   * Because the radios have been built with divs, we need to add the keyboard functionality manually
   */
  var handleKeyDown = function (event, focusedItem) {
    var _a, _b, _c;
    var newPosition = determineSelectionFromKeyPress(event.keyCode, selectedItem, focusedItem);
    if (newPosition) {
      event.preventDefault();
      onSelect((_a = scale.find(function (s) {
        return s.value === newPosition;
      })) !== null && _a !== void 0 ? _a : null);
      // Update focus
      var itemRef = itemRefs.find(function (item) {
        return item.value === newPosition;
      });
      (_c = (_b = itemRef === null || itemRef === void 0 ? void 0 : itemRef.ref) === null || _b === void 0 ? void 0 : _b.current) === null || _c === void 0 ? void 0 : _c.focus();
    }
  };
  var legend = (_c = (_b = hoveredItem === null || hoveredItem === void 0 ? void 0 : hoveredItem.label) !== null && _b !== void 0 ? _b : selectedItem === null || selectedItem === void 0 ? void 0 : selectedItem.label) !== null && _c !== void 0 ? _c : 'Not rated';
  var shouldDisplayValidationMessage = status !== 'default' && validationMessage !== undefined;
  var validationMessageId = shouldDisplayValidationMessage ? "".concat(labelId, "-field-validation-message") : undefined;
  var isRated = selectedItem && selectedItem.value > 0;
  return /*#__PURE__*/React.createElement("div", {
    className: classnames(styles.container, isRated && styles.rated, reversed && [styles.reversed], hoveredItem !== null && styles.hovered),
    "aria-labelledby": labelId,
    role: "radiogroup",
    tabIndex: -1,
    "aria-describedby": validationMessageId,
    "data-testid": dataTestId
  }, /*#__PURE__*/React.createElement("div", {
    className: styles.legend,
    "data-testid": dataTestId && "".concat(dataTestId, "-legend")
  }, /*#__PURE__*/React.createElement(Text, {
    variant: "small",
    color: reversed ? 'white' : 'dark'
  }, legend)), /*#__PURE__*/React.createElement("div", {
    className: classnames(styles.itemContainer, isRated && styles.rated, reversed && styles.reversed)
  }, scale.map(function (item) {
    if (item.value <= 0) {
      return;
    }
    var isSelectedItem = (selectedItem === null || selectedItem === void 0 ? void 0 : selectedItem.value) === item.value;
    var itemRef = itemRefs.find(function (i) {
      return item.value === i.value;
    });
    // Make control tabbable
    var tabIndex = 0;
    // Unless.. there's an item selected and it's not this one
    if (selectedItem && selectedItem.value > 0 && selectedItem.value !== item.value) {
      tabIndex = -1;
    }
    var isSelected = selectedItem && item.value <= (selectedItem === null || selectedItem === void 0 ? void 0 : selectedItem.value) && !hoveredItem;
    var isSuggested = hoveredItem && hoveredItem.value >= item.value;
    var isUnselected = selectedItem && selectedItem.value < item.value;
    return /*#__PURE__*/React.createElement("div", {
      className: classnames(styles.likertItem, colorSchema == 'blue' ? styles.blueColorSchema : styles.classicalColorSchema, styles["likertItem".concat(item.value)], isSelected && styles.selected, isSuggested && styles.suggested, isUnselected && styles.unselected),
      key: item.value,
      "data-testid": dataTestId && "".concat(dataTestId, "-item-").concat(item.value),
      onClick: function () {
        return handleRadioClick(item);
      },
      onMouseEnter: function () {
        return setHoveredItem(item);
      },
      onMouseLeave: function () {
        return setHoveredItem(null);
      },
      onKeyDown: function (event) {
        return handleKeyDown(event, item);
      },
      onFocus: function () {
        return setHoveredItem(item);
      },
      onBlur: function () {
        return setHoveredItem(null);
      },
      role: "radio",
      "aria-label": item.label,
      "aria-checked": isSelectedItem,
      "aria-posinset": item.value,
      "aria-setsize": 5,
      tabIndex: tabIndex,
      ref: itemRef === null || itemRef === void 0 ? void 0 : itemRef.ref
    }, /*#__PURE__*/React.createElement("div", {
      className: classnames(styles.likertItemFill, styles["field".concat(item.value)], isSelectedItem && styles.pop)
    }), isSelectedItem ? /*#__PURE__*/React.createElement(SelectedItemIcon, null) : null);
  })), shouldDisplayValidationMessage && (/*#__PURE__*/React.createElement(FieldMessage, {
    id: validationMessageId,
    message: validationMessage,
    status: status,
    reversed: reversed
  })));
};
export { LikertScaleLegacy };
