import { __rest, __assign } from 'tslib';
import React from 'react';
import classnames from 'classnames';
import { Heading } from '../../Heading/Heading.mjs';
import { Assertive, Positive, Negative, Informative, Cautionary } from '../../Illustration/Spot/Spot.mjs';
import '../../Illustration/Scene/BrandMomentCaptureIntro/BrandMomentCaptureIntro.mjs';
import '../../Illustration/Scene/Scene.mjs';
import { GenericModal } from '../GenericModal/GenericModal.mjs';
import '../GenericModal/context/ModalContext.mjs';
import { ModalAccessibleDescription } from '../GenericModal/subcomponents/ModalAccessibleDescription/ModalAccessibleDescription.mjs';
import { ModalFooter } from '../GenericModal/subcomponents/ModalFooter/ModalFooter.mjs';
import { ModalHeader } from '../GenericModal/subcomponents/ModalHeader/ModalHeader.mjs';
import { ModalAccessibleLabel } from '../GenericModal/subcomponents/ModalAccessibleLabel/ModalAccessibleLabel.mjs';
import { ModalBody } from '../GenericModal/subcomponents/ModalBody/ModalBody.mjs';
import { Icon } from '../../__next__/Icon/Icon.mjs';
import styles from './ConfirmationModal.module.scss.mjs';
var getIconName = function (variantName) {
  switch (variantName) {
    case 'cautionary':
      return 'warning';
    case 'informative':
      return 'info';
    case 'negative':
    case 'warning':
      return 'error';
    case 'positive':
    case 'success':
      return 'check_circle';
    case 'assertive':
      return 'error';
  }
};
var getIcon = function (variantName, isProminent) {
  if (isProminent) {
    switch (variantName) {
      case 'cautionary':
        return /*#__PURE__*/React.createElement(Cautionary, null);
      case 'informative':
        return /*#__PURE__*/React.createElement(Informative, null);
      case 'negative':
      case 'warning':
        return /*#__PURE__*/React.createElement(Negative, null);
      case 'positive':
      case 'success':
        return /*#__PURE__*/React.createElement(Positive, null);
      case 'assertive':
        return /*#__PURE__*/React.createElement(Assertive, null);
    }
  }
  var iconName = getIconName(variantName);
  return /*#__PURE__*/React.createElement(Icon, {
    name: iconName,
    isPresentational: true,
    isFilled: true
  });
};
/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3082093114/Modal Guidance} |
 * {@link https://cultureamp.design/?path=/docs/components-modals-confirmationmodal--docs Storybook}
 */
const ConfirmationModal = /*#__PURE__*/function () {
  const ConfirmationModal = function (_a) {
    var isOpen = _a.isOpen,
      _b = _a.isProminent,
      isProminent = _b === void 0 ? false : _b,
      _c = _a.unpadded,
      unpadded = _c === void 0 ? false : _c,
      mood = _a.mood,
      variant = _a.variant,
      title = _a.title,
      onConfirm = _a.onConfirm,
      onAfterLeave = _a.onAfterLeave,
      onAfterEnter = _a.onAfterEnter,
      _d = _a.confirmLabel,
      confirmLabel = _d === void 0 ? 'Confirm' : _d,
      _e = _a.dismissLabel,
      dismissLabel = _e === void 0 ? 'Cancel' : _e,
      confirmWorking = _a.confirmWorking,
      propsOnDismiss = _a.onDismiss,
      children = _a.children,
      className = _a.className,
      props = __rest(_a, ["isOpen", "isProminent", "unpadded", "mood", "variant", "title", "onConfirm", "onAfterLeave", "onAfterEnter", "confirmLabel", "dismissLabel", "confirmWorking", "onDismiss", "children", "className"]);
    var variantName = variant !== null && variant !== void 0 ? variant : mood;
    var onDismiss = confirmWorking ? undefined : propsOnDismiss;
    var footerActions = [];
    if (onConfirm) {
      var confirmAction = {
        label: confirmLabel,
        onClick: onConfirm
      };
      var workingProps = confirmWorking ? {
        working: true,
        workingLabel: confirmWorking.label,
        workingLabelHidden: confirmWorking.labelHidden
      } : {};
      footerActions.push(__assign(__assign({}, confirmAction), workingProps));
    }
    footerActions.push({
      label: dismissLabel,
      onClick: onDismiss,
      disabled: !!confirmWorking
    });
    return /*#__PURE__*/React.createElement(GenericModal, {
      isOpen: isOpen,
      onEscapeKeyup: onDismiss,
      onOutsideModalClick: onDismiss,
      onAfterLeave: onAfterLeave,
      onAfterEnter: onAfterEnter,
      className: className
    }, /*#__PURE__*/React.createElement("div", __assign({
      className: styles.modal,
      "data-modal": true
    }, props), /*#__PURE__*/React.createElement(ModalHeader, {
      onDismiss: onDismiss
    }, /*#__PURE__*/React.createElement("div", {
      className: classnames(styles.header, variant ? styles[variant] : styles["".concat(mood, "Header")], isProminent && styles.prominent, !unpadded && styles.padded)
    }, /*#__PURE__*/React.createElement("div", {
      className: classnames(styles.iconContainer, isProminent && styles.prominent)
    }, /*#__PURE__*/React.createElement("div", {
      className: styles.spotIcon
    }, getIcon(variantName, isProminent))), /*#__PURE__*/React.createElement(ModalAccessibleLabel, {
      isProminent: isProminent
    }, /*#__PURE__*/React.createElement(Heading, {
      tag: "h2",
      variant: "heading-2"
    }, title)))), /*#__PURE__*/React.createElement(ModalBody, null, /*#__PURE__*/React.createElement("div", {
      className: classnames(isProminent && styles.prominent, !unpadded && styles.padded)
    }, /*#__PURE__*/React.createElement(ModalAccessibleDescription, null, children))), /*#__PURE__*/React.createElement(ModalFooter, {
      actions: footerActions,
      appearance: mood === 'negative' || variant == 'warning' ? 'destructive' : 'primary',
      unpadded: unpadded
    })));
  };
  ConfirmationModal.displayName = 'ConfirmationModal';
  return ConfirmationModal;
}();
export { ConfirmationModal };
