import { __rest, __assign } from 'tslib';
import React from 'react';
import classnames from 'classnames';
import { Heading } from '../../Heading/Heading.mjs';
import { GenericModal } from '../GenericModal/GenericModal.mjs';
import '../GenericModal/context/ModalContext.mjs';
import '../GenericModal/subcomponents/ModalAccessibleDescription/ModalAccessibleDescription.mjs';
import { ModalFooter } from '../GenericModal/subcomponents/ModalFooter/ModalFooter.mjs';
import { ModalHeader } from '../GenericModal/subcomponents/ModalHeader/ModalHeader.mjs';
import { ModalAccessibleLabel } from '../GenericModal/subcomponents/ModalAccessibleLabel/ModalAccessibleLabel.mjs';
import { ModalBody } from '../GenericModal/subcomponents/ModalBody/ModalBody.mjs';
import styles from './ContextModal.module.scss.mjs';

/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3082093114/Modal Guidance} |
 * {@link https://cultureamp.design/?path=/docs/components-modals--contextmodal--docs Storybook}
 */
const ContextModal = /*#__PURE__*/function () {
  const ContextModal = function (_a) {
    var isOpen = _a.isOpen,
      _b = _a.unpadded,
      unpadded = _b === void 0 ? false : _b,
      _c = _a.layout,
      layout = _c === void 0 ? 'portrait' : _c,
      title = _a.title,
      onConfirm = _a.onConfirm,
      propsOnDismiss = _a.onDismiss,
      onAfterLeave = _a.onAfterLeave,
      onAfterEnter = _a.onAfterEnter,
      _d = _a.confirmLabel,
      confirmLabel = _d === void 0 ? 'Confirm' : _d,
      confirmWorking = _a.confirmWorking,
      renderBackground = _a.renderBackground,
      children = _a.children,
      contentHeader = _a.contentHeader,
      image = _a.image,
      secondaryLabel = _a.secondaryLabel,
      onSecondaryAction = _a.onSecondaryAction,
      className = _a.className,
      props = __rest(_a, ["isOpen", "unpadded", "layout", "title", "onConfirm", "onDismiss", "onAfterLeave", "onAfterEnter", "confirmLabel", "confirmWorking", "renderBackground", "children", "contentHeader", "image", "secondaryLabel", "onSecondaryAction", "className"]);
    var onDismiss = confirmWorking ? undefined : propsOnDismiss;
    var footerActions = [];
    var workingProps = confirmWorking ? {
      working: true,
      workingLabel: confirmWorking.label,
      workingLabelHidden: confirmWorking.labelHidden
    } : {};
    if (onConfirm) {
      var confirmAction = {
        label: confirmLabel,
        onClick: onConfirm
      };
      footerActions.push(__assign(__assign({}, confirmAction), workingProps));
    }
    if (secondaryLabel) {
      footerActions.push({
        label: secondaryLabel,
        onClick: onSecondaryAction,
        disabled: !!confirmWorking
      });
    }
    return /*#__PURE__*/React.createElement(GenericModal, {
      isOpen: isOpen,
      onEscapeKeyup: onDismiss,
      onOutsideModalClick: onDismiss,
      onAfterLeave: onAfterLeave,
      onAfterEnter: onAfterEnter,
      className: className
    }, /*#__PURE__*/React.createElement("div", __assign({
      className: styles.modal,
      "data-modal": true
    }, props), renderBackground === null || renderBackground === void 0 ? void 0 : renderBackground(), /*#__PURE__*/React.createElement(ModalHeader, {
      onDismiss: onDismiss
    }, /*#__PURE__*/React.createElement("div", {
      className: classnames(styles.header, !unpadded && styles.padded)
    }, /*#__PURE__*/React.createElement(ModalAccessibleLabel, null, /*#__PURE__*/React.createElement(Heading, {
      variant: "heading-2",
      tag: "h2"
    }, title)))), contentHeader && /*#__PURE__*/React.createElement("div", {
      className: styles.contentHeader
    }, contentHeader), /*#__PURE__*/React.createElement(ModalBody, null, /*#__PURE__*/React.createElement("div", {
      className: classnames(styles.contentLayout, styles["".concat(layout, "Contentlayout")])
    }, image && /*#__PURE__*/React.createElement("div", {
      className: styles.image
    }, image), /*#__PURE__*/React.createElement("div", {
      className: styles.content
    }, children, onConfirm != null && (/*#__PURE__*/React.createElement("div", {
      className: secondaryLabel ? styles.footerWithSecondaryAction : styles.footer
    }))))), /*#__PURE__*/React.createElement(ModalFooter, {
      variant: image ? 'context' : undefined,
      actions: footerActions,
      appearance: "primary",
      unpadded: unpadded
    })));
  };
  ContextModal.displayName = 'ContextModal';
  return ContextModal;
}();
export { ContextModal };
