import React, { useId, useState, useCallback, useEffect } from 'react';
import { createPortal } from 'react-dom';
import { Transition } from '@headlessui/react';
import classnames from 'classnames';
import FocusLock from 'react-focus-lock';
import { warn } from '../util/console.mjs';
import { ModalContext } from './context/ModalContext.mjs';
import styles from './GenericModal.module.scss.mjs';
const GenericModal = /*#__PURE__*/function () {
  const GenericModal = function (_a) {
    var propsId = _a.id,
      children = _a.children,
      _b = _a.isOpen,
      isOpen = _b === void 0 ? true : _b,
      focusLockDisabled = _a.focusLockDisabled,
      onEscapeKeyup = _a.onEscapeKeyup,
      onOutsideModalClick = _a.onOutsideModalClick,
      onAfterEnter = _a.onAfterEnter,
      propsOnAfterLeave = _a.onAfterLeave,
      className = _a.className;
    var reactId = useId();
    var id = propsId !== null && propsId !== void 0 ? propsId : reactId;
    var labelledByID = useId();
    var describedByID = useId();
    var _c = useState(null),
      scrollLayer = _c[0],
      setScrollLayer = _c[1];
    var _d = useState(null),
      modalLayer = _d[0],
      setModalLayer = _d[1];
    var scrollModalToTop = function () {
      // If we have a really long modal, the autofocus could land on an element down below
      // causing the modal to scroll down and skipping over the content near the modal's top.
      // Ensure that when the modal opens, we are at the top of its content.
      requestAnimationFrame(function () {
        if (!scrollLayer) return;
        scrollLayer.scrollTop = 0;
      });
    };
    var outsideModalClickHandler = function (event) {
      if (event.target === scrollLayer || event.target === modalLayer) {
        onOutsideModalClick === null || onOutsideModalClick === void 0 ? void 0 : onOutsideModalClick(event);
      }
    };
    var focusOnAccessibleLabel = function () {
      // Check if focus already exists within the modal
      if (modalLayer === null || modalLayer === void 0 ? void 0 : modalLayer.contains(document.activeElement)) {
        return;
      }
      var labelElement = document.getElementById(labelledByID);
      labelElement === null || labelElement === void 0 ? void 0 : labelElement.focus();
    };
    var a11yWarn = function () {
      // Ensure that consumers have provided an element that labels the modal
      // to meet ARIA accessibility guidelines.
      if (!document.getElementById(labelledByID)) {
        warn("When using the Modal component, you must provide a label for the modal.\n        Make sure you have a <ModalAccessibleLabel /> component with content that labels the modal.");
      }
    };
    var preventBodyScroll = function () {
      var _a;
      var hasScrollbar = window.innerWidth > document.documentElement.clientWidth;
      var scrollStyles = [styles.unscrollable];
      if (hasScrollbar) {
        scrollStyles.push(styles.pseudoScrollbar);
      }
      (_a = document.documentElement.classList).add.apply(_a, scrollStyles);
    };
    var onAfterEnterHandler = function () {
      scrollModalToTop();
      if (modalLayer) {
        onAfterEnter === null || onAfterEnter === void 0 ? void 0 : onAfterEnter();
        focusOnAccessibleLabel();
        a11yWarn();
      }
    };
    var escapeKeyHandler = useCallback(function (event) {
      if (event.key === 'Escape') {
        onEscapeKeyup === null || onEscapeKeyup === void 0 ? void 0 : onEscapeKeyup(event);
      }
    }, [onEscapeKeyup]);
    var onBeforeEnterHandler = function () {
      preventBodyScroll();
      if (onEscapeKeyup) {
        document.addEventListener('keyup', escapeKeyHandler);
      }
    };
    var cleanUpAfterClose = function () {
      document.documentElement.classList.remove(styles.unscrollable, styles.pseudoScrollbar);
      if (onEscapeKeyup) {
        document.removeEventListener('keyup', escapeKeyHandler);
      }
    };
    /* Ensure sure add-on styles (e.g. unscrollable) and key event is cleaned up when the modal is unmounted*/
    // @todo: Fix if possible - avoiding breaking in eslint upgrade
    // eslint-disable-next-line react-hooks/exhaustive-deps
    useEffect(function () {
      return function () {
        return cleanUpAfterClose();
      };
    }, []);
    var onAfterLeaveHandler = function () {
      cleanUpAfterClose();
      propsOnAfterLeave === null || propsOnAfterLeave === void 0 ? void 0 : propsOnAfterLeave();
    };
    return /*#__PURE__*/createPortal(/*#__PURE__*/React.createElement(Transition, {
      appear: true,
      show: isOpen,
      beforeEnter: onBeforeEnterHandler,
      afterEnter: onAfterEnterHandler,
      afterLeave: onAfterLeaveHandler,
      "data-generic-modal-transition-wrapper": true,
      enter: styles.animatingEnter,
      leave: styles.animatingLeave,
      as: "div",
      className: classnames(styles.transitionLayer, className)
    }, /*#__PURE__*/React.createElement(FocusLock, {
      disabled: focusLockDisabled,
      returnFocus: true,
      // Disabling false positive
      // eslint-disable-next-line jsx-a11y/no-autofocus
      autoFocus: false
    }, /*#__PURE__*/React.createElement("div", {
      className: styles.backdropLayer
    }), /*#__PURE__*/React.createElement("div", {
      className: styles.scrollLayer,
      ref: function (scrollLayerRef) {
        setScrollLayer(scrollLayerRef);
      },
      onClick: outsideModalClickHandler,
      "data-testid": "".concat(id, "-scrollLayer")
    }, /*#__PURE__*/React.createElement(ModalContext.Provider, {
      value: {
        labelledByID: labelledByID,
        describedByID: describedByID
      }
    }, /*#__PURE__*/React.createElement("div", {
      role: "dialog",
      className: styles.modalLayer,
      "aria-labelledby": labelledByID,
      "aria-describedby": describedByID,
      ref: function (modalLayerRef) {
        return setModalLayer(modalLayerRef);
      },
      "data-testid": id
    }, children))))), document.body);
  };
  GenericModal.displayName = 'GenericModal';
  return GenericModal;
}();
export { GenericModal };
