import { __rest, __assign } from 'tslib';
import React from 'react';
import classnames from 'classnames';
import { Heading } from '../../Heading/Heading.mjs';
import { GenericModal } from '../GenericModal/GenericModal.mjs';
import '../GenericModal/context/ModalContext.mjs';
import '../GenericModal/subcomponents/ModalAccessibleDescription/ModalAccessibleDescription.mjs';
import { ModalFooter } from '../GenericModal/subcomponents/ModalFooter/ModalFooter.mjs';
import { ModalHeader } from '../GenericModal/subcomponents/ModalHeader/ModalHeader.mjs';
import { ModalAccessibleLabel } from '../GenericModal/subcomponents/ModalAccessibleLabel/ModalAccessibleLabel.mjs';
import { ModalBody } from '../GenericModal/subcomponents/ModalBody/ModalBody.mjs';
import styles from './InputEditModal.module.scss.mjs';

/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3082093114/Modal#Input-Edit-Modal Guidance} |
 * {@link https://cultureamp.design/?path=/docs/components-modals-inputeditmodal--docs Storybook}
 */
const InputEditModal = /*#__PURE__*/function () {
  const InputEditModal = function (_a) {
    var isOpen = _a.isOpen,
      mood = _a.mood,
      title = _a.title,
      onSubmit = _a.onSubmit,
      onSecondaryAction = _a.onSecondaryAction,
      onAfterLeave = _a.onAfterLeave,
      _b = _a.submitLabel,
      submitLabel = _b === void 0 ? 'Submit' : _b,
      _c = _a.dismissLabel,
      dismissLabel = _c === void 0 ? 'Cancel' : _c,
      secondaryLabel = _a.secondaryLabel,
      submitWorking = _a.submitWorking,
      children = _a.children,
      _d = _a.unpadded,
      unpadded = _d === void 0 ? false : _d,
      propsOnDismiss = _a.onDismiss,
      onAfterEnter = _a.onAfterEnter,
      className = _a.className,
      props = __rest(_a, ["isOpen", "mood", "title", "onSubmit", "onSecondaryAction", "onAfterLeave", "submitLabel", "dismissLabel", "secondaryLabel", "submitWorking", "children", "unpadded", "onDismiss", "onAfterEnter", "className"]);
    var onDismiss = submitWorking ? undefined : propsOnDismiss;
    var submitAction = {
      label: submitLabel,
      onClick: onSubmit
    };
    var workingProps = submitWorking ? {
      working: true,
      workingLabel: submitWorking.label,
      workingLabelHidden: submitWorking.labelHidden
    } : {};
    var showSecondary = onSecondaryAction && secondaryLabel;
    var footerActions = [__assign(__assign({}, submitAction), workingProps), {
      label: showSecondary ? secondaryLabel : dismissLabel,
      onClick: showSecondary ? onSecondaryAction : onDismiss,
      disabled: !!submitWorking
    }];
    return /*#__PURE__*/React.createElement(GenericModal, {
      isOpen: isOpen,
      onEscapeKeyup: onDismiss,
      onAfterLeave: onAfterLeave,
      onAfterEnter: onAfterEnter,
      className: className
    }, /*#__PURE__*/React.createElement("div", __assign({
      className: styles.modal,
      "data-modal": true
    }, props), /*#__PURE__*/React.createElement(ModalHeader, {
      onDismiss: onDismiss
    }, /*#__PURE__*/React.createElement("div", {
      className: classnames(styles.header, !unpadded && styles.padded)
    }, /*#__PURE__*/React.createElement(ModalAccessibleLabel, null, /*#__PURE__*/React.createElement(Heading, {
      tag: "h2",
      variant: "heading-2"
    }, title)))), /*#__PURE__*/React.createElement(ModalBody, null, /*#__PURE__*/React.createElement("div", {
      className: classnames(styles.body, !unpadded && styles.padded)
    }, children)), /*#__PURE__*/React.createElement(ModalFooter, {
      actions: footerActions,
      appearance: mood === 'destructive' ? 'destructive' : 'primary',
      variant: "inputEdit",
      unpadded: unpadded
    })));
  };
  InputEditModal.displayName = 'InputEditModal';
  return InputEditModal;
}();
export { InputEditModal };
