import { __rest, __assign } from 'tslib';
import React, { forwardRef, useState, useRef, useEffect } from 'react';
import classnames from 'classnames';
import { isRefObject } from '../../../utils/isRefObject.mjs';
import { CancelButton } from '../CancelButton/CancelButton.mjs';
import { NotificationHeading } from '../NotificationHeading/NotificationHeading.mjs';
import { NotificationIconType, NotificationIconVariant } from '../NotificationIcon/NotificationIcon.mjs';
import styles from './GenericNotification.module.scss.mjs';
const GenericNotification = /*#__PURE__*/function () {
  const GenericNotification = /*#__PURE__*/forwardRef(function (_a, ref) {
    var type = _a.type,
      variant = _a.variant,
      style = _a.style,
      children = _a.children,
      title = _a.title,
      _b = _a.persistent,
      persistent = _b === void 0 ? false : _b,
      onHide = _a.onHide,
      noBottomMargin = _a.noBottomMargin,
      forceMultiline = _a.forceMultiline,
      headingProps = _a.headingProps,
      classNameOverride = _a.classNameOverride,
      restProps = __rest(_a, ["type", "variant", "style", "children", "title", "persistent", "onHide", "noBottomMargin", "forceMultiline", "headingProps", "classNameOverride"]);
    var _c = useState(true),
      isHidden = _c[0],
      setIsHidden = _c[1];
    var _d = useState(false),
      isRemoved = _d[0],
      setIsRemoved = _d[1];
    var fallbackRef = useRef(null);
    var containerRef = isRefObject(ref) ? ref : fallbackRef;
    useEffect(function () {
      requestAnimationFrame(function () {
        if (containerRef.current) {
          setIsHidden(false);
        }
      });
    }, [containerRef]);
    var getMarginTop = function () {
      if (isHidden && containerRef.current) {
        return -containerRef.current.clientHeight + 'px';
      }
      return '0';
    };
    var onTransitionEnd = function (e) {
      // Be careful: this assumes the final CSS property to be animated is "margin-top".
      if (isHidden && e.propertyName === 'margin-top') {
        setIsRemoved(true);
        onHide === null || onHide === void 0 ? void 0 : onHide();
      }
    };
    if (isRemoved) {
      return null;
    }
    return /*#__PURE__*/React.createElement("div", __assign({
      ref: containerRef,
      className: classnames(styles.notification, variant ? styles[variant] : styles[type], styles[style], isHidden && styles.hidden, noBottomMargin && styles.noBottomMargin, classNameOverride, persistent && styles.persistent),
      style: {
        marginTop: getMarginTop()
      },
      onTransitionEnd: onTransitionEnd
    }, restProps), /*#__PURE__*/React.createElement("div", {
      className: styles.icon
    }, type ? (/*#__PURE__*/React.createElement(NotificationIconType, {
      type: type
    })) : (/*#__PURE__*/React.createElement(NotificationIconVariant, {
      variant: variant
    }))), /*#__PURE__*/React.createElement("div", {
      className: classnames(styles.textContainer, forceMultiline && styles.forceMultiline)
    }, style !== 'global' && (/*#__PURE__*/React.createElement(NotificationHeading, {
      titleProp: title,
      headingProps: headingProps
    })), children && /*#__PURE__*/React.createElement("div", {
      className: styles.text
    }, children)), !persistent && /*#__PURE__*/React.createElement(CancelButton, {
      onClick: function () {
        return setIsHidden(true);
      }
    }));
  });
  GenericNotification.displayName = 'GenericNotification';
  return GenericNotification;
}();
export { GenericNotification };
