import { __rest, __assign } from 'tslib';
import React from 'react';
import classnames from 'classnames';
import { Heading } from '../Heading/Heading.mjs';
import { Label } from './subcomponents/Label/Label.mjs';
import { calculatePercentage } from './utils/calculatePercentage.mjs';
import styles from './ProgressBar.module.scss.mjs';

/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3081896891/Progress+Bar Guidance} |
 * {@link https://cultureamp.design/?path=/docs/components-progress-bar--docs Storybook}
 */
const ProgressBar = /*#__PURE__*/function () {
  const ProgressBar = function (_a) {
    var value = _a.value,
      max = _a.max,
      isAnimating = _a.isAnimating,
      mood = _a.mood,
      color = _a.color,
      subtext = _a.subtext,
      label = _a.label,
      classNameOverride = _a.classNameOverride,
      _b = _a.isReversed,
      isReversed = _b === void 0 ? false : _b,
      restProps = __rest(_a, ["value", "max", "isAnimating", "mood", "color", "subtext", "label", "classNameOverride", "isReversed"]);
    var percentage = calculatePercentage({
      value: value,
      max: max
    });
    return /*#__PURE__*/React.createElement("div", __assign({
      role: "progressbar",
      "aria-valuenow": percentage,
      "aria-valuemin": 0,
      "aria-valuemax": 100,
      className: classNameOverride
    }, restProps), label && /*#__PURE__*/React.createElement(Label, {
      content: label,
      isReversed: isReversed
    }), /*#__PURE__*/React.createElement("div", {
      className: styles.progressBackground
    }, /*#__PURE__*/React.createElement("div", {
      className: classnames(styles.progress, color ? styles[color] : styles[mood], isAnimating && styles.isAnimating),
      style: {
        transform: "translateX(-".concat(100 - percentage, "%")
      }
    })), subtext && (/*#__PURE__*/React.createElement("div", {
      className: styles.subtext
    }, /*#__PURE__*/React.createElement(Heading, {
      variant: "heading-6",
      tag: "p",
      color: isReversed ? 'white' : 'dark'
    }, subtext))));
  };
  ProgressBar.displayName = 'ProgressBar';
  return ProgressBar;
}();
export { ProgressBar };
