import { __rest, __assign } from 'tslib';
import React, { useState, useId, useEffect } from 'react';
import classnames from 'classnames';
import { createSchemaWithAll } from '../RichTextEditor/schema.mjs';
import * as ProseMirrorState from 'prosemirror-state';
import 'prosemirror-view';
import { useRichTextEditor } from '../utils/core/hooks/useRichTextEditor.mjs';
import * as ProseMirrorModel from 'prosemirror-model';
import 'prosemirror-inputrules';
import 'prosemirror-commands';
import 'prosemirror-keymap';
import 'prosemirror-history';
import 'prosemirror-schema-list';
import styles from './RichTextContent.module.scss.mjs';
const RichTextContent = /*#__PURE__*/function () {
  const RichTextContent = function (props) {
    var content = props.content,
      classNameOverride = props.classNameOverride,
      restProps = __rest(props, ["content", "classNameOverride"]);
    var schema = useState(createSchemaWithAll())[0];
    var editorId = useId();
    useEffect(function () {
      var _a;
      // prosemirror only allows us to set this to false (which has caused a strange bug in the platform)
      // so we have to hack a bit to remove the attribute completely
      (_a = document.getElementById(editorId)) === null || _a === void 0 ? void 0 : _a.removeAttribute('contenteditable');
      // @todo: Fix if possible - avoiding breaking in eslint upgrade
      // eslint-disable-next-line react-hooks/exhaustive-deps
    }, []);
    var editorRef = useRichTextEditor(ProseMirrorState.EditorState.create({
      doc: ProseMirrorModel.Node.fromJSON(schema, {
        type: 'doc',
        content: content
      }),
      schema: schema
    }), {
      id: editorId
    }, {
      editable: false
    })[0];
    return /*#__PURE__*/React.createElement("div", __assign({
      ref: editorRef,
      className: classnames(styles.content, classNameOverride)
    }, restProps));
  };
  RichTextContent.displayName = 'RichTextContent';
  return RichTextContent;
}();
export { RichTextContent };
