import { __spreadArray, __assign } from 'tslib';
import { TOOLBAR_CONTROLS } from '../constants.mjs';
import 'prosemirror-commands';
import 'prosemirror-keymap';
import 'prosemirror-history';
import 'prosemirror-state';
import * as ProseMirrorModel from 'prosemirror-model';
import 'prosemirror-inputrules';
import 'prosemirror-schema-list';
import { getMarks } from '../utils/schema/marks.mjs';
import { getNodes } from '../utils/schema/nodes.mjs';
var createSchemaFromControls = function (controls) {
  if (!controls) {
    return createSchema();
  }
  var namesFromControls = controls.reduce(function (acc, c) {
    return __spreadArray(__spreadArray([], acc, true), [c.name], false);
  }, []);
  return createSchema(namesFromControls);
};
var createSchemaWithAll = function () {
  return createSchema(TOOLBAR_CONTROLS);
};
var createSchema = function (controls) {
  var nodes = getNodes();
  var marks = getMarks();
  var defaultNodes = {
    doc: nodes.doc,
    paragraph: nodes.paragraph,
    text: nodes.text,
    hardBreak: nodes.hardBreak
  };
  if (!controls) {
    return new ProseMirrorModel.Schema({
      nodes: defaultNodes
    });
  }
  var newNodes = __assign({}, defaultNodes);
  var newMarks = {};
  if (controls.includes('bold')) {
    newMarks.strong = marks.strong;
  }
  if (controls.includes('italic')) {
    newMarks.em = marks.em;
  }
  if (controls.includes('underline')) {
    newMarks.underline = marks.underline;
  }
  if (controls.includes('bulletList')) {
    newNodes.bulletList = nodes.bulletList;
    newNodes.listItem = nodes.listItem;
  }
  if (controls.includes('orderedList')) {
    newNodes.orderedList = nodes.orderedList;
    newNodes.listItem = nodes.listItem;
  }
  if (controls.includes('link')) {
    newMarks.link = marks.link;
  }
  return new ProseMirrorModel.Schema({
    nodes: newNodes,
    marks: newMarks
  });
};
export { createSchemaFromControls, createSchemaWithAll };
