import { __rest, __assign } from 'tslib';
import React from 'react';
import classnames from 'classnames';
import styles from './Toolbar.module.scss.mjs';
var determineValidKeypress = function (event) {
  var validKeys = {
    left: 'ArrowLeft',
    right: 'ArrowRight'
  };
  return Object.values(validKeys).includes(event.key);
};
var handleKeyDown = function (e, buttonIndex, buttonFocusIndex, setFocusIndex, toolbarButtons) {
  if (!determineValidKeypress(e)) return;
  var newFocusIndex;
  var lastButtonIndex = toolbarButtons.current.length - 1;
  if (e.key === 'ArrowLeft') {
    newFocusIndex = buttonIndex === 0 ? lastButtonIndex : buttonFocusIndex - 1;
  } else {
    newFocusIndex = buttonIndex === lastButtonIndex ? 0 : buttonFocusIndex + 1;
  }
  setFocusIndex(newFocusIndex);
  toolbarButtons.current[newFocusIndex].focus();
};
const Toolbar = /*#__PURE__*/function () {
  const Toolbar = function (props) {
    var toolbarChildren = props.children,
      classNameOverride = props.classNameOverride,
      toolbarProps = __rest(props, ["children", "classNameOverride"]);
    var _a = React.useState(0),
      buttonFocusIndex = _a[0],
      setButtonFocusIndex = _a[1];
    var toolbarButtonsRef = React.useRef([]);
    var buttonCount = 0;
    return /*#__PURE__*/React.createElement("div", __assign({
      className: classnames(styles.toolbar, classNameOverride),
      role: "toolbar"
    }, toolbarProps), React.Children.map(toolbarChildren, function (toolbarSection, sectionIndex) {
      if (! /*#__PURE__*/React.isValidElement(toolbarSection)) {
        return toolbarChildren;
      }
      var _a = toolbarSection.props,
        sectionChildren = _a.children,
        toolbarSectionProps = __rest(_a, ["children"]);
      return /*#__PURE__*/React.createElement(toolbarSection.type, __assign({}, toolbarSectionProps, {
        key: "rte-section-".concat(sectionIndex)
      }), React.Children.map(sectionChildren, function (toolbarButton) {
        if (! /*#__PURE__*/React.isValidElement(toolbarButton)) {
          return;
        }
        var buttonIndex = buttonCount;
        buttonCount += 1;
        return /*#__PURE__*/React.createElement(toolbarButton.type, __assign({}, toolbarButton.props, {
          key: "rte-button-".concat(buttonIndex),
          tabIndex: buttonIndex === buttonFocusIndex ? 0 : -1,
          onKeyDown: function (e) {
            return handleKeyDown(e, buttonIndex, buttonFocusIndex, setButtonFocusIndex, toolbarButtonsRef);
          },
          ref: function (ref) {
            return toolbarButtonsRef.current[buttonIndex] = ref;
          }
        }));
      }));
    }));
  };
  Toolbar.displayName = 'Toolbar';
  return Toolbar;
}();
export { Toolbar };
