import * as ProseMirrorCommands from 'prosemirror-commands';
import 'prosemirror-keymap';
import * as ProseMirrorHistory from 'prosemirror-history';
import 'prosemirror-state';
import 'prosemirror-model';
import * as ProseMirrorInputrules from 'prosemirror-inputrules';
import * as ProseMirrorSchemaList from 'prosemirror-schema-list';
var buildKeymap = function (schema) {
  var redo = ProseMirrorHistory.redo,
    undo = ProseMirrorHistory.undo;
  var undoInputRule = ProseMirrorInputrules.undoInputRule;
  var wrapInList = ProseMirrorSchemaList.wrapInList,
    splitListItem = ProseMirrorSchemaList.splitListItem,
    liftListItem = ProseMirrorSchemaList.liftListItem,
    sinkListItem = ProseMirrorSchemaList.sinkListItem;
  var mac = typeof navigator != 'undefined' ? navigator.platform.includes('Mac') : false;
  var chainCommands = ProseMirrorCommands.chainCommands,
    exitCode = ProseMirrorCommands.exitCode,
    joinDown = ProseMirrorCommands.joinDown,
    joinUp = ProseMirrorCommands.joinUp,
    lift = ProseMirrorCommands.lift,
    selectParentNode = ProseMirrorCommands.selectParentNode,
    setBlockType = ProseMirrorCommands.setBlockType,
    toggleMark = ProseMirrorCommands.toggleMark;
  var keys = {
    'Mod-z': undo,
    'Shift-Mod-z': redo,
    'Backspace': undoInputRule,
    'Alt-ArrowUp': joinUp,
    'Alt-ArrowDown': joinDown,
    'Mod-BracketLeft': lift,
    'Escape': selectParentNode
  };
  if (!mac) {
    keys['Mod-y'] = redo;
  }
  if (schema.marks.strong) {
    var type = schema.marks.strong;
    keys['Mod-b'] = toggleMark(type);
    keys['Mod-B'] = toggleMark(type);
  }
  if (schema.marks.em) {
    var type = schema.marks.em;
    keys['Mod-i'] = toggleMark(type);
    keys['Mod-I'] = toggleMark(type);
  }
  if (schema.marks.underline) {
    var type = schema.marks.underline;
    keys['Mod-u'] = toggleMark(type);
    keys['Mod-U'] = toggleMark(type);
  }
  if (schema.nodes.hardBreak) {
    var br_1 = schema.nodes.hardBreak;
    var cmd = chainCommands(exitCode, function (state, dispatch) {
      dispatch === null || dispatch === void 0 ? void 0 : dispatch(state.tr.replaceSelectionWith(br_1.create()).scrollIntoView());
      return true;
    });
    keys['Mod-Enter'] = cmd;
    keys['Shift-Enter'] = cmd;
    if (mac) {
      keys['Ctrl-Enter'] = cmd;
    }
  }
  if (schema.nodes.paragraph) {
    keys['Shift-Ctrl-0'] = setBlockType(schema.nodes.paragraph);
  }
  if (schema.nodes.bulletList) {
    keys['Shift-Ctrl-8'] = wrapInList(schema.nodes.bulletList);
  }
  if (schema.nodes.orderedList) {
    keys['Shift-Ctrl-9'] = wrapInList(schema.nodes.orderedList);
  }
  if (schema.nodes.listItem) {
    var type = schema.nodes.listItem;
    keys.Enter = splitListItem(type);
    keys['Mod-['] = liftListItem(type);
    keys['Mod-]'] = sinkListItem(type);
  }
  return keys;
};
export { buildKeymap };
