import { RemoveMarkStep } from 'prosemirror-transform';

// This is a variation on the removeMark transform in
// https://github.com/ProseMirror/prosemirror-transform/blob/master/src/mark.js#L44
/** This will walk the full doc and remove the Marks that fail the validator method */
var validateAndRemoveMarks = function (markType, validator) {
  return function (state, dispatch) {
    if (!dispatch) return false;
    var from = 0;
    var to = state.doc.content.size;
    var tr = state.tr;
    var matched = [];
    var step = 0;
    tr.doc.nodesBetween(from, to, function (node, pos) {
      step++;
      var foundMark = markType.isInSet(node.marks);
      if (foundMark && !validator(foundMark.attrs)) {
        matched.push({
          style: foundMark,
          from: Math.max(pos, from),
          to: Math.min(pos + node.nodeSize, to),
          step: step
        });
      }
    });
    matched.forEach(function (m) {
      return tr.step(new RemoveMarkStep(m.from, m.to, m.style));
    });
    dispatch(tr);
    return true;
  };
};
export { validateAndRemoveMarks };
