import { __rest, __assign } from 'tslib';
import React, { useId } from 'react';
import classnames from 'classnames';
import { FieldGroup } from '../FieldGroup/FieldGroup.mjs';
import { InputRange } from '../Input/InputRange/InputRange.mjs';
import { Label } from '../Label/Label.mjs';
import { Text } from '../Text/Text.mjs';
import styles from './Slider.module.scss.mjs';

/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3081896335/Slider Guidance} |
 * {@link https://cultureamp.design/?path=/docs/components-slider--docs Storybook}
 */
const Slider = /*#__PURE__*/function () {
  const Slider = function (_a) {
    var propsId = _a.id,
      labelText = _a.labelText,
      description = _a.description,
      _b = _a.labelPosition,
      labelPosition = _b === void 0 ? 'inline' : _b,
      _c = _a.variant,
      variant = _c === void 0 ? 'default' : _c,
      disabled = _a.disabled,
      readOnlyMessage = _a.readOnlyMessage,
      restProps = __rest(_a, ["id", "labelText", "description", "labelPosition", "variant", "disabled", "readOnlyMessage"]);
    var fallbackId = useId();
    var id = propsId !== null && propsId !== void 0 ? propsId : fallbackId;
    var descriptionId = "".concat(id, "-description");
    return /*#__PURE__*/React.createElement(FieldGroup, {
      inline: true
    }, /*#__PURE__*/React.createElement("div", {
      className: classnames(styles.wrapper, labelPosition === 'inline' && styles.labelInline)
    }, /*#__PURE__*/React.createElement("div", {
      className: styles.labelWrapper
    }, /*#__PURE__*/React.createElement("div", {
      className: styles.label
    }, /*#__PURE__*/React.createElement(Label, {
      htmlFor: id,
      labelText: labelText,
      variant: variant,
      disabled: disabled
    })), description && (/*#__PURE__*/React.createElement(Text, {
      variant: "small",
      id: descriptionId,
      classNameOverride: disabled ? styles.descriptionDisabled : undefined
    }, description))), /*#__PURE__*/React.createElement("div", {
      className: styles.inputWrapper
    }, /*#__PURE__*/React.createElement(InputRange, __assign({
      id: id,
      "aria-describedby": descriptionId,
      disabled: disabled
    }, restProps)), readOnlyMessage && /*#__PURE__*/React.createElement("div", {
      className: styles.readOnlyMessage
    }, readOnlyMessage))));
  };
  Slider.displayName = 'Slider';
  return Slider;
}();
export { Slider };
