import { __assign } from 'tslib';
import React from 'react';
import classnames from 'classnames';
import { Avatar } from '../Avatar/Avatar.mjs';
import { Icon } from '../__next__/Icon/Icon.mjs';
import { LiveIcon } from './subcomponents/LiveIcon/LiveIcon.mjs';
import styles from './Tag.module.scss.mjs';
var isJSXElement = function (imageElementOrAvatarProps) {
  return 'props' in imageElementOrAvatarProps;
};
var renderAvatar = function (imageElementOrAvatarProps) {
  return isJSXElement(imageElementOrAvatarProps) ? (/*#__PURE__*/React.createElement(React.Fragment, null, imageElementOrAvatarProps)) : (/*#__PURE__*/React.createElement(Avatar, __assign({}, imageElementOrAvatarProps, {
    size: "small"
  })));
};
/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3081928978/Tags Guidance} |
 * {@link https://cultureamp.design/?path=/docs/components-tag--docs Storybook}
 */
const Tag = /*#__PURE__*/function () {
  const Tag = function (props) {
    var children = props.children,
      _a = props.variant,
      variant = _a === void 0 ? 'default' : _a,
      _b = props.size,
      size = _b === void 0 ? 'medium' : _b,
      _c = props.inline,
      inline = _c === void 0 ? false : _c,
      _d = props.dismissible,
      dismissible = _d === void 0 ? false : _d,
      onDismiss = props.onDismiss,
      onMouseDown = props.onMouseDown,
      onMouseLeave = props.onMouseLeave,
      truncateWidth = props.truncateWidth;
    var isTruncated = truncateWidth && truncateWidth > 0;
    var canShowIcon = size === 'medium';
    return /*#__PURE__*/React.createElement("div", {
      className: classnames(styles.root, styles[variant], variant === 'profile' && styles.default, styles[size], inline && styles.inline, dismissible && styles.dismissible)
    }, /*#__PURE__*/React.createElement("div", {
      className: styles.layoutContainer
    }, /*#__PURE__*/React.createElement(React.Fragment, null, canShowIcon && function () {
      switch (props.variant) {
        case 'validationPositive':
          return /*#__PURE__*/React.createElement("span", {
            className: styles.validationIcon
          }, /*#__PURE__*/React.createElement(Icon, {
            name: "check_circle",
            isPresentational: true,
            isFilled: true
          }));
        case 'validationNegative':
          return /*#__PURE__*/React.createElement("span", {
            className: styles.validationIcon
          }, /*#__PURE__*/React.createElement(Icon, {
            name: "error",
            isPresentational: true,
            isFilled: true
          }));
        case 'validationCautionary':
          return /*#__PURE__*/React.createElement("span", {
            className: styles.validationIcon
          }, /*#__PURE__*/React.createElement(Icon, {
            name: "warning",
            isPresentational: true,
            isFilled: true
          }));
        case 'validationInformative':
          return /*#__PURE__*/React.createElement("span", {
            className: styles.validationIcon
          }, /*#__PURE__*/React.createElement(Icon, {
            name: "info",
            isPresentational: true,
            isFilled: true
          }));
        case 'profile':
          return /*#__PURE__*/React.createElement("span", {
            className: styles.profile
          }, props.avatar && renderAvatar(props.avatar));
        default:
          return null;
      }
    }(), /*#__PURE__*/React.createElement("span", {
      className: classnames(styles.textContent, isTruncated && styles.truncate),
      style: {
        maxWidth: isTruncated ? truncateWidth : undefined
      }
    }, children), dismissible && (/*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("button", {
      type: "button",
      className: styles.dismissButton,
      onClick: onDismiss,
      onMouseDown: onMouseDown,
      onMouseLeave: onMouseLeave
    }, /*#__PURE__*/React.createElement("div", {
      className: styles.iconWrapper
    }, /*#__PURE__*/React.createElement(Icon, {
      name: "cancel",
      alt: "Dismiss",
      isFilled: true
    }))))), variant === 'statusLive' && /*#__PURE__*/React.createElement(LiveIcon, null))));
  };
  Tag.displayName = 'Tag';
  return Tag;
}();
export { Tag };
