import { __rest, __assign } from 'tslib';
import React, { useId } from 'react';
import classnames from 'classnames';
import { FieldGroup } from '../FieldGroup/FieldGroup.mjs';
import { FieldMessage } from '../FieldMessage/FieldMessage.mjs';
import { Label } from '../Label/Label.mjs';
import { TextArea } from '../TextArea/TextArea.mjs';
import styles from './TextAreaField.module.scss.mjs';

/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3081895966/Text+Area+Field Guidance} |
 * {@link https://cultureamp.design/?path=/docs/components-text-area-field--docs Storybook}
 */
const TextAreaField = /*#__PURE__*/function () {
  const TextAreaField = function (_a) {
    var labelText = _a.labelText,
      _b = _a.inline,
      inline = _b === void 0 ? false : _b,
      validationMessage = _a.validationMessage,
      description = _a.description,
      _c = _a.variant,
      variant = _c === void 0 ? 'default' : _c,
      propsId = _a.id,
      _d = _a.reversed,
      reversed = _d === void 0 ? false : _d,
      _e = _a.status,
      status = _e === void 0 ? 'default' : _e,
      disabled = _a.disabled,
      restProps = __rest(_a, ["labelText", "inline", "validationMessage", "description", "variant", "id", "reversed", "status", "disabled"]);
    var fallbackId = useId();
    var id = propsId !== null && propsId !== void 0 ? propsId : fallbackId;
    var validationMessageAria = validationMessage ? "".concat(id, "-field-validation-message") : '';
    var descriptionAria = description ? "".concat(id, "-field-message") : '';
    var ariaDescribedBy = [validationMessageAria, descriptionAria].reduce(function (prev, curr) {
      return curr ? [curr, prev].join(' ') : prev;
    }, '');
    var renderDescriptionOnTop = variant === 'prominent';
    var renderDescription = function (position) {
      if (!description) return null;
      return /*#__PURE__*/React.createElement("div", {
        className: classnames(styles.message, disabled && styles.disabled)
      }, /*#__PURE__*/React.createElement(FieldMessage, {
        id: descriptionAria,
        "data-testid": "".concat(id, "-field-description"),
        message: description,
        reversed: reversed,
        position: position
      }));
    };
    return /*#__PURE__*/React.createElement(FieldGroup, {
      id: "".concat(id, "-field-group"),
      inline: inline,
      "data-testid": "".concat(id, "-field-group"),
      classNameOverride: disabled ? styles.disabled : undefined
    }, /*#__PURE__*/React.createElement("div", {
      className: classnames(styles.textareaLabel, variant === 'prominent' && styles.textareaLabelProminent)
    }, /*#__PURE__*/React.createElement(Label, {
      id: "".concat(id, "-field-label"),
      "data-testid": "".concat(id, "-field-label"),
      htmlFor: "".concat(id, "-field-textarea"),
      labelText: labelText,
      reversed: reversed,
      variant: variant,
      disabled: disabled
    })), renderDescriptionOnTop && renderDescription('top'), /*#__PURE__*/React.createElement(TextArea, __assign({
      id: "".concat(id, "-field-textarea"),
      "data-testid": "".concat(id, "-field-textarea"),
      reversed: reversed,
      status: status,
      disabled: disabled,
      "aria-describedby": ariaDescribedBy
    }, restProps)), !disabled && validationMessage && (/*#__PURE__*/React.createElement(FieldMessage, {
      id: validationMessageAria,
      "data-testid": validationMessageAria,
      message: validationMessage,
      status: status,
      reversed: reversed
    })), !renderDescriptionOnTop && renderDescription('bottom'));
  };
  TextAreaField.displayName = 'TextAreaField';
  return TextAreaField;
}();
export { TextAreaField };
