import { __assign } from 'tslib';
import React from 'react';
import classnames from 'classnames';
import { Avatar } from '../Avatar/Avatar.mjs';
import '../Button/Button/Button.mjs';
import { IconButton } from '../Button/IconButton/IconButton.mjs';
import { Heading } from '../Heading/Heading.mjs';
import { Select } from '../Select/Select.mjs';
import { Tag } from '../Tag/Tag.mjs';
import { Icon } from '../__next__/Icon/Icon.mjs';
import { useMediaQueries } from '../utils/useMediaQueries.mjs';
import { MainActions } from './subcomponents/MainActions.mjs';
import { MobileActions } from './subcomponents/MobileActions.mjs';
import { SecondaryActions } from './subcomponents/SecondaryActions.mjs';
import { isReversed, createTabletOverflowMenuItems } from './utils.mjs';
import styles from './TitleBlockZen.module.scss.mjs';
var renderTag = function (surveyStatus) {
  var tagVariant;
  if (tagVariant === 'profile') {
    return null;
  }
  if (surveyStatus.status === 'draft') {
    tagVariant = 'statusDraft';
  }
  /*
    scheduled is actually a draft survey status that has a launch job scheduled
    still, we want to differentiate on the UI and render a specific tag
    the styles must be identical to the draft style
       we have similar behaviour on programs index page's table
  */
  if (surveyStatus.status === 'scheduled') {
    tagVariant = 'statusClosed';
  }
  if (surveyStatus.status === 'live') {
    tagVariant = 'statusLive';
  }
  if (surveyStatus.status === 'closed') {
    tagVariant = 'statusClosed';
  }
  if (surveyStatus.status === 'sentimentPositive') {
    tagVariant = 'sentimentPositive';
  }
  if (surveyStatus.status === 'default') {
    tagVariant = 'default';
  }
  return /*#__PURE__*/React.createElement("div", {
    "data-automation-id": "survey-status-tag",
    "data-testid": "survey-status-tag",
    className: styles.tag
  }, /*#__PURE__*/React.createElement(Tag, {
    variant: tagVariant,
    size: "small"
  }, surveyStatus.text));
};
var isJSXElement = function (imageElementOrAvatarProps) {
  return 'props' in imageElementOrAvatarProps;
};
var renderAvatar = function (imageElementOrAvatarProps, avatarAutomationId) {
  return isJSXElement(imageElementOrAvatarProps) ? (/*#__PURE__*/React.createElement("div", {
    "data-automation-id": avatarAutomationId,
    "data-testid": avatarAutomationId,
    className: classnames(styles.avatar, styles.withBorder)
  }, imageElementOrAvatarProps)) : (/*#__PURE__*/React.createElement("div", {
    "data-automation-id": avatarAutomationId,
    "data-testid": avatarAutomationId,
    className: styles.avatar
  }, /*#__PURE__*/React.createElement(Avatar, __assign({}, imageElementOrAvatarProps, {
    size: "medium"
  }))));
};
var renderSubtitle = function (subtitle, subtitleAutomationId) {
  return /*#__PURE__*/React.createElement("div", {
    className: styles.subtitle
  }, /*#__PURE__*/React.createElement("span", {
    "data-automation-id": subtitleAutomationId,
    "data-testid": subtitleAutomationId,
    className: styles.subtitleText
  }, subtitle));
};
var defaultRenderSectionTitle = function (sectionTitle, sectionTitleDescription, variant, sectionTitleAutomationId, sectionTitleDescriptionAutomationId) {
  return /*#__PURE__*/React.createElement(React.Fragment, null, sectionTitle && (/*#__PURE__*/React.createElement("div", {
    className: styles.sectionTitle
  }, /*#__PURE__*/React.createElement(Heading, {
    variant: "heading-2",
    color: isReversed(variant) ? 'white' : 'dark',
    classNameOverride: styles.sectionTitleOverride,
    "data-automation-id": sectionTitleAutomationId,
    "data-testid": sectionTitleAutomationId
  }, sectionTitle))), sectionTitleDescription && (/*#__PURE__*/React.createElement("div", {
    "data-automation-id": sectionTitleDescriptionAutomationId,
    "data-testid": sectionTitleDescriptionAutomationId,
    className: classnames(styles.sectionTitleDescription, !isReversed(variant) && styles.dark)
  }, sectionTitleDescription)));
};
var Breadcrumb = function (_a) {
  var breadcrumb = _a.breadcrumb,
    automationId = _a.automationId,
    textAutomationId = _a.textAutomationId,
    textDirection = _a.textDirection;
  var path = breadcrumb.path,
    handleClick = breadcrumb.handleClick,
    text = breadcrumb.text,
    render = breadcrumb.render;
  var InnerContents = function () {
    return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("div", {
      className: styles.circle
    }, /*#__PURE__*/React.createElement(Icon, {
      name: "arrow_back",
      isPresentational: true,
      shouldMirrorInRTL: true
    })), /*#__PURE__*/React.createElement("span", {
      className: styles.breadcrumbTextLink,
      "data-automation-id": textAutomationId,
      "data-testid": textAutomationId
    }, /*#__PURE__*/React.createElement("span", {
      className: styles.breadcrumbText
    }, text)));
  };
  if (render) {
    var CustomRender = render;
    return /*#__PURE__*/React.createElement(CustomRender, {
      breadcrumb: breadcrumb,
      className: styles.breadcrumb,
      automationId: automationId,
      textAutomationId: textAutomationId,
      textDirection: textDirection
    }, /*#__PURE__*/React.createElement(InnerContents, null));
  }
  var TagName = path ? 'a' : 'button';
  return /*#__PURE__*/React.createElement(TagName, __assign({}, path && {
    href: path
  }, {
    className: styles.breadcrumb,
    "data-automation-id": automationId,
    "data-testid": automationId,
    onClick: handleClick
  }), /*#__PURE__*/React.createElement(InnerContents, null));
};
// We want to accept undefined here because the NavigationTabs container is
// important for the flex-based layout (it pushes Secondary Actions over to the right)
var renderNavigationTabs = function (navigationTabs, collapse, ariaLabel) {
  return /*#__PURE__*/React.createElement("div", {
    className: styles.navigationTabScrollerContainer
  }, /*#__PURE__*/React.createElement("div", {
    className: classnames(styles.navigationTabsContainer, collapse && styles.navigationTabsContainerCollapsed)
  }, !collapse && navigationTabs !== undefined && (/*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("span", {
    className: styles.navigationTabEdgeShadowLeft
  }), /*#__PURE__*/React.createElement("nav", {
    className: styles.navigationTabsNav,
    "aria-label": ariaLabel
  }, /*#__PURE__*/React.createElement("ul", {
    className: styles.navigationTabsList
  }, navigationTabs.map(function (navigationTab, index) {
    return /*#__PURE__*/React.createElement("li", {
      key: index
    }, navigationTab);
  }))), /*#__PURE__*/React.createElement("span", {
    className: styles.navigationTabEdgeShadowRight
  })))));
};
/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3075605782/Title+Block Guidance} |
 * {@link https://cultureamp.design/?path=/story/components-titleblock--docs Storybook}
 */
const TitleBlockZen = /*#__PURE__*/function () {
  const TitleBlockZen = function (_a) {
    var _b, _c, _d, _e;
    var title = _a.title,
      variant = _a.variant,
      breadcrumb = _a.breadcrumb,
      avatar = _a.avatar,
      subtitle = _a.subtitle,
      sectionTitle = _a.sectionTitle,
      sectionTitleDescription = _a.sectionTitleDescription,
      renderSectionTitle = _a.renderSectionTitle,
      pageSwitcherSelect = _a.pageSwitcherSelect,
      handleHamburgerClick = _a.handleHamburgerClick,
      primaryAction = _a.primaryAction,
      defaultAction = _a.defaultAction,
      secondaryActions = _a.secondaryActions,
      secondaryOverflowMenuItems = _a.secondaryOverflowMenuItems,
      navigationTabs = _a.navigationTabs,
      _f = _a.collapseNavigationAreaWhenPossible,
      collapseNavigationAreaWhenPossible = _f === void 0 ? false : _f,
      textDirection = _a.textDirection,
      surveyStatus = _a.surveyStatus,
      id = _a.id,
      _g = _a.titleAutomationId,
      titleAutomationId = _g === void 0 ? 'TitleBlock__Title' : _g,
      _h = _a.avatarAutomationId,
      avatarAutomationId = _h === void 0 ? 'TitleBlock__Avatar' : _h,
      _j = _a.subtitleAutomationId,
      subtitleAutomationId = _j === void 0 ? 'TitleBlock__Subtitle' : _j,
      _k = _a.sectionTitleAutomationId,
      sectionTitleAutomationId = _k === void 0 ? 'TitleBlock__SectionTitle' : _k,
      _l = _a.sectionTitleDescriptionAutomationId,
      sectionTitleDescriptionAutomationId = _l === void 0 ? 'TitleBlock__SectionTitleDescription' : _l,
      _m = _a.breadcrumbAutomationId,
      breadcrumbAutomationId = _m === void 0 ? 'TitleBlock__Breadcrumb' : _m,
      _o = _a.breadcrumbTextAutomationId,
      breadcrumbTextAutomationId = _o === void 0 ? 'TitleBlock__BreadcrumbText' : _o,
      _p = _a.autoHideMobileActionsMenu,
      autoHideMobileActionsMenu = _p === void 0 ? false : _p;
    var hasNavigationTabs = navigationTabs && navigationTabs.length > 0;
    var collapseNavigationArea = collapseNavigationAreaWhenPossible && !hasNavigationTabs && secondaryActions === undefined;
    var _q = useMediaQueries().queries,
      isSmall = _q.isSmall,
      isMedium = _q.isMedium;
    var isSmallOrMediumViewport = isMedium || isSmall;
    return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("div", {
      id: id,
      className: classnames(styles.titleBlock, styles["".concat(variant, "Variant")], Boolean(subtitle) && styles.hasSubtitle, Boolean(pageSwitcherSelect) && styles.hasPageSwitcherSelect, collapseNavigationArea && !((_b = sectionTitle !== null && sectionTitle !== void 0 ? sectionTitle : sectionTitleDescription) !== null && _b !== void 0 ? _b : renderSectionTitle) && styles.collapseNavigationArea, title && title.length >= 30 && styles.hasLongTitle, subtitle && typeof subtitle === 'string' && subtitle.length >= 18 && styles.hasLongSubtitle, hasNavigationTabs && styles.hasNavigationTabs)
    }, /*#__PURE__*/React.createElement("div", {
      className: styles.titleRow
    }, /*#__PURE__*/React.createElement("div", {
      className: styles.titleRowInner
    }, /*#__PURE__*/React.createElement("div", {
      className: styles.titleRowInnerContent
    }, /*#__PURE__*/React.createElement("div", {
      className: styles.titleAndAdjacent
    }, breadcrumb && (/*#__PURE__*/React.createElement(Breadcrumb, {
      breadcrumb: breadcrumb,
      automationId: breadcrumbAutomationId,
      textAutomationId: breadcrumbTextAutomationId,
      textDirection: textDirection
    })), /*#__PURE__*/React.createElement("div", {
      className: styles.titleAndAdjacentNotBreadcrumb
    }, /*#__PURE__*/React.createElement(React.Fragment, null, handleHamburgerClick && (/*#__PURE__*/React.createElement("div", {
      className: styles.hamburger
    }, /*#__PURE__*/React.createElement(IconButton, {
      onClick: handleHamburgerClick,
      icon: /*#__PURE__*/React.createElement(Icon, {
        name: "menu",
        isPresentational: true
      }),
      label: "Open menu",
      reversed: isReversed(variant)
    }))), avatar && renderAvatar(avatar, avatarAutomationId), /*#__PURE__*/React.createElement("div", {
      className: styles.titleAndSubtitle
    }, /*#__PURE__*/React.createElement("div", {
      className: styles.titleAndSubtitleInner
    }, /*#__PURE__*/React.createElement("div", {
      className: styles.title
    }, /*#__PURE__*/React.createElement(Heading, {
      variant: "composable-header-title",
      color: isReversed(variant) ? 'white' : 'dark',
      classNameOverride: styles.titleTextOverride,
      "data-automation-id": titleAutomationId,
      "data-testid": titleAutomationId
    }, title)), isSmallOrMediumViewport && pageSwitcherSelect && (/*#__PURE__*/React.createElement("div", {
      className: styles.pageSwitcherSelectUnderneathTitle
    }, /*#__PURE__*/React.createElement(Select, __assign({}, pageSwitcherSelect, {
      variant: "secondary-small",
      reversed: true
    })))), subtitle && renderSubtitle(subtitle, subtitleAutomationId))), surveyStatus && renderTag(surveyStatus), !isSmallOrMediumViewport && pageSwitcherSelect && (/*#__PURE__*/React.createElement("div", {
      className: styles.pageSwitcherSelectNextToTitle
    }, /*#__PURE__*/React.createElement(Select, __assign({}, pageSwitcherSelect, {
      variant: "secondary",
      reversed: true,
      fullWidth: true
    }))))))), ((_d = (_c = primaryAction !== null && primaryAction !== void 0 ? primaryAction : defaultAction) !== null && _c !== void 0 ? _c : secondaryActions) !== null && _d !== void 0 ? _d : secondaryOverflowMenuItems) && (/*#__PURE__*/React.createElement(MainActions, {
      primaryAction: primaryAction,
      defaultAction: defaultAction,
      reversed: isReversed(variant),
      overflowMenuItems: createTabletOverflowMenuItems(secondaryActions, secondaryOverflowMenuItems),
      showOverflowMenu: isSmallOrMediumViewport
    }))))), /*#__PURE__*/React.createElement("div", {
      className: styles.rowBelowSeparator
    }, /*#__PURE__*/React.createElement("div", {
      className: styles.rowBelowSeparatorInner
    }, /*#__PURE__*/React.createElement("div", {
      className: styles.rowBelowSeparatorInnerContent
    }, ((_e = sectionTitle !== null && sectionTitle !== void 0 ? sectionTitle : sectionTitleDescription) !== null && _e !== void 0 ? _e : renderSectionTitle) && (/*#__PURE__*/React.createElement("div", {
      className: styles.sectionTitleContainer
    }, /*#__PURE__*/React.createElement("div", {
      className: styles.sectionTitleInner
    }, renderSectionTitle ? renderSectionTitle({
      sectionTitle: sectionTitle,
      sectionTitleAutomationId: sectionTitleAutomationId,
      sectionTitleDescription: sectionTitleDescription,
      sectionTitleDescriptionAutomationId: sectionTitleDescriptionAutomationId
    }) : defaultRenderSectionTitle(sectionTitle, sectionTitleDescription, variant, sectionTitleAutomationId, sectionTitleDescriptionAutomationId)))), renderNavigationTabs(navigationTabs, collapseNavigationArea, title), (secondaryActions !== null && secondaryActions !== void 0 ? secondaryActions : secondaryOverflowMenuItems) && (/*#__PURE__*/React.createElement(SecondaryActions, {
      secondaryActions: secondaryActions,
      secondaryOverflowMenuItems: secondaryOverflowMenuItems,
      reversed: isReversed(variant)
    }))))), /*#__PURE__*/React.createElement(MobileActions, {
      primaryAction: primaryAction,
      defaultAction: defaultAction,
      secondaryActions: secondaryActions,
      secondaryOverflowMenuItems: secondaryOverflowMenuItems,
      drawerHandleLabelIconPosition: primaryAction && 'iconPosition' in primaryAction ? primaryAction.iconPosition : undefined,
      autoHide: autoHideMobileActionsMenu
    })));
  };
  TitleBlockZen.displayName = 'TitleBlockZen';
  return TitleBlockZen;
}();
export { TitleBlockZen };
