import { __assign } from 'tslib';
import React, { useState, useId, useRef, useEffect, cloneElement } from 'react';
import ReactDOM from 'react-dom';
import classnames from 'classnames';
import { usePopper } from 'react-popper';
import { AnimationProvider, useAnimation } from './subcomponents/AppearanceAnim.mjs';
import { isSemanticElement } from './utils/isSemanticElement.mjs';
import styles from './Tooltip.module.scss.mjs';
var positionToPlacement = new Map([['above', 'top'], ['below', 'bottom'], ['left', 'left'], ['right', 'right']]);
// Sync with Tooltip.scss
var arrowHeight = 7;
var arrowWidth = 14;
var TooltipContent = function (_a) {
  var position = _a.position,
    text = _a.text,
    referenceElement = _a.referenceElement,
    tooltipId = _a.tooltipId,
    _b = _a.mood,
    mood = _b === void 0 ? 'default' : _b;
  var _c = useState(null),
    popperElement = _c[0],
    setPopperElement = _c[1];
  var _d = useState(null),
    arrowElement = _d[0],
    setArrowElement = _d[1];
  var _e = usePopper(referenceElement, popperElement, {
      modifiers: [{
        name: 'arrow',
        options: {
          element: arrowElement,
          // Ensures that the arrow doesn't go too far to the left or right
          // of the tooltip.
          padding: arrowWidth / 2 + 10
        }
      }, {
        name: 'offset',
        options: {
          offset: [0, arrowHeight + 6]
        }
      }, {
        name: 'preventOverflow',
        options: {
          // Makes sure that the tooltip isn't flush up against the end of the
          // viewport
          padding: 8,
          altAxis: true,
          altBoundary: true,
          tetherOffset: 50
        }
      }, {
        name: 'flip',
        options: {
          padding: 8,
          altBoundary: true,
          fallbackPlacements: ['left', 'top', 'bottom', 'right']
        }
      }],
      placement: position ? positionToPlacement.get(position) : undefined
    }),
    popperStyles = _e.styles,
    attributes = _e.attributes;
  var _f = useAnimation(),
    isVisible = _f.isVisible,
    isAnimIn = _f.isAnimIn,
    isAnimOut = _f.isAnimOut;
  return isVisible || isAnimOut || isAnimIn ? (/*#__PURE__*/React.createElement("div", __assign({
    ref: setPopperElement,
    className: styles.tooltip,
    style: popperStyles.popper
  }, attributes.popper, {
    role: "tooltip",
    id: tooltipId
  }), /*#__PURE__*/React.createElement("div", {
    className: classnames(styles.tooltipContent, styles[mood])
  }, text), /*#__PURE__*/React.createElement("div", {
    ref: setArrowElement,
    className: styles.arrow,
    style: popperStyles.arrow
  }, /*#__PURE__*/React.createElement("div", {
    className: styles.arrowInner
  }, /*#__PURE__*/React.createElement("div", {
    className: classnames(styles.arrowMain, styles[mood])
  }), /*#__PURE__*/React.createElement("div", {
    className: styles.arrowShadow
  }))))) : null;
};
var renderChildren = function (content, tooltipId, hasActiveTooltip) {
  if (isSemanticElement(content)) {
    return /*#__PURE__*/cloneElement(content, {
      'aria-describedby': hasActiveTooltip ? tooltipId : undefined
    });
  }
  // We don't want to block them from this but just provide context for better a11y guidance
  // eslint-disable-next-line no-console
  console.warn('<Tooltip /> is not directly wrapping a semantic element, screen reader users will not be able to access the tooltip info. To ensure accessibility, Tooltip should be wrapping a semantic and focusable element directly.');
  return content;
};
const Tooltip = /*#__PURE__*/function () {
  const Tooltip = function (_a) {
    var children = _a.children,
      text = _a.text,
      _b = _a.display,
      display = _b === void 0 ? 'block' : _b,
      _c = _a.position,
      position = _c === void 0 ? 'above' : _c,
      classNameOverride = _a.classNameOverride,
      portalSelector = _a.portalSelector,
      animationDuration = _a.animationDuration,
      _d = _a.isInitiallyVisible,
      isInitiallyVisible = _d === void 0 ? false : _d,
      _e = _a.mood,
      mood = _e === void 0 ? 'default' : _e;
    var _f = useState(isInitiallyVisible),
      isHover = _f[0],
      setIsHover = _f[1];
    var _g = useState(false),
      isFocus = _g[0],
      setIsFocus = _g[1];
    var _h = useState(null),
      referenceElement = _h[0],
      setReferenceElement = _h[1];
    var tooltipId = useId();
    var hasActiveTooltip = isHover || isFocus;
    var tooltip = /*#__PURE__*/React.createElement(TooltipContent, {
      text: text,
      position: position,
      referenceElement: referenceElement,
      tooltipId: tooltipId,
      mood: mood
    });
    var portalSelectorElementRef = useRef(null);
    useEffect(function () {
      portalSelectorElementRef.current = portalSelector ? document.querySelector(portalSelector) : null;
    }, [portalSelector]);
    useEffect(function () {
      if (portalSelector && !portalSelectorElementRef.current) {
        // eslint-disable-next-line no-console
        console.warn('The portal could not be created using the selector: ' + portalSelector);
      }
    }, [portalSelectorElementRef, portalSelector]);
    var getDisplayClassName = function () {
      switch (display) {
        case 'inline':
          return styles.displayInline;
        case 'block':
          return styles.displayBlock;
        case 'inline-block':
          return styles.displayInlineBlock;
        case 'flex':
          return styles.displayFlex;
        case 'inline-flex':
          return styles.displayInlineFlex;
        default:
          return undefined;
      }
    };
    return /*#__PURE__*/React.createElement(AnimationProvider, {
      isVisible: hasActiveTooltip,
      animationDuration: animationDuration
    }, /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("div", {
      ref: setReferenceElement,
      className: classnames(classNameOverride, getDisplayClassName()),
      onMouseEnter: function () {
        return setIsHover(true);
      },
      onMouseLeave: function () {
        return setIsHover(false);
      },
      onFocusCapture: function () {
        return setIsFocus(true);
      },
      onBlurCapture: function () {
        return setIsFocus(false);
      }
    }, renderChildren(children, tooltipId, hasActiveTooltip)), portalSelector && portalSelectorElementRef.current ? /*#__PURE__*/ReactDOM.createPortal(tooltip, portalSelectorElementRef.current) : tooltip));
  };
  Tooltip.displayName = 'Tooltip';
  return Tooltip;
}();
export { Tooltip };
