import { __rest, __assign } from 'tslib';
import React, { useId, useState, useEffect } from 'react';
import { useButton } from '@react-aria/button';
import { useSelect, HiddenSelect } from '@react-aria/select';
import { useSelectState } from '@react-stately/select';
import classnames from 'classnames';
import { FieldMessage } from '../../FieldMessage/FieldMessage.mjs';
import { Popover } from '../../MultiSelect/subcomponents/Popover/Popover.mjs';
import { useFloating } from '@floating-ui/react-dom';
import { SelectProvider } from './context/SelectContext.mjs';
import { ListBox } from './subcomponents/ListBox/ListBox.mjs';
import { ListBoxSection } from './subcomponents/ListBoxSection/ListBoxSection.mjs';
import { ListItem } from './subcomponents/ListItem/ListItem.mjs';
import './subcomponents/ListItems/ListItems.mjs';
import { Option } from './subcomponents/Option/Option.mjs';
import './subcomponents/Overlay/Overlay.mjs';
import { SectionDivider } from './subcomponents/SectionDivider/SectionDivider.mjs';
import { SelectPopoverContents } from './subcomponents/SelectPopoverContents/SelectPopoverContents.mjs';
import { SelectToggle } from './subcomponents/SelectToggle/SelectToggle.mjs';
import { getDisabledKeysFromItems } from './utils/getDisabledKeysFromItems.mjs';
import { transformSelectItemToCollectionElement } from './utils/transformSelectItemToCollectionElement.mjs';
import styles from './Select.module.scss.mjs';

/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3081896474/Select Guidance} |
 * {@link https://cultureamp.design/?path=/docs/components-select--docs Storybook}
 */
const Select = /*#__PURE__*/function () {
  const Select = function (_a) {
    var _b;
    var label = _a.label,
      items = _a.items,
      propsId = _a.id,
      trigger = _a.trigger,
      children = _a.children,
      status = _a.status,
      validationMessage = _a.validationMessage,
      isReversed = _a.isReversed,
      isFullWidth = _a.isFullWidth,
      disabledValues = _a.disabledValues,
      classNameOverride = _a.classNameOverride,
      selectedKey = _a.selectedKey,
      description = _a.description,
      _c = _a.placeholder,
      placeholder = _c === void 0 ? '' : _c,
      isDisabled = _a.isDisabled,
      onSelectionChange = _a.onSelectionChange,
      portalContainerId = _a.portalContainerId,
      restProps = __rest(_a, ["label", "items", "id", "trigger", "children", "status", "validationMessage", "isReversed", "isFullWidth", "disabledValues", "classNameOverride", "selectedKey", "description", "placeholder", "isDisabled", "onSelectionChange", "portalContainerId"]);
    var refs = useFloating().refs;
    var triggerRef = refs.reference;
    var fallbackId = useId();
    var id = propsId !== null && propsId !== void 0 ? propsId : fallbackId;
    var descriptionId = "".concat(id, "--description");
    var validationId = "".concat(id, "--validation");
    var popoverId = "".concat(id, "--popover");
    var disabledKeys = getDisabledKeysFromItems(items);
    var ariaSelectProps = __assign({
      label: label,
      items: items,
      children: transformSelectItemToCollectionElement,
      disabledKeys: disabledValues !== null && disabledValues !== void 0 ? disabledValues : disabledKeys,
      selectedKey: typeof selectedKey === 'number' ? selectedKey.toString() : selectedKey,
      description: description,
      placeholder: placeholder,
      isDisabled: isDisabled,
      onSelectionChange: onSelectionChange ? function (key) {
        return onSelectionChange(key);
      } : undefined
    }, restProps);
    var state = useSelectState(ariaSelectProps);
    var _d = useSelect(ariaSelectProps, state, triggerRef),
      labelProps = _d.labelProps,
      reactAriaTriggerProps = _d.triggerProps,
      valueProps = _d.valueProps,
      menuProps = _d.menuProps,
      errorMessageProps = _d.errorMessageProps,
      descriptionProps = _d.descriptionProps;
    // Hack incoming:
    // react-aria/useSelect wants to prefix the combobox's accessible name with the value of the select.
    // We use role=combobox, meaning screen readers will read the value.
    // So we're modifying the `aria-labelledby` property to remove the value element id.
    // Issue: https://github.com/adobe/react-spectrum/issues/4091
    var reactAriaLabelledBy = reactAriaTriggerProps['aria-labelledby'];
    var triggerProps = __assign(__assign({}, reactAriaTriggerProps), {
      'aria-labelledby': reactAriaLabelledBy === null || reactAriaLabelledBy === void 0 ? void 0 : reactAriaLabelledBy.substring(reactAriaLabelledBy.indexOf(' ') + 1)
    });
    var buttonProps = useButton(triggerProps, triggerRef).buttonProps;
    var selectToggleProps = __assign(__assign({}, buttonProps), {
      label: label,
      labelProps: labelProps,
      'value': (_b = state === null || state === void 0 ? void 0 : state.selectedItem) === null || _b === void 0 ? void 0 : _b.rendered,
      valueProps: valueProps,
      'isOpen': state.isOpen,
      placeholder: placeholder,
      status: status,
      'isDisabled': triggerProps.isDisabled,
      isReversed: isReversed,
      'ref': refs.setReference,
      'aria-describedby': classnames(validationMessage && validationId, description && descriptionId)
    });
    var _e = useState(),
      portalContainer = _e[0],
      setPortalContainer = _e[1];
    useEffect(function () {
      if (portalContainerId) {
        var portalElement = document.getElementById(portalContainerId);
        if (portalElement) setPortalContainer(portalElement);
      }
    }, [portalContainerId]);
    return /*#__PURE__*/React.createElement("div", {
      className: classnames(!isFullWidth && styles.notFullWidth, classNameOverride)
    }, /*#__PURE__*/React.createElement(HiddenSelect, {
      label: label,
      name: id,
      state: state,
      triggerRef: triggerRef
    }), /*#__PURE__*/React.createElement("div", {
      className: styles.container
    }, trigger === undefined ? (/*#__PURE__*/React.createElement(SelectToggle, __assign({}, selectToggleProps))) : trigger(selectToggleProps, selectToggleProps.ref), state.isOpen && (/*#__PURE__*/React.createElement(Popover, {
      id: popoverId,
      portalContainer: portalContainer,
      refs: refs
    }, /*#__PURE__*/React.createElement(SelectProvider, {
      state: state
    }, /*#__PURE__*/React.createElement(SelectPopoverContents, {
      menuProps: menuProps,
      popoverRef: refs.floating
    }, children))))), validationMessage && (/*#__PURE__*/React.createElement(FieldMessage, __assign({}, errorMessageProps, {
      id: validationId,
      message: validationMessage,
      status: status,
      reversed: isReversed
    }))), description && (/*#__PURE__*/React.createElement(FieldMessage, __assign({}, descriptionProps, {
      id: descriptionId,
      message: description,
      reversed: isReversed
    }))));
  };
  Select.displayName = 'Select';
  Select.Section = ListBoxSection;
  Select.SectionDivider = SectionDivider;
  Select.Option = Option;
  Select.ItemDefaultRender = ListItem;
  // @deprecated Legacy exported aliases
  Select.TriggerButton = SelectToggle;
  Select.ListBox = ListBox;
  return Select;
}();
export { Select };
