import { __rest, __assign } from 'tslib';
import React, { useRef, useEffect } from 'react';
import { useListBox } from '@react-aria/listbox';
import classnames from 'classnames';
import { useIsClientReady } from '../../../../utils/useIsClientReady/useIsClientReady.mjs';
import { useSelectContext } from '../../context/SelectContext.mjs';
import styles from './ListBox.module.scss.mjs';

/** A util to retrieve the key of the correct focusable items based of the focus strategy
 * This is used to determine which element from the collection to focus to on open base on the keyboard event
 * ie: UpArrow will set the focusStrategy to "last"
 */
var getOptionKeyFromCollection = function (state) {
  if (state.selectedItem) {
    return state.selectedItem.key;
  } else if (state.focusStrategy === 'last') {
    return state.collection.getLastKey();
  }
  return state.collection.getFirstKey();
};
/** This makes the use of query selector less brittle in instances where a failed selector is passed in
 */
var safeQuerySelector = function (selector) {
  try {
    return document.querySelector(selector);
  } catch (error) {
    // eslint-disable-next-line no-console
    console.error('Kaizen querySelector failed:', error);
    return null;
  }
};
const ListBox = /*#__PURE__*/function () {
  const ListBox = function (_a) {
    var children = _a.children,
      menuProps = _a.menuProps,
      classNameOverride = _a.classNameOverride,
      restProps = __rest(_a, ["children", "menuProps", "classNameOverride"]);
    var isClientReady = useIsClientReady();
    var state = useSelectContext().state;
    var ref = useRef(null);
    var listBoxProps = useListBox(__assign(__assign({}, menuProps), {
      disallowEmptySelection: true,
      // This is to ensure that the listbox doesn't use React Aria's auto focus feature for Listbox, which creates a visual bug
      autoFocus: false
    }), state, ref).listBoxProps;
    /**
     * This uses the new useIsClientReady to ensure document exists before trying to querySelector and give the time to focus to the correct element
     */
    useEffect(function () {
      var _a;
      if (isClientReady) {
        var optionKey = getOptionKeyFromCollection(state);
        var focusToElement = safeQuerySelector("[data-key='".concat(optionKey, "']"));
        if (focusToElement) {
          focusToElement.focus();
        } else {
          // If an element is not found, focus on the listbox. This ensures the list can still be navigated to via keyboard if the keys do not align to the data attributes of the list items.
          (_a = ref.current) === null || _a === void 0 ? void 0 : _a.focus();
        }
      }
      // Only run this effect for checking the first successful render
      // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [isClientReady]);
    return /*#__PURE__*/React.createElement("ul", __assign({
      ref: ref,
      className: classnames(styles.listBox, classNameOverride)
    }, listBoxProps, restProps), children);
  };
  ListBox.displayName = 'ListBox';
  return ListBox;
}();
export { ListBox };
