import { __rest, __assign } from 'tslib';
import React, { forwardRef, useContext, useState, useLayoutEffect } from 'react';
import { useContextProps, TooltipContext, TooltipTriggerStateContext, Tooltip as Tooltip$1 } from 'react-aria-components';
export { TooltipContext } from 'react-aria-components';
import { VisuallyHidden } from '../../VisuallyHidden/VisuallyHidden.mjs';
import { useReversedColors } from '../../utils/ReversedColors/ReversedColors.mjs';
import { mergeClassNames } from '../../utils/mergeClassNames.mjs';
import { OverlayArrow } from './OverlayArrow.mjs';
import styles from './Tooltip.module.scss.mjs';

/**
 * A tooltip displays a description of an element on hover or focus.
 */
const Tooltip = /*#__PURE__*/function () {
  const Tooltip = /*#__PURE__*/forwardRef(function (_a, ref) {
    var children = _a.children,
      className = _a.className,
      props = __rest(_a, ["children", "className"]);
    var triggerRef = useContextProps(__assign({
      children: children,
      className: className
    }, props), ref, TooltipContext)[0].triggerRef;
    var contextState = useContext(TooltipTriggerStateContext);
    var reverseColors = useReversedColors();
    var _b = useState(false),
      shouldInlineHiddenContent = _b[0],
      setShouldInlineHiddenContent = _b[1];
    useLayoutEffect(function () {
      var _a;
      setShouldInlineHiddenContent(!!((_a = triggerRef === null || triggerRef === void 0 ? void 0 : triggerRef.current) === null || _a === void 0 ? void 0 : _a.getAttribute('data-inline-hidden-content')));
    }, [triggerRef]);
    return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Tooltip$1, __assign({
      ref: ref,
      offset: 8
    }, props, {
      className: mergeClassNames(styles.tooltip, className, reverseColors && styles.reversed)
    }), function (renderProps) {
      return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(OverlayArrow, null), typeof children === 'function' ? children(renderProps) : children);
    }), shouldInlineHiddenContent ? (/*#__PURE__*/React.createElement(VisuallyHidden, null, typeof children === 'function' ? contextState && children({
      placement: 'center',
      isEntering: false,
      isExiting: false,
      state: contextState,
      defaultChildren: undefined
    }) : children)) : null);
  });
  Tooltip.displayName = 'Tooltip';
  return Tooltip;
}();
export { Tooltip };
