import { type HTMLAttributes } from 'react';
import { type CompanyAvatarProps, type GenericAvatarProps } from "../Avatar";
import { type OverrideClassName } from "../types/OverrideClassName";
export type AvatarGroupAvatarProps = Omit<GenericAvatarProps, 'size'> | Omit<CompanyAvatarProps, 'size'>;
export type AvatarGroupSize = 'small' | 'medium' | 'large';
export type AvatarList = [AvatarGroupAvatarProps, ...AvatarGroupAvatarProps[]];
export type AvatarGroupProps = {
    /**
     * There are 3 fixed sizes available. `"small"` will remove border and box shadow to save space.
     * @default "medium"
     */
    size?: AvatarGroupSize;
    /**
     * If the length of Avatars exceeds the `maxVisible` a counter token will render
     * @default 2
     */
    maxVisible: 2 | 3 | 4 | 5 | 6;
    /**
     * Takes a array of `AvatarProps` that must have at least item.
     * Note that 'size' is omitted from the `AvatarProps` type so it will throw a type error if size is provided.
     * */
    avatars: AvatarList;
} & OverrideClassName<HTMLAttributes<HTMLUListElement>>;
/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3065021264/Avatar+Group Guidance} |
 * {@link https://cultureamp.design/?path=/docs/components-avatar-avatar-group--docs Storybook}
 */
export declare const AvatarGroup: ({ size, maxVisible, avatars, classNameOverride, ...restProps }: AvatarGroupProps) => JSX.Element;
