import React, { type HTMLAttributes } from 'react';
import { type HeadingProps } from "../Heading";
import { type AnimatedSceneProps } from "../Illustration";
import { type OverrideClassName } from "../types/OverrideClassName";
export type EmptyStateProps = {
    children?: React.ReactNode;
    id?: string;
    /** @deprecated Use `variant` instead */
    illustrationType?: 'positive' | 'informative' | 'negative' | 'action' | 'neutral';
    /**
     * If you are transitioning from `illustrationType`:
     * - `positive` should be `success`
     * - `informative` remains as `informative`
     * - `negative` should be `warning`
     * - `action` should be `warning`
     * - `neutral` should be `expert-advice`
     * @default informative
     */
    variant?: 'success' | 'warning' | 'informative' | 'expert-advice';
    /** @deprecated - This prop no longer has any effect */
    layoutContext?: 'sidebarAndContent' | 'contentOnly';
    bodyText: string | React.ReactNode;
    straightCorners?: boolean;
    headingProps?: HeadingProps;
} & OverrideClassName<HTMLAttributes<HTMLDivElement>> & Pick<AnimatedSceneProps, 'isAnimated' | 'loop'>;
/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3082094098/Empty+State Guidance} |
 * {@link https://cultureamp.design/?path=/docs/components-empty-state--docs Storybook}
 */
export declare const EmptyState: {
    ({ children, id, illustrationType, variant, layoutContext: _, headingProps, bodyText, straightCorners, isAnimated, loop, classNameOverride, ...props }: EmptyStateProps): JSX.Element;
    displayName: string;
};
