import { type FilterAttributes, type FilterState, type Filters, type FiltersValues } from '../types';
import { type ActiveFiltersArray } from './types';
export type FilterBarContextValue<Value, ValuesMap extends FiltersValues = Record<string, Value>> = {
    getFilterState: <Id extends keyof ValuesMap>(id: Id) => FilterState<keyof ValuesMap, ValuesMap[Id]>;
    isClearable: boolean;
    getActiveFilterValues: () => Partial<ValuesMap>;
    /**
     * @deprecated Use `setFilterOpenState` instead.
     */
    toggleOpenFilter: <Id extends keyof ValuesMap>(id: Id, isOpen: boolean) => void;
    setFilterOpenState: <Id extends keyof ValuesMap>(id: Id, isOpen: boolean) => void;
    openFilter: <Id extends keyof ValuesMap>(id: Id) => void;
    updateValue: <Id extends keyof ValuesMap>(id: Id, value: ValuesMap[Id]) => void;
    showFilter: <Id extends keyof ValuesMap>(id: Id) => void;
    hideFilter: <Id extends keyof ValuesMap>(id: Id) => void;
    getInactiveFilters: () => FilterAttributes<ValuesMap>[];
    clearAllFilters: () => void;
    setFocus: <Id extends keyof ValuesMap>(id: Id | undefined) => void;
    focusId?: keyof ValuesMap;
};
export declare const useFilterBarContext: <Value, Values extends FiltersValues = Record<string, Value>>() => FilterBarContextValue<Value, Values>;
export type FilterBarProviderProps<ValuesMap extends FiltersValues> = {
    children: (activeFilters: ActiveFiltersArray<ValuesMap>) => JSX.Element;
    filters: Filters<ValuesMap>;
    values: Partial<ValuesMap>;
    onValuesChange: (values: Partial<ValuesMap>) => void;
};
export declare const FilterBarProvider: <ValuesMap extends FiltersValues>({ children, filters, values, onValuesChange, }: FilterBarProviderProps<ValuesMap>) => JSX.Element;
