import React from 'react';
import { type ButtonProps as V1ButtonProps } from "../Button";
import { type HeadingProps } from "../Heading";
import { type SceneProps, type SpotProps } from "../Illustration";
import { type TooltipProps } from "../Tooltip";
import { type VariantType } from './types';
export type ActionProps = V1ButtonProps & {
    'tooltip'?: TooltipProps;
    'aria-label'?: string;
    'aria-labelledby'?: string;
    'aria-describedby'?: string;
};
type LayoutType = 'default' | 'inline' | 'stacked';
type IllustrationType = 'spot' | 'scene';
type TextAlignment = 'center' | 'left';
type GuidanceBlockActions = {
    primary: ActionProps;
    secondary?: ActionProps;
    dismiss?: {
        onClick: () => void;
    };
};
type BaseGuidanceBlockProps = {
    layout?: LayoutType;
    illustration: React.ReactElement<SpotProps | SceneProps>;
    illustrationType?: IllustrationType;
    smallScreenTextAlignment?: TextAlignment;
    /** @deprecated use the `actionsSlot` prop with Button/next instead */
    actions?: GuidanceBlockActions;
    /** A slot for the primary and secondary action. It is recommended to use the {@link https://cultureamp.design/?path=/docs/components-button-button-next-api-specification--docs | Button} or {@link https://cultureamp.design/?path=/docs/components-linkbutton-usage-guidelines--docs | LinkButton} wrapped in fragment. */
    actionsSlot?: React.ReactNode;
    /** @deprecated this is no longer a used feature and is only the deprecated `actions` prop, ie: {secondary: { label: "Dismiss action" }}` */
    secondaryDismiss?: boolean;
    variant?: VariantType;
    /**  @deprecated use the `actionsSlot` and pass the icon into the JSX elements */
    withActionButtonArrow?: boolean;
    noMaxWidth?: boolean;
};
type GuidanceBlockWithText = {
    text: {
        title: string;
        titleTag?: HeadingProps['tag'];
        description: string | React.ReactNode;
    };
} & BaseGuidanceBlockProps;
type GuidanceBlockPropsWithContent = {
    content: React.ReactElement;
} & BaseGuidanceBlockProps;
export type GuidanceBlockProps = GuidanceBlockWithText | GuidanceBlockPropsWithContent;
export type GuidanceBlockState = {
    hidden: boolean;
    removed: boolean;
};
/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3082093807/Guidance+Block Guidance} |
 * {@link https://cultureamp.design/?path=/docs/components-guidanceblock--docs Storybook}
 */
export declare const GuidanceBlock: {
    ({ layout, variant, withActionButtonArrow, noMaxWidth, illustrationType, smallScreenTextAlignment, actions, illustration, secondaryDismiss, actionsSlot, ...restProps }: GuidanceBlockProps): JSX.Element;
    displayName: string;
};
export {};
