import React from 'react';
import type { ButtonProps } from "../Button";
import { type StatelessMenuProps } from './subcomponents/StatelessMenu';
type ButtonPropsWithOptionalAria = ButtonProps & {
    'aria-haspopup'?: boolean;
    'aria-expanded'?: boolean;
};
export type MenuProps = Omit<StatelessMenuProps, 'renderButton' | 'hideMenuDropdown' | 'toggleMenuDropdown' | 'isMenuVisible'> & {
    /**
     * The initial state of the dropdown. Once initalised, further changes to this
     * prop will not have any affect, as the state is handled internally to the component.
     * @default: false
     */
    menuVisible?: boolean;
    /**
     * Takes any ReactElement with button props but is most commonly used with a Kaizen `<Button>` or `<IconButton>` component.
     */
    button: React.ReactElement<ButtonPropsWithOptionalAria>;
};
/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3082059782/Menu Guidance} |
 * {@link https://cultureamp.design/?path=/docs/components-menu--docs Storybook}
 */
export declare const Menu: {
    ({ button, menuVisible, ...rest }: MenuProps): JSX.Element;
    displayName: string;
};
export {};
