import React, { type HTMLAttributes } from 'react';
type Mood = 'positive' | 'informative' | 'negative' | 'cautionary' | 'assertive';
type Variant = 'success' | 'informative' | 'warning' | 'cautionary';
type BaseConfirmationModalProps = {
    isOpen: boolean;
    unpadded?: boolean;
    /**
     * To display the Prominent variation of the modal types
     */
    isProminent?: boolean;
    title: string;
    onConfirm?: () => void;
    onDismiss: () => void;
    /** A callback that is triggered after the modal is opened. */
    onAfterEnter?: () => void;
    /** A callback that is triggered after the modal is closed. */
    onAfterLeave?: () => void;
    confirmLabel?: string;
    dismissLabel?: string;
    confirmWorking?: {
        label: string;
        labelHidden?: boolean;
    };
    /**
     * @deprecated Please use data-testid
     */
    automationId?: string;
    children: React.ReactNode;
} & HTMLAttributes<HTMLDivElement>;
type ConfirmationModalMoods = {
    /**
     * @deprecated Please use `variant` instead
     */
    mood: Mood;
    variant?: never;
};
type ConfirmationModalVariants = {
    /**
     * @deprecated Please use `variant` instead
     */
    mood?: never;
    /**
     * If you are transitioning from Moods:
     * - `positive` should be `success`
     * - `negative` should be `warning`
     * - `assertive` should be `cautionary`
     */
    variant: Variant;
};
export type ConfirmationModalProps = BaseConfirmationModalProps & (ConfirmationModalMoods | ConfirmationModalVariants);
/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3082093114/Modal Guidance} |
 * {@link https://cultureamp.design/?path=/docs/components-modals-confirmationmodal--docs Storybook}
 */
export declare const ConfirmationModal: {
    ({ isOpen, isProminent, unpadded, mood, variant, title, onConfirm, onAfterLeave, onAfterEnter, confirmLabel, dismissLabel, confirmWorking, onDismiss: propsOnDismiss, children, className, ...props }: ConfirmationModalProps): JSX.Element;
    displayName: string;
};
export {};
