import React, { type HTMLAttributes } from 'react';
export type InputEditModalProps = {
    isOpen: boolean;
    unpadded?: boolean;
    /**
     * @deprecated we are no longer supporting different moods for InputModal, instead there will only be a single default variant set by the component.
     */
    mood?: 'positive' | 'destructive';
    title: string;
    onSubmit: () => void;
    onSecondaryAction?: () => void;
    onDismiss: () => void;
    /** A callback that is triggered after the modal is opened. */
    onAfterEnter?: () => void;
    /** A callback that is triggered after the modal is closed. */
    onAfterLeave?: () => void;
    submitLabel?: string;
    dismissLabel?: string;
    secondaryLabel?: string;
    /**
     * @deprecated Please use data-testid
     */
    automationId?: string;
    children: React.ReactNode;
    submitWorking?: {
        label: string;
        labelHidden?: boolean;
    };
} & Omit<HTMLAttributes<HTMLDivElement>, 'onSubmit'>;
/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3082093114/Modal#Input-Edit-Modal Guidance} |
 * {@link https://cultureamp.design/?path=/docs/components-modals-inputeditmodal--docs Storybook}
 */
export declare const InputEditModal: {
    ({ isOpen, mood, title, onSubmit, onSecondaryAction, onAfterLeave, submitLabel, dismissLabel, secondaryLabel, submitWorking, children, unpadded, onDismiss: propsOnDismiss, onAfterEnter, className, ...props }: InputEditModalProps): JSX.Element;
    displayName: string;
};
