import React, { type HTMLAttributes, type ReactNode } from 'react';
import { type OverrideClassName } from "../../types/OverrideClassName";
import { type EditorContentArray, type EditorRows, type ToolbarItems } from '../types';
import { ProseMirrorState } from '../utils/prosemirror';
type BaseRichTextEditorProps = {
    id?: string;
    onChange: (content: ProseMirrorState.EditorState) => void;
    defaultValue: EditorContentArray;
    controls?: ToolbarItems[];
    /**
     * Sets a default min-height for the editable area in units of body paragraph line height, similar to the 'rows' attribute on <textarea>.
     * The editable area will autogrow, so this only affects the component when the content doesn't exceed this height.
     */
    rows?: EditorRows;
    dataError?: React.ReactElement;
    onDataError?: () => void;
    status?: 'default' | 'error' | 'caution';
    /**
     * A descriptive message for `error` or `caution` states
     */
    validationMessage?: React.ReactNode;
    /**
     * A description that provides context
     */
    description?: React.ReactNode;
} & OverrideClassName<Omit<HTMLAttributes<HTMLDivElement>, 'onChange' | 'defaultValue'>>;
type WithLabelText = {
    'labelText': ReactNode;
    'aria-labelledby'?: never;
};
type WithLabelledBy = {
    'labelText'?: never;
    'aria-labelledby': string;
};
export type RichTextEditorProps = BaseRichTextEditorProps & (WithLabelText | WithLabelledBy);
/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3081896752/Rich+Text+Editor Guidance} |
 * {@link https://cultureamp.design/?path=/docs/components-richtexteditor--docs Storybook}
 */
export declare const RichTextEditor: {
    ({ id, onChange, defaultValue, labelText, "aria-labelledby": labelledBy, "aria-describedby": describedBy, classNameOverride, controls, rows, dataError, onDataError, validationMessage, description, status, ...restProps }: RichTextEditorProps): JSX.Element;
    displayName: string;
};
export {};
