import React from 'react';
import { type Props as ReactSelectProps } from 'react-select';
import { type AsyncProps as ReactAsyncSelectProps } from 'react-select/async';
export type SelectProps = {
    /**
     * The secondary variant is a more subdued variant that takes up as little space as possible
     * `variant="secondary" reversed="false" is not implemented and will throw a "not implemented" error
     * @default "default"
     */
    variant?: 'default' | 'secondary' | 'secondary-small';
    status?: 'default' | 'error';
    label?: React.ReactNode;
    validationMessage?: React.ReactNode;
    description?: React.ReactNode;
    /**
     * Use a reversed colour scheme
     * @default false
     */
    reversed?: boolean;
    /**
     * Whether the "select control" (the button you click to open the menu) width fills the
     * full width of  the container or is as wide as the selected option text.
     * Note that the control text will ellipsize if it is wider than the parent container.
     * @default false
     */
    fullWidth?: boolean;
    /**
     * @deprecated Use of placeholder text goes against our a11y standards.
     * Use the `labelText` prop to provide a concise name, and the `description` prop for any help text.
     */
    placeholder?: string;
} & ReactSelectProps<any, boolean>;
/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3081896474/Select Guidance} |
 * {@link https://cultureamp.design/?path=/docs/components-select--docs Storybook}
 */
export declare const Select: React.ForwardRefExoticComponent<{
    /**
     * The secondary variant is a more subdued variant that takes up as little space as possible
     * `variant="secondary" reversed="false" is not implemented and will throw a "not implemented" error
     * @default "default"
     */
    variant?: "default" | "secondary" | "secondary-small";
    status?: "default" | "error";
    label?: React.ReactNode;
    validationMessage?: React.ReactNode;
    description?: React.ReactNode;
    /**
     * Use a reversed colour scheme
     * @default false
     */
    reversed?: boolean;
    /**
     * Whether the "select control" (the button you click to open the menu) width fills the
     * full width of  the container or is as wide as the selected option text.
     * Note that the control text will ellipsize if it is wider than the parent container.
     * @default false
     */
    fullWidth?: boolean;
    /**
     * @deprecated Use of placeholder text goes against our a11y standards.
     * Use the `labelText` prop to provide a concise name, and the `description` prop for any help text.
     */
    placeholder?: string;
} & Omit<import("react-select/dist/declarations/src/Select").PublicBaseSelectProps<any, boolean, import("react-select").GroupBase<any>>, "onChange" | "value" | "inputValue" | "onInputChange" | "menuIsOpen" | "onMenuOpen" | "onMenuClose"> & Partial<import("react-select/dist/declarations/src/Select").PublicBaseSelectProps<any, boolean, import("react-select").GroupBase<any>>> & import("react-select/dist/declarations/src/useStateManager").StateManagerAdditionalProps<any> & React.RefAttributes<any>>;
interface AsyncProps extends ReactAsyncSelectProps<any, boolean, any>, ReactSelectProps<any, boolean, any> {
}
export declare const AsyncSelect: React.ForwardRefExoticComponent<AsyncProps & React.RefAttributes<any>>;
export {};
