import React, { type HTMLAttributes } from 'react';
import { type DataAttributes } from "../types/DataAttributes";
import { type OverrideClassName } from "../types/OverrideClassName";
import { type ActionButtonProps } from './subcomponents/ActionButton';
import { type DropdownButtonProps } from './subcomponents/DropdownButton';
export type SplitButtonProps = {
    /**
     * Props for primary action button (left).
     * Allows all native button/anchor attributes.
     */
    actionButtonProps: ActionButtonProps & DataAttributes;
    /**
     * Props for dropdown menu button (right).
     * Allows all native button/anchor attributes.
     */
    dropdownButtonProps?: DropdownButtonProps & DataAttributes;
    /**
     * Suggested components - MenuList > MenuItem
     */
    dropdownContent: React.ReactNode;
    /**
     * Sets the dropdown menu to be open on initial render.
     */
    isDropdownInitOpen?: boolean;
    /**
     * Disables both the primary action button and dropdown button.
     */
    disabled?: boolean;
    /**
     * Use the `reversed` styles.
     */
    isReversed?: boolean;
    /**
     * Text direction.
     */
    dir?: 'ltr' | 'rtl';
} & OverrideClassName<HTMLAttributes<HTMLDivElement>>;
/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3081896196/Split+Button Guidance} |
 * {@link https://cultureamp.design/storybook/?path=/docs/components-splitbutton--docs Storybook}
 */
export declare const SplitButton: {
    ({ actionButtonProps, dropdownButtonProps, dropdownContent, isDropdownInitOpen, disabled, isReversed, dir, classNameOverride, ...restProps }: SplitButtonProps): JSX.Element;
    displayName: string;
};
