import React from 'react';
import { type InputProps } from "../Input";
type OmittedInputProps = 'startIconAdornment' | 'endIconAdornment' | 'ariaDescribedBy' | 'ariaLabel';
export type TextFieldProps = {
    /**
     * A short example of input text. For context or additional information use the `description` prop
     */
    labelText: React.ReactNode;
    inline?: boolean;
    icon?: JSX.Element;
    /**
     * A descriptive message for `error` or `caution` states
     */
    validationMessage?: string | React.ReactNode;
    /**
     * A description that provides context for the text field
     */
    description?: string | React.ReactNode;
} & Omit<InputProps, OmittedInputProps>;
/**
 * {@link https://cultureamp.atlassian.net/wiki/spaces/DesignSystem/pages/3081928705/Text+Field Guidance} |
 * {@link https://cultureamp.design/?path=/docs/components-text-field--docs Storybook}
 */
export declare const TextField: {
    ({ id: propsId, labelText, inline, icon, validationMessage, description, status, reversed, disabled, ...restProps }: TextFieldProps): JSX.Element;
    displayName: string;
};
export {};
