import React from 'react';
type Position = 'above' | 'below' | 'left' | 'right';
type Mood = 'default' | 'informative' | 'positive' | 'cautionary' | 'highlight';
export type TooltipProps = {
    /**
     * Unfortunately, the content needed to be wrapped in a div. This can sometimes
     * break the css layout. To get around this, we allow you to specify the css
     * display value directly. If you need to need to modify more values, feel free
     * to use the `classNameOverride` prop, but avoid it if you can.
     */
    display?: 'block' | 'inline' | 'inline-block' | 'flex' | 'inline-flex';
    /**
     * This is more a "desired position". The tooltip will automatically change
     * its position, if there's not enough room to show it in the one specified.
     */
    position?: Position;
    /** The text content for the tooltip */
    text: React.ReactNode;
    /**
     * This is the interactable element that is being described by the tooltip `text`
     */
    children?: React.ReactNode;
    classNameOverride?: string;
    mood?: Mood;
    /**
     * Render the tooltip inside a react portal, given the ccs selector.
     * This is typically used for instances where the menu is a descendant of an
     * `overflow: scroll` or `overflow: hidden` element.
     */
    portalSelector?: string;
    /**
     * Should the tooltip be visible on the first render. Useful for visual
     * regression testing.
     */
    isInitiallyVisible?: boolean;
    animationDuration?: number;
};
export declare const Tooltip: {
    ({ children, text, display, position, classNameOverride, portalSelector, animationDuration, isInitiallyVisible, mood, }: TooltipProps): JSX.Element;
    displayName: string;
};
export {};
