import { type Ref } from 'react';
export interface DOMRectReadOnly {
    readonly x: number;
    readonly y: number;
    readonly width: number;
    readonly height: number;
    readonly top: number;
    readonly right: number;
    readonly bottom: number;
    readonly left: number;
}
/**
 * Hook for observing changes to a DOM element via ResizeObserver.
 *
 * @param {resolveEntryCallback} resolveEntry - Callback for resolving the
 * desired value from each ResizeObserverEntry emitted by ResizeObserver
 * @return {Array} An array containing a ref for binding to the observed DOM
 * element, and the current value of the callback-resolved ResizeObserverEntry
 * @callback resolveEntryCallback
 * @deprecated use native `ResizeObserver` DOM API instead
 */
export declare const useResizeObserver: <T, E extends Element = HTMLElement>(resolveEntry?: (entry: ResizeObserverEntry) => any) => [Ref<E>, T | undefined];
